<?php
/*
Plugin Name: Quick Start Plugin
Plugin URI: http://www.EtoileWebDesign.com/plugins/
Description: Handles inital page creation and plugin setup - can be deactivated and deleted once installation is complete
Author: EWD
Text Domain: ewd-quick-starter
Version: 0.1
*/

class EWD_Quick_Starter {
    /**
    * The (hopefully) only app integration instance
    *
    * @since 1.0.0
    *
    * @var EWD_Quick_Starter
    */
    private static $instance;

    /**
    * Plugin version for enqueueing, etc.
    *
    * @since 1.0.0
    *
    * @var string
    */
    public $version = '0.1';

    public function __construct() {
        register_activation_hook( __FILE__, array( $this, 'set_initial_setup_transient' ) );

        if ( get_transient( 'ewdqs-do-initital-setup' ) ) { add_action( 'wp_loaded', array( $this, 'do_initial_setup' ), 1 ); }

        if ( get_transient( 'ewdqs-getting-started' ) ) { $this->redirect_after_install(); }

        if ( isset( $_GET['ewdqs_run_installation'] ) ) { add_action( 'wp_loaded', array( $this, 'run_installation' ), 10 ); }
    }


    /**
    * Main EWD_Quick_Starter Instance.
    *
    * Insures that only one instance of EWD_Quick_Starter exists in memory at any one
    * time. Also prevents needing to define globals all over the place.
    *
    * @since 1.0.0
    *
    * @return EWD_Quick_Starter
    */
    public static function instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof EWD_Quick_Starter ) ) {

            self::$instance = new EWD_Quick_Starter();

            add_action( 'wp_loaded', array( self::$instance, 'enqueue_tasks' ), 10 );

            if ( isset($_GET['page']) and $_GET['page'] == 'ewdqs-overview' ) { add_action( 'wp_loaded', array( self::$instance, 'display_overview_if_necessary' ), 11 ); } 

            // Hook now that all of the EWD_Quick_Starter stuff is loaded.
            do_action( 'ewdqs_loaded' );
        }

        return self::$instance;
    }

    public function set_initial_setup_transient() {
        set_transient( 'ewdqs-do-initital-setup', true, 30 );
    }

    public function do_initial_setup() {

        if ( is_admin() ) {
            $this->constants();

            require_once EWDQS_DIR . 'includes/class-run-background-setup.php';

            new EWDQS_Background_Setup();

        }
    } 

    public function run_installation() {

        $this->constants();

        require_once EWDQS_DIR . 'includes/class-run-installation.php';

        new EWDQS_Installation();
    }

    public function enqueue_tasks() {
        $tasks = get_option("ewdqs_tasks");
        $completed_tasks = get_option("ewdqs_completed_tasks");

        if ( $tasks != $completed_tasks and is_admin() ) {
            $this->constants();
            $this->includes();

            add_action( 'plugins_loaded', array( $this, 'load_textdomain' ), 10 );
            add_action( 'plugins_loaded', array( $this, 'objects' ), 10 );

            foreach ( $tasks as $task ) {
                if ( in_array( $task, $completed_tasks ) ) { continue; }

                $this->task = $task;

                new $task;

                if ( $task != 'EWDQS_Show_Optional_Steps') { new EWDQS_Admin_Header; }

                break;
            }
        }
    }

    public function display_overview_if_necessary() {

        if ( $this->task == 'EWDQS_Show_Overview' ) { return; }

        $this->constants();

        require_once EWDQS_DIR . 'includes/class-build-admin-header.php';
        require_once EWDQS_DIR . 'includes/class-show-overview.php';

        new EWDQS_Show_Overview();
        new EWDQS_Admin_Header;
    }

    public function redirect_after_install() {
        delete_transient( 'ewdqs-getting-started' );

        header( "Location:index.php?page=ewdqs-overview" );
    }

    /**
     * Setup plugin constants.
     *
     * @since 1.0.0
     */
    private function constants() {

        // Plugin version.
        if ( ! defined( 'EWDQS_VERSION' ) ) {
            define( 'EWDQS_VERSION', $this->version );
        }

        // Plugin Folder Path.
        if ( ! defined( 'EWDQS_DIR' ) ) {
            define( 'EWDQS_DIR', plugin_dir_path( __FILE__ ) );
        }

        // Plugin Folder URL.
        if ( ! defined( 'EWDQS_URL' ) ) {
            define( 'EWDQS_URL', plugin_dir_url( __FILE__ ) );
        }

        // Plugin Root File.
        if ( ! defined( 'EWDQS_FILE' ) ) {
            define( 'EWDQS_FILE', __FILE__ );
        }
    }

    /**
     * Include files.
     *
     * @since 1.0.0
     */
    private function includes() {
        require_once EWDQS_DIR . 'includes/class-build-admin-header.php';
        require_once EWDQS_DIR . 'includes/class-dashboard-redirect.php';
        require_once EWDQS_DIR . 'includes/class-handle-basic-setup.php';
        require_once EWDQS_DIR . 'includes/class-handle-catalogue-setup.php';
        require_once EWDQS_DIR . 'includes/class-handle-category-creation.php';
        require_once EWDQS_DIR . 'includes/class-handle-faq-creation.php';
        require_once EWDQS_DIR . 'includes/class-handle-featured-products.php';
        require_once EWDQS_DIR . 'includes/class-handle-menu-setup.php';
        require_once EWDQS_DIR . 'includes/class-handle-pages-setup.php';
        require_once EWDQS_DIR . 'includes/class-handle-order-tracking-setup.php';
        require_once EWDQS_DIR . 'includes/class-handle-restaurant-menu-creation.php';
        require_once EWDQS_DIR . 'includes/class-handle-restaurant-reservations-settings.php';
        require_once EWDQS_DIR . 'includes/class-handle-theme-setup.php';
        require_once EWDQS_DIR . 'includes/class-handle-woocommerce-setup.php';
        require_once EWDQS_DIR . 'includes/class-handle-wpforms-creation.php';
        require_once EWDQS_DIR . 'includes/class-show-optional-steps.php';
        require_once EWDQS_DIR . 'includes/class-show-overview.php';
    }

    /**
     * Loads the plugin language files.
     *
     * @since 1.0.0
     */
    public function load_textdomain() {

        load_plugin_textdomain( 'ewd-quick-starter', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
    }

    /**
     * Setup objects.
     *
     * @since 1.0.0
     */
    public function objects() {
        
    }
}

/**
 * The function which returns the one AF_App_Interaction instance.
 *
 * @since 1.0.0
 *
 * @return AF_App_Interaction
 */
function ewd_quick_starter() {

    return EWD_Quick_Starter::instance();
}

ewd_quick_starter();

?>