<?php
class EWDQS_Create_Blog_Categories {

	function __construct() {
		add_action( 'admin_enqueue_scripts', array($this, 'enqueue_scripts') );
		add_action( 'admin_menu', array($this, 'add_menu_page') );
		add_action( 'admin_head', array($this, 'remove_admin_menu_link') );

		if (isset($_POST['save_post_categories'])) {
			$this->save_page_content();
			$this->update_tasks();

			wp_safe_redirect(admin_url());
		}
		else {
			if (!isset($_GET['page']) or $_GET['page'] != 'ewdqs-category-creation') {
				wp_safe_redirect( admin_url( 'index.php?page=ewdqs-category-creation') );
				exit;
			}
		}
	}

	function enqueue_scripts() {
		wp_enqueue_script( 'ewdqs-category-creation-js', EWDQS_URL . 'includes/js/ewdqs-category-creation.js', array('jquery') );
		wp_enqueue_style( 'ewdqs-category-creation-css', EWDQS_URL . 'includes/css/ewdqs-category-creation.css' );
	}

	function add_menu_page() {
		add_dashboard_page(
			esc_html__( 'Create Categories', 'ewd-quick-starter' ),
			esc_html__( 'Create Categories', 'ewd-quick-starter' ),
			'manage_options',
			'ewdqs-category-creation',
			array($this, 'display_category_creation_screen')
		);
	}

	function remove_admin_menu_link() {
		remove_submenu_page( 'index.php', 'ewdqs-category-creation' );
	}

	function display_category_creation_screen() {
		echo '<div class="ewdqs-categories-setup">';
			echo '<form method="post">';

				echo '<h2>' . __('Blog Categories', 'ewd-quick-starter') . '</h2>';
				echo '<div class="ewdqs-categories-setup-box">';

					echo '<div class="ewdqs-categories-setup-box-each">';
						echo '<div class="ewdqs-categories-setup-box-content-divs">';
							echo '<label>' . __('Category Name', 'ewd-quick-starter') . '</label>';
							echo '<input type="text" name="category_name_0">';
						echo '</div>';
						echo '<div class="ewdqs-categories-setup-box-content-divs">';
							echo '<label>' . __('Category Description', 'ewd-quick-starter') . '</label>';
							echo '<textarea name="category_description_0"></textarea>';
						echo '</div>';
					echo '</div>';

					echo '<div class="ewdqs-clear"></div>';
					echo '<div class="ewdqs-add-category" data-nextcategory="1">' . __('Add Category', 'ewd-quick-starter') . '</div>';
					echo '<div class="ewdqs-clear"></div>';

				echo '</div>';

				echo '<div class="ewdqs-clear"></div>';

				echo '<div class="ewdqs-category-creation-save">';
					echo '<input type="submit" name="save_post_categories" value="' . __('Save and Continue') . '" />';
				echo '</div>';

			echo '</form>';
		echo '</div>';
	}

	function save_page_content() {
		for ($i=0; $i<=100; $i++) {
			if (!isset($_POST['category_name_' . $i])) {break;}

	    	wp_insert_term(
	    		sanitize_text_field($_POST['category_name_' . $i]),
	    		'category', 
	    		array(
	    			'description' => sanitize_text_field($_POST['category_description_' . $i]),
	    			'slug' => sanitize_title($_POST['category_name_' . $i]),
	    			'category_parent' => 0,
	    		)
	    	);
		}
	}

	function update_tasks() {
		$completed_tasks = get_option("ewdqs_completed_tasks");
		$completed_tasks[] = 'EWDQS_Create_Blog_Categories';
		update_option("ewdqs_completed_tasks", $completed_tasks);
	}
}

function EWDQS_Create_Blog_Categories_name() {
	return "Blog Categories";
}

function EWDQS_Create_Blog_Categories_instructions() {
	return "Create categories for your blog. Categories help visitors find the post that will most interest them.";
}