<?php
class EWDQS_Featured_Products {

	function __construct() {
		add_action( 'admin_enqueue_scripts', array($this, 'enqueue_scripts') );
		add_action( 'admin_menu', array($this, 'add_menu_page') );
		add_action( 'admin_head', array($this, 'remove_admin_menu_link') );
		
		if (isset($_POST['save_featured_products'])) {
			$this->save_featured_products();
			$this->update_tasks();

			wp_safe_redirect(admin_url());
		}
		else {
			if (!isset($_GET['page']) or $_GET['page'] != 'ewdqs-featured-products') {
				wp_safe_redirect( admin_url( 'index.php?page=ewdqs-featured-products') );
				exit;
			}
		}
	}

	function enqueue_scripts() {
		wp_enqueue_style( 'ewdqs-featured-products-css', EWDQS_URL . 'includes/css/ewdqs-featured-products.css' );
	}

	function add_menu_page() {
		add_dashboard_page(
			esc_html__( 'Featured Products', 'ewd-quick-starter' ),
			esc_html__( 'Featured Products', 'ewd-quick-starter' ),
			'manage_options',
			'ewdqs-featured-products',
			array($this, 'display_featured_products_screen')
		);
	}

	function remove_admin_menu_link() {
		remove_submenu_page( 'index.php', 'ewdqs-featured-products' );
	}

	function display_featured_products_screen() {
		$products = UPCP_Get_All_Products();
		$categories = UPCP_Get_All_Categories();

		echo '<div class="ewdqs-featured-products-section">';
		echo '<form action="#" method="post">';

		echo '<h2>' . __('Select Featured Products', 'ewd-quick-starter') . '</h2>';
		echo '<div class="ewdqs-featured-products-section-box">';
			echo '<div class="ewdqs-featured-product-selection">';
			echo '<select name="featured_product_one" class="ewdqs-featured-product-field" />';
			foreach ($products as $product) {
			    echo "<option value='" . esc_attr( $product->Get_Item_ID() ) . "' />" . esc_html( $product->Get_Product_Name() ) . "</option>";
			}
			echo '</select>';
			echo '<div class="ewdqs-clear"></div>';
			echo '</div>';
			echo '<div class="ewdqs-featured-product-selection">';
			echo '<select name="featured_product_two" class="ewdqs-featured-product-field" />';
			foreach ($products as $product) {
			    echo "<option value='" . esc_attr( $product->Get_Item_ID() ) . "' />" . esc_html( $product->Get_Product_Name() ) . "</option>";
			}
			echo '</select>';
			echo '<div class="ewdqs-clear"></div>';
			echo '</div>';
			echo '<div class="ewdqs-featured-product-selection">';
			echo '<select name="featured_product_three" class="ewdqs-featured-product-field" />';
			foreach ($products as $product) {
			    echo "<option value='" . esc_attr( $product->Get_Item_ID() ) . "' />" . esc_html( $product->Get_Product_Name() ) . "</option>";
			}
			echo '</select>';
			echo '<div class="ewdqs-clear"></div>';
			echo '</div>';
			echo '<div class="ewdqs-featured-product-selection">';
			echo '<select name="featured_product_four" class="ewdqs-featured-product-field" />';
			foreach ($products as $product) {
			    echo "<option value='" . esc_attr( $product->Get_Item_ID() ) . "' />" . esc_html( $product->Get_Product_Name() ) . "</option>";
			}
			echo '</select>';
			echo '<div class="ewdqs-clear"></div>';
			echo '</div>';

		echo '</div>';

		echo '<div class="ewdqs-clear"></div>';

		if( get_option('template') == 'ultimate-showcase' ){
			echo '<div class="ewdqs-featured-products-section-box-hide">';
		}
		echo '<h2>' . __('Select A Featured Category', 'ewd-quick-starter') . '</h2>';
		echo '<div class="ewdqs-featured-products-section-box">';
			echo '<div class="ewdqs-featured-category-selection">';
			echo '<select name="featured_category" class="ewdqs-featured-category-field" />';
			foreach ($categories as $category) {
			    echo "<option value='" . esc_attr( $category->Category_ID ) . "' />" . esc_html( $category->Category_Name ) . "</option>";
			}
			echo '</select>';
			echo '<div class="ewdqs-clear"></div>';
			echo '</div>';
		echo '</div>';
		if( get_option('template') == 'ultimate-showcase' ){
			echo '</div>';
		}


		echo '<div class="ewdqs-clear"></div>';

		echo '<div class="ewdqs-featured-products-save">';
		echo '<input type="submit" name="save_featured_products" value="' . __('Save and Continue') . '" />';
		echo '</div>';

		echo '</form>';
		echo '</div>';
	}

	function save_featured_products() {
		$products = array();

		if ($_POST['featured_product_one']) {$products[] = array('ProductID' => intval($_POST['featured_product_one']));}
		if ($_POST['featured_product_two']) {$products[] = array('ProductID' => intval($_POST['featured_product_two']));}
		if ($_POST['featured_product_three']) {$products[] = array('ProductID' => intval($_POST['featured_product_three']));}
		if ($_POST['featured_product_four']) {$products[] = array('ProductID' => intval($_POST['featured_product_four']));}

		update_option("EWD_UPCP_Theme_Featured_Products", $products);

		$products_string = '';
		foreach ($products as $product) {
			$products_string .= $product['ProductID'] . ",";
		}
		$products_string = trim($products_string, ",");

		$homepage_object = get_page_by_path('home');
		$post_content = str_replace( array('featured_product_ids', 'featured_category_id'), array($products_string, $_POST['featured_category']), $homepage_object->post_content );
		wp_update_post( array('ID' => $homepage_object->ID, 'post_content' => $post_content ) );

		update_option('widget_upcp_product_list_widget', str_replace( 'featured_product_ids', $products_string, get_option('widget_upcp_product_list_widget') ));
	}

	function update_tasks() {
		$completed_tasks = get_option("ewdqs_completed_tasks");
		$completed_tasks[] = 'EWDQS_Featured_Products';
		update_option("ewdqs_completed_tasks", $completed_tasks);
	}
}

function EWDQS_Featured_Products_name() {
	return "Featured Products";
}

function EWDQS_Featured_Products_instructions() {
	return "Select the products that you'd like to feature on the homepage of your site.";
}