<?php
class EWDQS_Pages_Setup {

	function __construct() {
		add_action( 'admin_enqueue_scripts', array($this, 'enqueue_scripts') );
		add_action( 'admin_menu', array($this, 'add_menu_page') );
		add_action( 'admin_head', array($this, 'remove_admin_menu_link') );

		if (isset($_POST['save_page_content'])) {
			$this->save_page_content();
			$this->update_tasks();

			global $wpdb;

			// This is overwriting the theme's plugin options function, is it necessary?
			$option_value = $wpdb->get_var( "SELECT option_value FROM $wpdb->options WHERE option_name='ewdqs_active_plugins'");
			$wpdb->query( "UPDATE $wpdb->options SET option_value = '" . $option_value . "' WHERE option_name='active_plugins'" );

			flush_rewrite_rules();

			wp_safe_redirect(admin_url());
		}
		else {
			if (!isset($_GET['page']) or $_GET['page'] != 'ewdqs-page-content') {
				wp_safe_redirect( admin_url( 'index.php?page=ewdqs-page-content') );
				exit;
			}
		}
	}

	function enqueue_scripts() {
		wp_enqueue_style( 'ewdqs-pages-setup-css', EWDQS_URL . 'includes/css/ewdqs-pages-setup.css' );
	}

	function add_menu_page() {
		add_dashboard_page(
			esc_html__( 'Page Content', 'ewd-quick-starter' ),
			esc_html__( 'Page Content', 'ewd-quick-starter' ),
			'manage_options',
			'ewdqs-page-content',
			array($this, 'display_page_setup_screen')
		);
	}

	function remove_admin_menu_link() {
		remove_submenu_page( 'index.php', 'ewdqs-page-content' );
	}

	function display_page_setup_screen() {
		/*$pages = array(
			array(
				'page_slug' => 'frequently-asked-questions',
				'deletable' => false
			),
			array(
				'page_slug' => 'contact-us',
				'deletable' => false
			),
			array(
				'page_slug' => 'about-us',
				'deletable' => true
			)
		);
		update_option("ewdqs_pages", $pages);*/

		$pages = get_option("ewdqs_pages");

		echo '<div class="ewdqs-page-setup">';
		echo '<form method="post">';

		foreach ($pages as $page) {
			$page_object = get_page_by_path($page['page_slug']);

			echo '<div class="ewdqs-page">';

			echo '<div class="ewdqs-page-keep">';
			if ($page['deletable']) {echo '<input type="checkbox" name="' . $page_object->ID . '_keep" value="yes" checked>';}
			else {echo '<input type="hidden" name="' . $page_object->ID . '_keep" value="yes">';}
			echo '</div>';

			echo '<div class="ewdqs-page-name">' . $page_object->post_title . '</div>';

			echo '<div class="ewdqs-page-edit">';
			echo '<div class="ewdqs-page-title">';
			echo '<div class="ewdqs-page-title-label">' . __('Title:', 'ewd-quick-starter') . '</div>';
			echo '<input type="text" name="' . $page_object->ID . '_title" value="' . $page_object->post_title . '" />';
			echo '</div>';
			echo '<div class="ewdqs-clear"></div>';
			echo '<div class="ewdqs-page-content">';
			echo '<div class="ewdqs-page-content-label">' . __('Content:', 'ewd-quick-starter') . '</div>';
			wp_editor($page_object->post_content, $page_object->ID . '_content', array('media_buttons' => false, 'textarea_rows' => 6));
			echo '</div>';
			echo '</div>';
			echo '<div class="ewdqs-clear"></div>';

			echo '</div>';
			//echo '<div class="ewdqs-clear"></div>';
		}

		echo '<div class="ewdqs-page-content-save">';
			echo '<input type="submit" name="save_page_content" value="' . __('Save and Continue') . '" />';
		echo '</div>';

		echo '<div class="ewdqs-clear"></div>';

		echo '</form>';
		echo '</div>';
	}

	function save_page_content() {
		$pages = get_option("ewdqs_pages");

		foreach ($pages as $page) {
			$page_object = get_page_by_path($page['page_slug']);

			if ($page['deletable'] and !isset($_POST[$page_object->ID . '_keep'])) {wp_delete_post($page_object->ID);}
			else {
				wp_update_post(array(
					'ID' => $page_object->ID,
					'post_title' => sanitize_text_field($_POST[$page_object->ID . '_title']),
					'post_content' => wp_kses_post($_POST[$page_object->ID . '_content'])
				));
			}
		}
	}

	function update_tasks() {
		$completed_tasks = get_option("ewdqs_completed_tasks");
		$completed_tasks[] = 'EWDQS_Pages_Setup';
		update_option("ewdqs_completed_tasks", $completed_tasks);
	}
}

function EWDQS_Pages_Setup_name() {
	return "Page Content";
}

function EWDQS_Pages_Setup_instructions() {
	return "Set your page content below. If there are pages you don't want to include in your site, you can uncheck the checkbox beside the page name. Pages can always be updated or deleted after your site has been set up.";
}