<?php
class EWDQS_Theme_Selection {

	function __construct() {
		add_action( 'admin_enqueue_scripts', array($this, 'enqueue_scripts') );
		add_action( 'admin_menu', array($this, 'add_menu_page') );
		add_action( 'admin_head', array($this, 'remove_admin_menu_link') );
		
		if (isset($_POST['save_theme_options'])) {
			$this->save_theme_settings();
			$this->update_tasks();

			wp_safe_redirect(admin_url());
		}
		else {
			if (!isset($_GET['page']) or $_GET['page'] != 'ewdqs-theme-selection') {
				wp_safe_redirect( admin_url( 'index.php?page=ewdqs-theme-selection') );
				exit;
			}
		}
	}

	function enqueue_scripts() {
		wp_enqueue_style( 'ewdqs-theme-selection-css', EWDQS_URL . 'includes/css/ewdqs-theme-selection.css' );

		wp_enqueue_style( 'wp-color-picker' ); 
		wp_enqueue_script( 'ewdqs-theme-colors', EWDQS_URL . 'includes/js/ewdqs-theme-selection.js', array( 'wp-color-picker' ) );
	}

	function add_menu_page() {
		add_dashboard_page(
			esc_html__( 'Theme Selection', 'ewd-quick-starter' ),
			esc_html__( 'Theme Selection', 'ewd-quick-starter' ),
			'manage_options',
			'ewdqs-theme-selection',
			array($this, 'display_theme_selection_screen')
		);
	}

	function remove_admin_menu_link() {
		remove_submenu_page( 'index.php', 'ewdqs-theme-selection' );
	}

	function display_theme_selection_screen() {
		// $themes = array(
		// 	array(
		// 		'theme_slug' => 'bakes-and-cakes',
		// 		'theme_name' => 'Bakes and Cakes',
		// 		'theme_screenshot_url' => 'https://i0.wp.com/themes.svn.wordpress.org/bakes-and-cakes/1.1.6/screenshot.png?w=1142&strip=all'
		// 	),
		// 	array(
		// 		'theme_slug' => 'catch-foodmania',
		// 		'theme_name' => 'Catch Foodmania',
		// 		'theme_screenshot_url' => 'https://themes.svn.wordpress.org/catch-foodmania/2.0/screenshot.png'
		// 	),
		// 	array(
		// 		'theme_slug' => 'recipe-lite',
		// 		'theme_name' => 'Recipe Lite',
		// 		'theme_screenshot_url' => 'https://themes.svn.wordpress.org/recipe-lite/1.1/screenshot.png'
		// 	),
		// );
		// update_option("ewdqs_theme_options", $themes); 
		$theme_options = get_option("ewdqs_theme_options");
		$current_theme = get_option("template");

		echo '<div class="ewdqs-theme-selection">';
		echo '<form method="post">';

		foreach ($theme_options as $theme_option) {
			echo '<div class="ewdqs-possible-theme">';
			echo '<img src="' . $theme_option['theme_screenshot_url'] . '" />';
			echo '<div class="ewdqd-theme-name">';
			echo '<input type="radio" name="ewdqs_selected_theme" value="' . $theme_option['theme_slug'] . '" ' . ($theme_option['theme_slug'] == $current_theme ? 'checked' : '') . ' />';
			echo $theme_option['theme_name'];
			echo '</div>';
			echo '</div>';
		}
		echo '<div class="ewdqs-clear"></div>';

		echo '<h2>' . __('Set Your Colors', 'ewd-quick-starter') . '</h2>';
		echo '<div class="ewdqs-theme-color-section">';
		echo '<div class="ewdqs-theme-color-option">';
		echo '<div class="ewdqs-theme-color-label">' . __('Headings', 'ewd-quick-starter') . '</div>';
		echo '<input type="text" name="theme_selection_headings_color" class="ewdqs-color-field" />';
		echo '<div class="ewdqs-clear"></div>';
		echo '</div>';
		echo '<div class="ewdqs-theme-color-option">';
		echo '<div class="ewdqs-theme-color-label">' . __('Text', 'ewd-quick-starter') . '</div>';
		echo '<input type="text" name="theme_selection_text_color" class="ewdqs-color-field" />';
		echo '<div class="ewdqs-clear"></div>';
		echo '</div>';
		echo '<div class="ewdqs-theme-color-option">';
		echo '<div class="ewdqs-theme-color-label">' . __('Background', 'ewd-quick-starter') . '</div>';
		echo '<input type="text" name="theme_selection_background_color" class="ewdqs-color-field" />';
		echo '<div class="ewdqs-clear"></div>';
		echo '</div>';
		echo '<div class="ewdqs-theme-color-option">';
		echo '<div class="ewdqs-theme-color-label">' . __('Foreground', 'ewd-quick-starter') . '</div>';
		echo '<input type="text" name="theme_selection_foreground_color" class="ewdqs-color-field" />';
		echo '<div class="ewdqs-clear"></div>';
		echo '</div>';
		echo '</div>';

		echo '<div class="ewdqs-clear"></div>';

		echo '<div class="ewdqs-theme-selection-save">';
		echo '<input type="submit" name="save_theme_options" value="' . __('Save and Continue') . '" />';
		echo '</div>';

		echo '</form>';
		echo '</div>';
	}

	function save_theme_settings() {
		$this->set_theme_options($_POST['ewdqs_selected_theme']);
		$this->activate_plugins($_POST['ewdqs_selected_theme']);
		$this->set_page_content($_POST['ewdqs_selected_theme']);
		$this->create_objects($_POST['ewdqs_selected_theme']);
		$this->switch_theme($_POST['ewdqs_selected_theme']);
		$this->set_colors($_POST['ewdqs_selected_theme']);
		$this->set_post_meta($_POST['ewdqs_selected_theme']);

		update_user_meta(1, 'tgmpa_dismissed_notice_' . $_POST['ewdqs_selected_theme'], "1");
	}

	function switch_theme($theme_slug) {
		switch_theme($theme_slug);
	}

	function set_theme_options($theme_slug) {
		// Kale and Pulito
		// $theme_options = array(
		// 	'show_on_front' => 'posts'
		// );
		// update_option('theme_options_' . $theme_slug, $theme_options);

		$theme_options = get_option('theme_options_' . $theme_slug);
		foreach ($theme_options as $option_name => $option_value) {
			update_option($option_name, $option_value);
		}
	}

	function set_colors($theme_slug) {
		//	//Bakes and Cakes
		//	$theme_selectors = array(
		//		'foreground' => '\n/* Site navigation border line */\n.main-navigation {\nborder-top: 1px solid $color;\n}\n\n\n/* Site navigation */\n.main-navigation .current_page_item > a, .main-navigation .current-menu-item > a, .main-navigation .current_page_ancestor > a, .main-navigation .current-menu-ancestor > a, .main-navigation a:hover,\n.main-navigation a:focus\n{\ncolor: $color;\n}\n\n\n/* Featured color */\n.featured {\nbackground: $color;\n}\n\n\n/* \"What\'s Happening\" Text color */\n.special .header .main-title {\ncolor: $color;\n}\n\n\n/* \"Reserve Now\" button hover*/\n.promotional-block .btn-join:hover {\nbackground: $color;\n}\n\n\n/* \"TOP\" link hover*/\n.btn-top:hover {\ncolor: $color;\n}\n\n\n/* Menu \n.erm_product_price .price {\ncolor: $color;\n}\n*/\n\n\n/* \"Request Booking\" button */\n.rtb-booking-form button:hover {\nbackground-color: $color;\n}\n\n\n/* FAQ 	+/- symbol */\n.ewd-ufaq-post-margin-symbol {\ncolor: $color !important;\n}\n\n\n/* \"Submit\" button hover */\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\nbackground-color: $color;\n}\n\n\n/* Overall changes: */\n\n/* make anchor text color as the foreground color */\na {\ncolor: $color;\n}'	
		//	);
		//	update_option("theme_css_selectors_bakes-and-cakes", $theme_selectors);

		//	//Catch Foodmania
		//	$theme_selectors = array(
		//		'foreground' => '\n\n/* Site navigation */\n.sticky-nav.navigation-classic.absolute-header .main-navigation a,\n.sticky-nav.navigation-classic.absolute-header .main-navigation .current-menu-item > a,\n.sticky-nav.absolute-header .site-title a,\n.sticky-nav.absolute-header #social-search-toggle {\n	color: $color;\n}\n\n\n/* scroll to top button*/\n#scrollup {\n	background-color: $color;\n}\n\n\n/* \"Request Booking\" button */\n.rtb-booking-form button {\n	background-color: $color;\n}\n\n\n/* FAQ +/- symbol */\n.ewd-ufaq-post-margin-symbol {\n	color: $color !important;\n}\n\n\n/* contact form button */\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n	background-color: $color;\n}\n\n\n/* make anchor text color as the foreground color */\na {\n	color: $color;\n}\n\n\n/* homepage section headings */\n.featured-content-section 	h2,\n.hero-content-wrapper h2,\n.testimonials-content-wrapper h2 {\n	color: $color;\n}\n\n\n/*border around testimonial images*/\n.cycle-pager-active {\n	color: $color;\n}\n\n\n/*read more buttons*/\n.more-button a {\n	background-color: $color;\n}\n\n\n/*footer*/\n.site-footer {\n	background-color: $color;\n}'	
		//	);
		//	update_option("theme_css_selectors_catch-foodmania", $theme_selectors);

		//	//Recipe Lite
		//	$theme_selectors = array(
		//		'foreground' => '\n.sitenav ul li a:hover, .sitenav ul li.current_page_item a, .sitenav ul li.menu-item-has-children.hover, .sitenav ul li.current-menu-parent a.parent {\ncolor: $color;\n}\n\n\n/* Slider \"Read More\" button hover*/\n\n.slide_info .slide_more:hover {\nbackground-color:$color;\n}\n\n\n/* Check if slide_info span needs to be foreground or if it is included in \"Headings\" color selector */\n/*\n.slide_info h2 span {\n    color: $color;\n}\n*/\n\n\n/* Slider ControNav Dot */\n\n.nivo-controlNav a.active {\n    background-color: $color;\n}\n\n/* Specialty Box */\n/* Check if :hover h4 is included in \"Headings\" color selector \n.specialty-box-inner:hover h4 {\n    color: $color;\n}\n*/\n\n\n/* Threebox hover color */\n\n.threebox {\nbackground-color: $color;\n}\n\n\n/* \"Reserve Now\" button hover*/\n\n.newReservationButton:hover {\nbackground: 	$color;\n}\n\n\n/* Footer recent-post anchor text hover*/\n.recent-post a:hover {\ncolor: $color;\n}\n\n\n/* Footer email text hover*/\n.phone-no a:hover {\ncolor: $color;\n}\n\n\n.erm_product_price .price {\ncolor: $color;\n}\n*/\n\n\n/* \"Request Booking\" button */\n.rtb-booking-form button:hover {\nbackground-color: $color;\n}\n\n\n/* FAQ +/- symbol */\n.ewd-ufaq-post-margin-symbol {\ncolor: $color !important;\n}\n\n/* \"Search\" button */\ninput.search-submit, .post-password-form input[type=submit], .wpcf7-form input[type=submit] {\nbackground-color: $color;\n}\n\n/* \"Submit\" button hover */\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\nbackground-color: $color;\n}\n\n\n\n/* Overall changes: */\n\n/* make anchor text color as the foreground color */\na {\ncolor: $color;\n}'	
		//	);
		//	update_option("theme_css_selectors_recipe-lite", $theme_selectors);

		//	//Ultimate Showcase
		//	$theme_selectors = array(
		//		'foreground' => '#menu ul li a:hover {color: $color; border-bottom: 2px solid $color;} #header input:hover {border-color: $color; background: $color;} .ewd-slider-icon:hover {color: $color;} .slideButtons li a:hover {background: $color !important;} .newButton.centerButton:hover {background: $color;} .newButton.whiteButton:hover {background: $color;} .testimonials ul li .testimonialQuote {color: $color;} .calloutArea {background-color: $color;} .singlePage .titleArea {background-color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}'
		//	);
		//	update_option("theme_css_selectors_ultimate-showcase", $theme_selectors);

		//	//Gutenshop
		//	$theme_selectors = array(
		//		'foreground' => '.ewd-slider-icon:hover {color: $color;} .slideButtons li a:hover {background: $color !important;} .upcp-minimal-title {color: $color;} .upcp-minimal-price {color: $color;} .site-info > a {color: $color;} .footer-info-right > a {color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}'
		//	);
		//	update_option("theme_css_selectors_gutenshop", $theme_selectors);

		//	//GTL Multipurpose
		//	$theme_selectors = array(
		//		'foreground' => 'nav ul > li.current-menu-item {background-color: $color;} .custom-btn.secondary-btn, .wpcf7-submit {background-color: $color;} .flex-prev {color: $color;} .flex-prev:hover {color: $color;} .flex-next {color: $color;} .flex-next:hover {color: $color;} .upcp-minimal-title {color: $color;} .upcp-minimal-price {color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}'
		//	);
		//	update_option("theme_css_selectors_gtl-multipurpose", $theme_selectors);

		$theme_selectors = get_option("theme_css_selectors_" . $theme_slug);

		$added_css = ($this->check_color($_POST['theme_selection_headings_color']) ? (isset($theme_selectors['headings']) ? str_replace('$color', $_POST['theme_selection_headings_color'], $theme_selectors['headings']) : 'h1,h2,h3,h4,h5,h6 {color:' . $_POST['theme_selection_headings_color'] . ' !important;}') : '');
		if(get_option('template') == 'gutenshop'){
			$added_css .= ($this->check_color($_POST['theme_selection_text_color']) ? (isset($theme_selectors['text']) ? str_replace('$color', $_POST['theme_selection_text_color'], $theme_selectors['text']) : 'body {color:' . $_POST['theme_selection_text_color'] . ' !important;}p {color:' . $_POST['theme_selection_text_color'] . ' !important;}') : '');
		}
		else{
			$added_css .= ($this->check_color($_POST['theme_selection_text_color']) ? (isset($theme_selectors['text']) ? str_replace('$color', $_POST['theme_selection_text_color'], $theme_selectors['text']) : 'body {color:' . $_POST['theme_selection_text_color'] . ' !important;}') : '');			
		}
		$added_css .= ($this->check_color($_POST['theme_selection_background_color']) ? (isset($theme_selectors['background']) ? str_replace('$color', $_POST['theme_selection_background_color'], $theme_selectors['background']) : 'body {background:' . $_POST['theme_selection_background_color'] . ' !important;}') : '');
		$added_css .= ($this->check_color($_POST['theme_selection_foreground_color']) ? (isset($theme_selectors['foreground']) ? str_replace('$color', $_POST['theme_selection_foreground_color'], $theme_selectors['foreground']) : 'body div {background:' . $_POST['theme_selection_foreground_color'] . ' !important;}') : '');
		$posts = get_posts(array('post_type' => 'custom_css', 'name' => $theme_slug));
			
		foreach ($posts as $post) {
			wp_update_custom_css_post($post->post_content . $added_css, $post->post_name);
		}
	}

	function set_page_content($theme_slug) {
		//Ultimate Showcase
		// $theme_content = array(
		// 	array(
		// 		'ID' => 2,
		// 		'post_content' => '<!-- wp:paragraph --><p>Thanks for visiting our shop site. We have all the latest tech and the best prices and customer service in the industry. If you have any questions or need any help, please do not hesitate to get in touch.</p><!-- /wp:paragraph -->'
		// 	)
		// );


		// Gutenshop
		// $theme_content = array(
		// 	array(
		// 		'ID' => 2,
		// 		'post_content' => '<!-- wp:ultimate-slider/ewd-us-slider-block /--><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode --><p>[insert-products catalogue_url="' . esc_url( home_url( '/' ) ) . 'store/" product_count="4"]</p><!-- /wp:shortcode --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="' . esc_url( home_url( '/' ) ) . 'wp-content/uploads/2019/05/freeshipping.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="' . esc_url( home_url( '/' ) ) . 'wp-content/uploads/2019/05/customerservice.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="' . esc_url( home_url( '/' ) ) . 'wp-content/uploads/2019/05/nohiddenfees.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns --><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">New Smartphones</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our latest new stock of smartphones. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode --><p>[insert-products catalogue_url="' . esc_url( home_url( '/' ) ) . 'store/" product_count="4"]</p><!-- /wp:shortcode -->'
		// 	)
		// );


		// GTL
		// $theme_content = array(
		// 	array(
		// 		'ID' => 2,
		// 		'post_content' => '<!-- wp:ultimate-slider/ewd-us-slider-block /--><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode --><p>[insert-products catalogue_url="' . esc_url( home_url( '/' ) ) . 'store/" product_count="4"]</p><!-- /wp:shortcode --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="' . esc_url( home_url( '/' ) ) . 'wp-content/uploads/2019/05/freeshipping.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="' . esc_url( home_url( '/' ) ) . 'wp-content/uploads/2019/05/customerservice.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="' . esc_url( home_url( '/' ) ) . 'wp-content/uploads/2019/05/nohiddenfees.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns --><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">New Smartphones</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our latest new stock of smartphones. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode --><p>[insert-products catalogue_url="' . esc_url( home_url( '/' ) ) . 'store/" product_count="4"]</p><!-- /wp:shortcode -->'
		// 	)
		// );
		//update_option("theme_page_content_" . $theme_slug, $theme_content);



		// Keep Calm
		// $theme_content = array(
		// 	array(
		// 		'ID' => 2,
		// 		'post_content' => '<!-- wp:paragraph --><p>Thanks for visiting our shop site. We have all the latest tech and the best prices and customer service in the industry. If you have any questions or need any help, please do not hesitate to get in touch.</p><!-- /wp:paragraph -->'
		// 	)
		// );
		// update_option("theme_page_content_" . $theme_slug, $theme_content);


		// Gutenshop
		// $theme_content = array(
		// 	array(
		// 		'ID' => 2,
		// 		'post_content' => '<!-- wp:ultimate-slider/ewd-us-slider-block /--><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:woocommerce/product-new --><div class="wp-block-woocommerce-product-new">[products limit="3" columns="3" orderby="date" order="DESC"]</div><!-- /wp:woocommerce/product-new --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/freeshipping.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/customerservice.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/nohiddenfees.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns -->'
		// 	)
		// );
		// update_option("theme_page_content_" . $theme_slug, $theme_content);


		// Ecommerce Hub
		// $theme_content = array(
		// 	array(
		// 		'ID' => 2,
		// 		'post_content' => '<!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:woocommerce/product-new --><div class="wp-block-woocommerce-product-new">[products limit="3" columns="3" orderby="date" order="DESC"]</div><!-- /wp:woocommerce/product-new --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/freeshipping.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/customerservice.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/nohiddenfees.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns -->'
		// 	)
		// );
		// update_option("theme_page_content_" . $theme_slug, $theme_content);



		// Vega
		// $theme_content = array(
		// 	array(
		// 		'ID' => 2,
		// 		'post_content' => '<!-- wp:paragraph --><p>This is a website set up to help NGOs and educational institutions create their websites.</p><!-- /wp:paragraph -->'
		// 	)
		// );
		// update_option("theme_page_content_" . $theme_slug, $theme_content);


		$theme_content = get_option("theme_page_content_" . $theme_slug);

		foreach ($theme_content as $page_content) {
			wp_update_post($page_content);
		}
	}

	function activate_plugins($theme_slug) {
		$theme_plugins = get_option("theme_plugins_" . $theme_slug);
		$active_plugins = get_option("active_plugins");

		foreach ($theme_plugins as $theme_plugin) {
			$active_plugins[] = $theme_plugin;
		}
		update_option("active_plugins", $active_plugins);
	}

	function set_post_meta($theme_slug) {
	//		//Bakes and Cakes
	//		$theme_post_meta = array(
	//			array(
	//				'post_id' => 2,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-home.php'
	//			)
	//		);
	//		update_option("theme_post_meta_bakes-and-cakes", $theme_post_meta);
	//
	//		//Recipe Lite
	//		$theme_post_meta = array(
	//			array(
	//				'post_id' => 2,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-fullwide.php'
	//			),
	//			array(
	//				'post_id' => 3,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-fullwide.php'
	//			),
	//			array(
	//				'post_id' => 4,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-fullwide.php'
	//			),
	//			array(
	//				'post_id' => 5,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-fullwide.php'
	//			),
	//			array(
	//				'post_id' => 6,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-fullwide.php'
	//			),
	//			array(
	//				'post_id' => 7,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-fullwide.php'
	//			)
	//		);
	//		update_option("theme_post_meta_recipe-lite", $theme_post_meta);




	//		//GTL Multipurpose
	//		$theme_post_meta = array(
	//			array(
	//				'post_id' => 2,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'template-home.php'
	//			)
	//		);
	//		update_option("theme_post_meta_gtl-multipurpose", $theme_post_meta);
	//
	//		//Gutenshop
	//		$theme_post_meta = array(
	//			array(
	//				'post_id' => 4,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'page-templates/fullwidth.php'
	//			),
	//			array(
	//				'post_id' => 3,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'page-templates/fullwidth.php'
	//			),
	//			array(
	//				'post_id' => 2,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'page-templates/landing-page.php'
	//			),
	//		);
	//		update_option("theme_post_meta_gutenshop", $theme_post_meta);
	// 
	//		// Ultimate Showcase
	//		$theme_post_meta = array(
	//			array(
	//				'post_id' => 2,
	//				'meta_key' => '_wp_page_template',
	//				'meta_value' => 'page-home.php'
	//			)
	//		);
	//		update_option("theme_post_meta_ultimate-showcase", $theme_post_meta);

		
			// // Keep Calm and E-Comm
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 5,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-sidebar.php'
			// 	),
			// 	array(
			// 		'post_id' => 6,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-sidebar.php'
			// 	),
			// 	array(
			// 		'post_id' => 2,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-home.php'
			// 	)
			// );
			// update_option("theme_post_meta_keep-calm-and-e-comm", $theme_post_meta);


			// // Ecommerce Hub
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 5,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'page-template/page-with-right-sidebar.php'
			// 	),
			// 	array(
			// 		'post_id' => 6,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'page-template/page-with-right-sidebar.php'
			// 	),
			// 	array(
			// 		'post_id' => 2,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'page-template/custom-front-page.php'
			// 	)
			// );
			// update_option("theme_post_meta_ecommerce-hub", $theme_post_meta);


			// //Gutenshop
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'page-templates/fullwidth.php'
			// 	),
			// 	array(
			// 		'post_id' => 7,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'page-templates/fullwidth.php'
			// 	),
			// 	array(
			// 		'post_id' => 2,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'page-templates/landing-page.php'
			// 	),
			// );
			// update_option("theme_post_meta_gutenshop", $theme_post_meta);



			// // Atlast Agency
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 2,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'page-templates/atlast-agency-front-tpl.php'
			// 	),
			// 	array(
			// 		'post_id' => 5,
			// 		'meta_key' => '_thumbnail_id',
			// 		'meta_value' => 'books_notebook_attachment'
			// 	),
			// );
			// update_option("theme_post_meta_atlast-agency", $theme_post_meta);


			// Vega 
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 3,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// 	array(
			// 		'post_id' => 7,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// 	array(
			// 		'post_id' => 8,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	)
			// );
			// update_option("theme_post_meta_vega", $theme_post_meta);


			// LEANEX 
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 3,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'templates/full-width-page.php'
			// 	),
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'templates/full-width-page.php'
			// 	),
			// 	array(
			// 		'post_id' => 7,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'templates/full-width-page.php'
			// 	),
			// 	array(
			// 		'post_id' => 8,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'templates/full-width-page.php'
			// 	)
			// );
			// update_option("theme_post_meta_leanex-lite", $theme_post_meta);


			// // Kale
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 5,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'city1'
			// 	),
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'imacmacbookipad2'
			// 	),
			// 	array(
			// 		'post_id' => 6,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'gtlslider1'
			// 	)
			// );
			// update_option("theme_post_meta_kale", $theme_post_meta);


			// // Pulito
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 5,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'city1'
			// 	),
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'imacmacbookipad2'
			// 	),
			// 	array(
			// 		'post_id' => 6,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'gtlslider1'
			// 	)
			// );
			// update_option("theme_post_meta_pulito-clean-blog-lite", $theme_post_meta);


			// // Blog Lover
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 5,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'city1'
			// 	),
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'imacmacbookipad2'
			// 	),
			// 	array(
			// 		'post_id' => 6,
			// 		'meta_key' => 'thumbnail',
			// 		'meta_value' => 'gtlslider1'
			// 	)
			// );
			// update_option("theme_post_meta_blog-lover", $theme_post_meta);


			// //Charity Help Lite
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 2,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// 	array(
			// 		'post_id' => 3,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// );
			// update_option("theme_post_meta_charity-help-lite", $theme_post_meta);


			// // Vega
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 2,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// 	array(
			// 		'post_id' => 3,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// 	array(
			// 		'post_id' => 4,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-full-width.php'
			// 	),
			// );
			// update_option("theme_post_meta_vega", $theme_post_meta);


			// // Benevolent
			// $theme_post_meta = array(
			// 	array(
			// 		'post_id' => 2,
			// 		'meta_key' => '_wp_page_template',
			// 		'meta_value' => 'template-home.php'
			// 	),
			// );
			// update_option("theme_post_meta_benevolent", $theme_post_meta);


		$theme_post_meta = get_option("theme_post_meta_" . $theme_slug);

		foreach ($theme_post_meta as $post_meta) {
			update_post_meta( $post_meta['post_id'], $post_meta['meta_key'], $post_meta['meta_value'] );
		}
	}

	function create_objects($theme_slug) {
		//Bakes and Cakes
		// $create_objects = array(
		// 	array(
		// 		'type' => 'category',
		// 		'name' => 'slider',
		// 		'title' => 'Slider',
		// 		'content' => 'For the homepage slider'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'restaurant4',
		// 		'filename' => 'restaurant4.jpg',
		// 		'title' => 'Slider Restaurant Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'abendbrot-939435_1920',
		// 		'filename' => 'abendbrot-939435_1920.jpg',
		// 		'title' => 'Slider Table Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 190;
		// 		'type' => 'post',
		// 		'name' => 'an-amazing-dining-experience',
		// 		'title' => 'An Amazing Dining Experience!',
		// 		'content' => '<!-- wp:paragraph --><p>Our handmade dishes will take you on a culinary adventure. Come join us for a dining experience you will not soon forget.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Our handmade dishes will take you on a culinary adventure.',
		// 		'terms' => array (
		// 			array(
		// 				'slug' => 'slider',
		// 				'taxonomy' => 'category'
		// 			)
		// 		),
		// 		'thumbnail' => 'restaurant4',
		// 		'replace_term' => 'an_amazing_dining_experience_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 196;
		// 		'type' => 'post',
		// 		'name' => 'great-food-great-service',
		// 		'title' => 'Great Food! Great Service!',
		// 		'content' => '<!-- wp:paragraph --><p>When you are here, you are family! Come feel right at home with our tasty menu and warm service.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'When you are here, you are family! Come feel right at home with our tasty menu and warm service.',
		// 		'terms' => array (
		// 			array(
		// 				'slug' => 'slider',
		// 				'taxonomy' => 'category'
		// 			)
		// 		),
		// 		'thumbnail' => 'abendbrot-939435_1920',
		// 		'replace_term' => 'great_food_great_service_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 176;
		// 		'type' => 'post',
		// 		'name' => 'event-one',
		// 		'title' => 'Event One',
		// 		'content' => '<!-- wp:paragraph --><p>Description of weekly event.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Event One Schedule',
		// 		'replace_term' => 'event_one_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 179;
		// 		'type' => 'post',
		// 		'name' => 'event-two',
		// 		'title' => 'Event Two',
		// 		'content' => '<!-- wp:paragraph --><p>Description of weekly event.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Event Two Schedule',
		// 		'category_name' => '',
		// 		'replace_term' => 'event_two_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects);
		
		// Catch Foodmania
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'restaurant4',
		// 		'filename' => 'restaurant4.jpg',
		// 		'title' => 'Slider Restaurant Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'abendbrot-939435_1920',
		// 		'filename' => 'abendbrot-939435_1920.jpg',
		// 		'title' => 'Slider Table Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'reservations_fc',
		// 		'filename' => 'reservations_fc.jpg',
		// 		'title' => 'Private Events Featured Content Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'table_fc',
		// 		'filename' => 'table_fc.jpg',
		// 		'title' => 'Weekly Specials Featured Content Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'cheersing_fc',
		// 		'filename' => 'cheersing_fc.jpg',
		// 		'title' => 'Happy Hour Featured Content Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'bowl-1932375_1280',
		// 		'filename' => 'bowl-1932375_1280.jpg',
		// 		'title' => 'First Testimonial Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'pizza-3303388_1280',
		// 		'filename' => 'pizza-3303388_1280.jpg',
		// 		'title' => 'Second Testimonial Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 314;
		// 		'type' => 'page',
		// 		'name' => 'an-amazing-dining-experience',
		// 		'title' => 'An Amazing Dining Experience!',
		// 		'content' => '<!-- wp:paragraph --><p>Our handmade dishes will take you on a culinary adventure. Come join us for a dining experience you will not soon forget.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Our handmade dishes will take you on a culinary adventure!',
		// 		'thumbnail' => 'restaurant4',
		// 		'replace_term' => 'an_amazing_dining_experience_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 316;
		// 		'type' => 'page',
		// 		'name' => 'great-food-great-service',
		// 		'title' => 'Great Food! Great Service!',
		// 		'content' => '<!-- wp:paragraph --><p>When you are here, you are family! Come feel right at home with our tasty menu and warm service.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'When you are here, you are family! Come feel right at home with our tasty menu and warm service.',
		// 		'thumbnail' => 'abendbrot-939435_1920',
		// 		'replace_term' => 'great_food_great_service_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 366;
		// 		'type' => 'ect_featured_content',
		// 		'name' => 'private-events',
		// 		'title' => 'Private Events',
		// 		'content' => '<!-- wp:paragraph --><p>Our restaurant offers the perfect setting to host your event.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Our restaurant offers the perfect setting to host your event.',
		// 		'thumbnail' => 'reservations_fc',
		// 		'replace_term' => 'private_event_featured_content_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 361;
		// 		'type' => 'ect_featured_content',
		// 		'name' => 'weekly-specials',
		// 		'title' => 'Weekly Specials',
		// 		'content' => '<!-- wp:paragraph --><p>Including dinner specials on Wednesdays and wine tasting on Thursdays.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Including dinner specials on Wednesdays and wine tasting on Thursdays.',
		// 		'thumbnail' => 'table_fc',
		// 		'replace_term' => 'weekly_specials_featured_content_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 360;
		// 		'type' => 'ect_featured_content',
		// 		'name' => 'happy-hour',
		// 		'title' => 'Happy Hour',
		// 		'content' => '<!-- wp:paragraph --><p>Between 4pm and 6pm, enjoy 2 for 1 drinks.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Between 4pm and 6pm, enjoy 2 for 1 drinks.',
		// 		'thumbnail' => 'cheersing_fc',
		// 		'replace_term' => 'happy_hour_featured_content_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 370;
		// 		'type' => 'ect_testimonial',
		// 		'name' => 'giovanna-arturi',
		// 		'title' => 'Giovanna Arturi',
		// 		'content' => '<!-- wp:paragraph --><p>The best restaurant experience I have had in years! The food was great and the service was above and beyond.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => '',
		// 		'thumbnail' => 'bowl-1932375_1280',
		// 		'replace_term' => 'first_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 368;
		// 		'type' => 'ect_testimonial',
		// 		'name' => 'james-blake',
		// 		'title' => 'James Blake',
		// 		'content' => '<!-- wp:paragraph --><p>I had a super experience at this restaurant. The food was great, the service was outstanding, and they even brought me a complementary glass of bubbly when they found out it was my birthday!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => '',
		// 		'thumbnail' => 'pizza-3303388_1280',
		// 		'replace_term' => 'second_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 

		// Recipe Lite
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'restaurant4',
		// 		'filename' => 'restaurant4.jpg',
		// 		'title' => 'Slider Restaurant Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'abendbrot-939435_1920',
		// 		'filename' => 'abendbrot-939435_1920.jpg',
		// 		'title' => 'Slider Table Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'toast',
		// 		'filename' => 'toast.jpg',
		// 		'title' => 'Happy Hour Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'weeklyspecial',
		// 		'filename' => 'weeklyspecial.jpg',
		// 		'title' => 'Weekly Specials Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'dinnerevent',
		// 		'filename' => 'dinnerevent.jpg',
		// 		'title' => 'Private Events Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 314;
		// 		'type' => 'page',
		// 		'name' => 'an-amazing-dining-experience',
		// 		'title' => 'An Amazing Dining Experience!',
		// 		'content' => '<!-- wp:paragraph --><p>Our handmade dishes will take you on a culinary adventure. Come join us for a dining experience you will not soon forget.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Our handmade dishes will take you on a culinary adventure!',
		// 		'thumbnail' => 'restaurant4',
		// 		'replace_term' => 'an_amazing_dining_experience_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 316;
		// 		'type' => 'page',
		// 		'name' => 'great-food-great-service',
		// 		'title' => 'Great Food! Great Service!',
		// 		'content' => '<!-- wp:paragraph --><p>When you are here, you are family! Come feel right at home with our tasty menu and warm service.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'When you are here, you are family! Come feel right at home with our tasty menu and warm service.',
		// 		'thumbnail' => 'abendbrot-939435_1920',
		// 		'replace_term' => 'great_food_great_service_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 408;
		// 		'type' => 'page',
		// 		'name' => 'happy-hour',
		// 		'title' => 'Happy Hour',
		// 		'content' => '<!-- wp:paragraph --><p>Between 4pm and 6pm, enjoy 2 for 1 drinks.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Between 4pm and 6pm, enjoy 2 for 1 drinks.',
		// 		'thumbnail' => 'toast',
		// 		'replace_term' => 'happy_hour_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 407;
		// 		'type' => 'page',
		// 		'name' => 'weekly-specials',
		// 		'title' => 'Weekly Specials',
		// 		'content' => '<!-- wp:paragraph --><p>Including dinner specials on Wednesdays and wine tasting on Thursdays.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Including dinner specials on Wednesdays and wine tasting on Thursdays.',
		// 		'thumbnail' => 'weeklyspecial',
		// 		'replace_term' => 'weekly_specials_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 406;
		// 		'type' => 'page',
		// 		'name' => 'private-events',
		// 		'title' => 'Private Events',
		// 		'content' => '<!-- wp:paragraph --><p>Our restaurant offers the perfect setting to host your event.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Our restaurant offers the perfect setting to host your event.',
		// 		'thumbnail' => 'dinnerevent',
		// 		'replace_term' => 'private_events_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 




		// Ultimate Showcase
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Ultimate Slider iMac Macbook Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'macbookipadipone',
		// 		'filename' => 'macbookipadipone.jpg',
		// 		'title' => 'Ultimate Slider Macbook iPad',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'macbookonleft2',
		// 		'filename' => 'macbookonleft2.jpg',
		// 		'title' => 'Text On Pic Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 6;
		// 		'type' => 'page',
		// 		'name' => 'home',
		// 		'title' => 'Home',
		// 		'content' => '<!-- wp:paragraph --><p>Thanks for visiting our shop site. We have all the latest tech and the best prices and customer service in the industry. If you have any questions or need any help, please do not hesitate to get in touch.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'home_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 95;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'shop-smart-shop-easy',
		// 		'title' => 'Shop Smart. Shop Easy.',
		// 		'content' => '<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!',
		// 		'thumbnail' => 'imacmacbookipad2',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 1
		// 			)
		// 		),
		// 		'replace_term' => 'imac_macbook_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 99;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'great-prices-great-service',
		// 		'title' => 'Great Prices. Great Service.',
		// 		'content' => '<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We pride ourselves on offering the most up-to-date stock at the best prices you will find online.',
		// 		'thumbnail' => 'macbookipadipone',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 2
		// 			)
		// 		),
		// 		'replace_term' => 'macbook_ipad_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 110;
		// 		'type' => 'upcp_theme_jumpboxes',
		// 		'name' => 'everything-you-need',
		// 		'title' => 'Everything You Need',
		// 		'content' => 'We have a very large selection of in-stock products. No waiting around or buying from multiple sources. We are your one-stop shop for smartphones, tablets and computers.',
		// 		'excerpt' => 'We are your one-stop shop for smartphones, tablets and computers.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'everything_you_need_jumpbox_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 112;
		// 		'type' => 'upcp_theme_jumpboxes',
		// 		'name' => 'great-service',
		// 		'title' => 'Great Service',
		// 		'content' => 'Our knowledgeable staff lives and breathes tech. We are always up to date on the latest technology and trends. So, if you are uncertain about what you need, be sure to ask our experts.',
		// 		'excerpt' => 'We are always up to date on the latest technology and trends.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'great_service_jumpbox_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 114;
		// 		'type' => 'upcp_theme_jumpboxes',
		// 		'name' => 'best-price-guarantee',
		// 		'title' => 'Best Price Guarantee',
		// 		'content' => 'We offer the best prices you will find online and will not be undersold. If you happen to find one of our items cheaper somewhere else, be sure to get in touch with us and we will beat it.',
		// 		'excerpt' => 'We offer the best prices you will find online and will not be undersold.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'best_price_jumpbox_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 34;
		// 		'type' => 'upcp_theme_testi',
		// 		'name' => 'testimonial-one',
		// 		'title' => 'Testimonial One',
		// 		'content' => 'Buying from Shop Site was a breeze. I will definitely be back!',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => '_testimonialName',
		// 				'meta_value' => 'Michelle Falsetto'
		// 			),
		// 			array(
		// 				'meta_key' => '_testimonialCompany',
		// 				'meta_value' => 'Widgets ETC'
		// 			)
		// 		),
		// 		'replace_term' => 'one_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 36;
		// 		'type' => 'upcp_theme_testi',
		// 		'name' => 'testimonial-two',
		// 		'title' => 'Testimonial Two',
		// 		'content' => 'Thank you for the great phone and quick shipping!',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => '_testimonialName',
		// 				'meta_value' => 'Jane Q. Notreal'
		// 			),
		// 			array(
		// 				'meta_key' => '_testimonialCompany',
		// 				'meta_value' => 'Unreal Enterprises'
		// 			)
		// 		),
		// 		'replace_term' => 'two_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 123;
		// 		'type' => 'upcp_theme_testi',
		// 		'name' => 'testimonial-three',
		// 		'title' => 'Testimonial Three',
		// 		'content' => 'Excellent customer service! They helped me pick out the perfect tablet for my small business.',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => '_testimonialName',
		// 				'meta_value' => 'John Q. Fake'
		// 			),
		// 			array(
		// 				'meta_key' => '_testimonialCompany',
		// 				'meta_value' => 'The Fake Company Inc.'
		// 			)
		// 		),
		// 		'replace_term' => 'three_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 



		// Gutenshop
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Ultimate Slider iMac Macbook Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'macbookipadipone',
		// 		'filename' => 'macbookipadipone.jpg',
		// 		'title' => 'Ultimate Slider Macbook iPad',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'nohiddenfees',
		// 		'filename' => 'nohiddenfees.png',
		// 		'title' => 'Gutenshop Jump Box Image One',
		// 		'content' => '',
		//		'replace_term' => 'nohiddenfees_attachment',
		//		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'customerservice',
		// 		'filename' => 'customerservice.png',
		// 		'title' => 'Gutenshop Jump Box Image Two',
		// 		'content' => '',
		//		'replace_term' => 'customerservice_attachment',
		//		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'freeshipping',
		// 		'filename' => 'freeshipping.png',
		// 		'title' => 'Gutenshop Jump Box Image Three',
		// 		'content' => '',
		//		'replace_term' => 'freeshipping_attachment',
		//		'replace_value' => 'post_url'
		// 	),
		// 	array( //post id: 95;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'shop-smart-shop-easy',
		// 		'title' => 'Shop Smart. Shop Easy.',
		// 		'content' => '<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!',
		// 		'thumbnail' => 'imacmacbookipad2',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 1
		// 			)
		// 		),
		// 		'replace_term' => 'imac_macbook_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 99;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'great-prices-great-service',
		// 		'title' => 'Great Prices. Great Service.',
		// 		'content' => '<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We pride ourselves on offering the most up-to-date stock at the best prices you will find online.',
		// 		'thumbnail' => 'macbookipadipone',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 2
		// 			)
		// 		),
		// 		'replace_term' => 'macbook_ipad_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 


		// GTL
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'gtlslider1',
		// 		'filename' => 'gtlslider1.jpg',
		// 		'title' => 'GTL Slider Fist Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'GTL Slider Second Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'nohiddenfees',
		// 		'filename' => 'nohiddenfees.png',
		// 		'title' => 'GTL Jump Box Image One',
		// 		'content' => '',
		//		'replace_term' => 'nohiddenfees_attachment',
		//		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'customerservice',
		// 		'filename' => 'customerservice.png',
		// 		'title' => 'GTL Jump Box Image Two',
		// 		'content' => '',
		//		'replace_term' => 'customerservice_attachment',
		//		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'freeshipping',
		// 		'filename' => 'freeshipping.png',
		// 		'title' => 'GTL Jump Box Image Three',
		// 		'content' => '',
		//		'replace_term' => 'freeshipping_attachment',
		//		'replace_value' => 'post_url'
		// 	)
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 




		// Keep Calm and E-Comm
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Ultimate Slider iMac Macbook Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'macbookipadipone',
		// 		'filename' => 'macbookipadipone.jpg',
		// 		'title' => 'Ultimate Slider Macbook iPad',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'northernlights2-1',
		// 		'filename' => 'northernlights2-1.jpg',
		// 		'title' => 'Text On Pic Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'iphone3',
		// 		'filename' => 'iphone3.png',
		// 		'title' => 'Text On Pic Overlay Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'bicycle2',
		// 		'filename' => 'bicycle2.png',
		// 		'title' => 'Bicycle Jump Box Icon',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'bus2',
		// 		'filename' => 'bus2.png',
		// 		'title' => 'Bus Jump Box Icon',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'taxi2',
		// 		'filename' => 'taxi2.png',
		// 		'title' => 'Taxi Jump Box Icon',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 95;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'shop-smart-shop-easy',
		// 		'title' => 'Shop Smart. Shop Easy.',
		// 		'content' => '<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!',
		// 		'thumbnail' => 'imacmacbookipad2',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 1
		// 			)
		// 		),
		// 		'replace_term' => 'imac_macbook_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 99;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'great-prices-great-service',
		// 		'title' => 'Great Prices. Great Service.',
		// 		'content' => '<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We pride ourselves on offering the most up-to-date stock at the best prices you will find online.',
		// 		'thumbnail' => 'macbookipadipone',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 2
		// 			)
		// 		),
		// 		'replace_term' => 'macbook_ipad_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 110;
		// 		'type' => 'upcp_theme_jumpboxes',
		// 		'name' => 'everything-you-need',
		// 		'title' => 'Everything You Need',
		// 		'content' => 'We have a very large selection of in-stock products. No waiting around or buying from multiple sources. We are your one-stop shop for smartphones, tablets and computers.',
		// 		'excerpt' => 'We are your one-stop shop for smartphones, tablets and computers.',
		// 		'thumbnail' => 'bicycle2',
		// 		'replace_term' => 'everything_you_need_jumpbox_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 112;
		// 		'type' => 'upcp_theme_jumpboxes',
		// 		'name' => 'great-service',
		// 		'title' => 'Great Service',
		// 		'content' => 'Our knowledgeable staff lives and breathes tech. We are always up to date on the latest technology and trends. So, if you are uncertain about what you need, be sure to ask our experts.',
		// 		'excerpt' => 'We are always up to date on the latest technology and trends.',
		// 		'thumbnail' => 'bus2',
		// 		'replace_term' => 'great_service_jumpbox_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 114;
		// 		'type' => 'upcp_theme_jumpboxes',
		// 		'name' => 'best-prices',
		// 		'title' => 'Best Prices',
		// 		'content' => 'We offer the best prices you will find online and will not be undersold. If you happen to find one of our items cheaper somewhere else, be sure to get in touch with us and we will beat it.',
		// 		'excerpt' => 'We offer the best prices you will find online and will not be undersold.',
		// 		'thumbnail' => 'taxi2',
		// 		'replace_term' => 'best_price_jumpbox_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 116;
		// 		'type' => 'upcp_theme_jumpboxes',
		// 		'name' => 'satisfaction-guaranteed',
		// 		'title' => 'Satisfaction Guaranteed',
		// 		'content' => 'We are sure it will not happen, but, if ever there was something about a specific product that did not live up to your expectations, make sure to get in touch and we will be happy to help.',
		// 		'excerpt' => 'If there is something that did not live up to your expectations, get in touch and we will be happy to help.',
		// 		'thumbnail' => 'bicycle2',
		// 		'replace_term' => 'best_price_jumpbox_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 34;
		// 		'type' => 'upcp_theme_testi',
		// 		'name' => 'testimonial-one',
		// 		'title' => 'Testimonial One',
		// 		'content' => 'Buying from Shop Site was a breeze. I will definitely be back!',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => '_testimonialName',
		// 				'meta_value' => 'Michelle Falsetto'
		// 			),
		// 			array(
		// 				'meta_key' => '_testimonialCompany',
		// 				'meta_value' => 'Widgets ETC'
		// 			)
		// 		),
		// 		'replace_term' => 'one_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 36;
		// 		'type' => 'upcp_theme_testi',
		// 		'name' => 'testimonial-two',
		// 		'title' => 'Testimonial Two',
		// 		'content' => 'Thank you for the great phone and quick shipping!',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => '_testimonialName',
		// 				'meta_value' => 'Jane Q. Notreal'
		// 			),
		// 			array(
		// 				'meta_key' => '_testimonialCompany',
		// 				'meta_value' => 'Unreal Enterprises'
		// 			)
		// 		),
		// 		'replace_term' => 'two_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 38;
		// 		'type' => 'upcp_theme_testi',
		// 		'name' => 'testimonial-three',
		// 		'title' => 'Testimonial Three',
		// 		'content' => 'Excellent customer service! They helped me pick out the perfect tablet for my small business.',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => '_testimonialName',
		// 				'meta_value' => 'John Q. Fake'
		// 			),
		// 			array(
		// 				'meta_key' => '_testimonialCompany',
		// 				'meta_value' => 'The Fake Company Inc.'
		// 			)
		// 		),
		// 		'replace_term' => 'three_testimonial_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	// array( //post id: 40;
		// 	// 	'type' => 'upcp_theme_testi',
		// 	// 	'name' => 'testimonial-four',
		// 	// 	'title' => 'Testimonial Four',
		// 	// 	'content' => 'Amazing and smooth Order! Could not have asked for a more easy and pleasant experience.',
		// 	// 	'excerpt' => '',
		// 	// 	'thumbnail' => '',
		// 	// 	'post_meta' => array(
		// 	// 		array(
		// 	// 			'meta_key' => '_testimonialName',
		// 	// 			'meta_value' => 'Rebecca Simon'
		// 	// 		),
		// 	// 		array(
		// 	// 			'meta_key' => '_testimonialCompany',
		// 	// 			'meta_value' => 'New Industries'
		// 	// 		)
		// 	// 	),
		// 	// 	'replace_term' => 'four_testimonial_post',
		// 	// 	'replace_value' => 'post_id'
		// 	// )
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 



		// Gutenshop
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Ultimate Slider iMac Macbook Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'macbookipadipone',
		// 		'filename' => 'macbookipadipone.jpg',
		// 		'title' => 'Ultimate Slider Macbook iPad',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'nohiddenfees',
		// 		'filename' => 'nohiddenfees.png',
		// 		'title' => 'Gutenshop Jump Box Image One',
		// 		'content' => '',
		// 		'replace_term' => 'nohiddenfees_attachment',
		// 		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'customerservice',
		// 		'filename' => 'customerservice.png',
		// 		'title' => 'Gutenshop Jump Box Image Two',
		// 		'content' => '',
		// 		'replace_term' => 'customerservice_attachment',
		// 		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'freeshipping',
		// 		'filename' => 'freeshipping.png',
		// 		'title' => 'Gutenshop Jump Box Image Three',
		// 		'content' => '',
		// 		'replace_term' => 'freeshipping_attachment',
		// 		'replace_value' => 'post_url'
		// 	),
		// 	array( //post id: 95;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'shop-smart-shop-easy',
		// 		'title' => 'Shop Smart. Shop Easy.',
		// 		'content' => '<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!',
		// 		'thumbnail' => 'imacmacbookipad2',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 1
		// 			)
		// 		),
		// 		'replace_term' => 'imac_macbook_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 99;
		// 		'type' => 'ultimate_slider',
		// 		'name' => 'great-prices-great-service',
		// 		'title' => 'Great Prices. Great Service.',
		// 		'content' => '<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We pride ourselves on offering the most up-to-date stock at the best prices you will find online.',
		// 		'thumbnail' => 'macbookipadipone',
		// 		'post_meta' => array(
		// 			array(
		// 				'meta_key' => 'EWD_US_Slide_Order',
		// 				'meta_value' => 2
		// 			)
		// 		),
		// 		'replace_term' => 'macbook_ipad_ultimate_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 


		// Ecommerce Hub
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Ultimate Slider iMac Macbook Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'gtlslider1',
		// 		'filename' => 'gtlslider1.jpg',
		// 		'title' => 'Ultimate Slider Macbook iPad',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'nohiddenfees',
		// 		'filename' => 'nohiddenfees.png',
		// 		'title' => 'Ecommerce Hub Jump Box Image One',
		// 		'content' => '',
		// 		'replace_term' => 'nohiddenfees_attachment',
		// 		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'customerservice',
		// 		'filename' => 'customerservice.png',
		// 		'title' => 'Ecommerce Hub Jump Box Image Two',
		// 		'content' => '',
		// 		'replace_term' => 'customerservice_attachment',
		// 		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'freeshipping',
		// 		'filename' => 'freeshipping.png',
		// 		'title' => 'Ecommerce Hub Jump Box Image Three',
		// 		'content' => '',
		// 		'replace_term' => 'freeshipping_attachment',
		// 		'replace_value' => 'post_url'
		// 	),
		// 	array( //post id: 314;
		// 		'type' => 'page',
		// 		'name' => 'great-prices-great-service',
		// 		'title' => 'Great Prices. Great Service.',
		// 		'content' => '<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We pride ourselves on offering the most up-to-date stock at the best prices',
		// 		'thumbnail' => 'gtlslider1',
		// 		'replace_term' => 'ecommerce_hub_first_slide_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 316;
		// 		'type' => 'page',
		// 		'name' => 'shop-smart-shop-easy',
		// 		'title' => 'Shop Smart. Shop Easy.',
		// 		'content' => '<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have all the latest electronics, including smartphones, tablets and computers.',
		// 		'thumbnail' => 'imacmacbookipad2',
		// 		'replace_term' => 'ecommerce_hub_second_slide_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 




		// // Vega
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'letter',
		// 		'filename' => 'letter.jpg',
		// 		'title' => 'Letter Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'typewriter',
		// 		'filename' => 'typewriter.jpg',
		// 		'title' => 'Typewriter Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'teamwork',
		// 		'filename' => 'teamwork.jpg',
		// 		'title' => 'Teamwork Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 82;
		// 		'type' => 'post',
		// 		'name' => 'a-great-adventure',
		// 		'title' => 'A Great Adventure',
		// 		'content' => '<!-- wp:paragraph --><p>We recently had the pleasure of working on a fun translation for a travel magazine about a great adventure the author had.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We recently had the pleasure of working on a fun translation for a travel magazine about a great adventure the author had.',
		// 		'thumbnail' => 'letter',
		// 		'replace_term' => 'great_adventure_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 78;
		// 		'type' => 'post',
		// 		'name' => 'awesome-new-translation',
		// 		'title' => 'Awesome New Translation',
		// 		'content' => '<!-- wp:paragraph --><p>Check out our latest translation, which we just completed for an awesome bicycle manufacturer.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Check out our latest translation, which we just completed for an awesome bicycle manufacturer.',
		// 		'thumbnail' => 'typewriter',
		// 		'replace_term' => 'awesome_new_translation_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 83;
		// 		'type' => 'post',
		// 		'name' => 'first-post',
		// 		'title' => 'First Post',
		// 		'content' => '<!-- wp:paragraph --><p>Welcome to WordPress. This is your first post. Edit or delete it, then start writing!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Welcome to WordPress. This is your first post. Edit or delete it, then start writing!',
		// 		'thumbnail' => 'teamwork',
		// 		'replace_term' => 'first_post_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 85;
		// 		'type' => 'page',
		// 		'name' => 'full-service-agency',
		// 		'title' => 'Full Service Agency',
		// 		'content' => '<!-- wp:paragraph --><p>We offer a wide array of translation services for several languages. Get in touch to see how we can help you.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We offer a wide array of translation services for several languages.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'full_service_agency_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 87;
		// 		'type' => 'page',
		// 		'name' => 'quick-turn-around',
		// 		'title' => 'Quick Turn Around',
		// 		'content' => '<!-- wp:paragraph --><p>With quick turn-around times, great accessibility and friendly service, we will make sure you get the exact results you need.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'With quick turn-around times, great accessibility and friendly service, we will make sure you get the exact results you need.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'quick_turn_around_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 94;
		// 		'type' => 'page',
		// 		'name' => 'translation-made-easy',
		// 		'title' => 'Translation Made Easy',
		// 		'content' => '<!-- wp:paragraph --><p>Our goal is to give you a professional translation in a timely manner and with great customer service.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Our goal is to give you a professional translation in a timely manner and with great customer service.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'translation_made_easy_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 92;
		// 		'type' => 'page',
		// 		'name' => 'very-accessible',
		// 		'title' => 'Very Accessible',
		// 		'content' => '<!-- wp:paragraph --><p>We are always accessible, in case you have any questions or concerns, or need to make any last-second changes to your translation.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We are always accessible, in case you have any questions or concerns.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'very_accessible_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 


		// // Atlast Agency
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'letter',
		// 		'filename' => 'letter.jpg',
		// 		'title' => 'Letter Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'typewriter',
		// 		'filename' => 'typewriter.jpg',
		// 		'title' => 'Typewriter Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'teamwork',
		// 		'filename' => 'teamwork.jpg',
		// 		'title' => 'Teamwork Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'dictionary',
		// 		'filename' => 'dictionary.jpg',
		// 		'title' => 'Dictionary Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'books-notebook',
		// 		'filename' => 'books-notebook.jpg',
		// 		'title' => 'Books and Notebook Image',
		// 		'content' => '',
		// 		'replace_term' => 'books_notebook_attachment',
		// 		'replace_value' => 'attachment_id'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'board',
		// 		'filename' => 'board.jpg',
		// 		'title' => 'Departure Board Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 82;
		// 		'type' => 'post',
		// 		'name' => 'a-great-adventure',
		// 		'title' => 'A Great Adventure',
		// 		'content' => '<!-- wp:paragraph --><p>We recently had the pleasure of working on a fun translation for a travel magazine about a great adventure the author had.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We recently had the pleasure of working on a fun translation for a travel magazine about a great adventure the author had.',
		// 		'thumbnail' => 'letter',
		// 		'replace_term' => 'great_adventure_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 78;
		// 		'type' => 'post',
		// 		'name' => 'awesome-new-translation',
		// 		'title' => 'Awesome New Translation',
		// 		'content' => '<!-- wp:paragraph --><p>Check out our latest translation, which we just completed for an awesome bicycle manufacturer.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Check out our latest translation, which we just completed for an awesome bicycle manufacturer.',
		// 		'thumbnail' => 'typewriter',
		// 		'replace_term' => 'awesome_new_translation_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 83;
		// 		'type' => 'post',
		// 		'name' => 'first-post',
		// 		'title' => 'First Post',
		// 		'content' => '<!-- wp:paragraph --><p>Welcome to WordPress. This is your first post. Edit or delete it, then start writing!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Welcome to WordPress. This is your first post. Edit or delete it, then start writing!',
		// 		'thumbnail' => 'teamwork',
		// 		'replace_term' => 'first_post_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 129;
		// 		'type' => 'page',
		// 		'name' => 'big-translation-job',
		// 		'title' => 'Big Translation Job',
		// 		'content' => '<!-- wp:paragraph --><p>With an engaging description below it.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'With an engaging description below it.',
		// 		'post_parent' => 'portfolio',
		// 		'thumbnail' => 'dictionary',
		// 		'replace_term' => 'big_translation_job_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 131;
		// 		'type' => 'page',
		// 		'name' => 'medium-translation-job',
		// 		'title' => 'Medium Translation Job',
		// 		'content' => '<!-- wp:paragraph --><p>Another engaging description.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Another engaging description.',
		// 		'post_parent' => 'portfolio',
		// 		'thumbnail' => 'books-notebook',
		// 		'replace_term' => 'medium_translation_job_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 133;
		// 		'type' => 'page',
		// 		'name' => 'small-translation-job',
		// 		'title' => 'Small Translation Job',
		// 		'content' => '<!-- wp:paragraph --><p>The most engaging description yet!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'The most engaging description yet!',
		// 		'post_parent' => 'portfolio',
		// 		'thumbnail' => 'board',
		// 		'replace_term' => 'small_translation_job_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 50;
		// 		'type' => 'page',
		// 		'name' => 'slider-parent',
		// 		'title' => 'Slider Parent',
		// 		'content' => '',
		// 		'excerpt' => '',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'slider_parent_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 59;
		// 		'type' => 'page',
		// 		'name' => 'amazing-collaborations',
		// 		'title' => 'Amazing Collaborations',
		// 		'content' => '<!-- wp:paragraph --><p>We have worked with some great clients over the years. Click below to see some of our projects.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have worked with some great clients over the years.',
		// 		'post_parent' => 'slider-parent',
		// 		'thumbnail' => 'collaboration-1',
		// 		'replace_term' => 'amazing_collaborations_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 52;
		// 		'type' => 'page',
		// 		'name' => 'our-latest-project',
		// 		'title' => 'Our Latest Project',
		// 		'content' => '<!-- wp:paragraph --><p>Click below to checkout out some of the highlights from our latest project.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Click below to checkout out some of the highlights from our latest project.',
		// 		'post_parent' => 'slider-parent',
		// 		'thumbnail' => 'teamwork',
		// 		'replace_term' => 'our_latest_project_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 


		// Leanex Lite
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'letter',
		// 		'filename' => 'letter.jpg',
		// 		'title' => 'Letter Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'typewriter',
		// 		'filename' => 'typewriter.jpg',
		// 		'title' => 'Typewriter Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'teamwork',
		// 		'filename' => 'teamwork.jpg',
		// 		'title' => 'Teamwork Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 82;
		// 		'type' => 'post',
		// 		'name' => 'a-great-adventure',
		// 		'title' => 'A Great Adventure',
		// 		'content' => '<!-- wp:paragraph --><p>We recently had the pleasure of working on a fun translation for a travel magazine about a great adventure the author had.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We recently had the pleasure of working on a fun translation for a travel magazine about a great adventure the author had.',
		// 		'thumbnail' => 'letter',
		// 		'replace_term' => 'great_adventure_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 78;
		// 		'type' => 'post',
		// 		'name' => 'awesome-new-translation',
		// 		'title' => 'Awesome New Translation',
		// 		'content' => '<!-- wp:paragraph --><p>Check out our latest translation, which we just completed for an awesome bicycle manufacturer.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Check out our latest translation, which we just completed for an awesome bicycle manufacturer.',
		// 		'thumbnail' => 'typewriter',
		// 		'replace_term' => 'awesome_new_translation_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 83;
		// 		'type' => 'post',
		// 		'name' => 'first-post',
		// 		'title' => 'First Post',
		// 		'content' => '<!-- wp:paragraph --><p>Welcome to WordPress. This is your first post. Edit or delete it, then start writing!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Welcome to WordPress. This is your first post. Edit or delete it, then start writing!',
		// 		'thumbnail' => 'teamwork',
		// 		'replace_term' => 'first_post_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 




		// // // Blog Lover
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'city1',
		// 		'filename' => 'city1.jpg',
		// 		'title' => 'City 1 Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'city2',
		// 		'filename' => 'city2.jpg',
		// 		'title' => 'City 2 Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'town',
		// 		'filename' => 'town.jpg',
		// 		'title' => 'Town Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'gtlslider1',
		// 		'filename' => 'gtlslider1.jpg',
		// 		'title' => 'Macbook and Notepad Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Imac Macbook Ipad Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 94;
		// 		'type' => 'post',
		// 		'name' => 'tech-at-its-best',
		// 		'title' => 'Tech at Its Best',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'thumbnail' => 'imacmacbookipad2',
		// 		'replace_term' => 'tech_at_its_best_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 41;
		// 		'type' => 'post',
		// 		'name' => 'what-an-adventure',
		// 		'title' => 'What an Adventure',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'thumbnail' => 'town',
		// 		'replace_term' => 'what_an_adventure_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 35;
		// 		'type' => 'post',
		// 		'name' => 'a-great-new-thing',
		// 		'title' => 'A Great New Thing',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'thumbnail' => 'city1',
		// 		'replace_term' => 'a_great_new_thing_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 90;
		// 		'type' => 'post',
		// 		'name' => 'outside-the-box-thinking',
		// 		'title' => 'Outside the Box Thinking',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'thumbnail' => 'city2',
		// 		'replace_term' => 'outside_the_box_thinking_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 


		// Kale
		// $create_objects = array(
		// 	array(
		// 		'type' => 'category',
		// 		'name' => 'featured',
		// 		'title' => 'Featured',
		// 		'content' => 'For the homepage featured area'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'city1',
		// 		'filename' => 'city1.jpg',
		// 		'title' => 'City 1 Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'city2',
		// 		'filename' => 'city2.jpg',
		// 		'title' => 'City 2 Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'town',
		// 		'filename' => 'town.jpg',
		// 		'title' => 'Town Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'gtlslider1',
		// 		'filename' => 'gtlslider1.jpg',
		// 		'title' => 'Macbook and Notepad Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Imac Macbook Ipad Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 94;
		// 		'type' => 'post',
		// 		'name' => 'tech-at-its-best',
		// 		'title' => 'Tech at Its Best',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'terms' => array (
		// 			array(
		// 				'slug' => 'featured',
		// 				'taxonomy' => 'category'
		// 			)
		// 		),
		// 		'thumbnail' => 'imacmacbookipad2',
		// 		'replace_term' => 'tech_at_its_best_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 41;
		// 		'type' => 'post',
		// 		'name' => 'what-an-adventure',
		// 		'title' => 'What an Adventure',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'terms' => array (
		// 			array(
		// 				'slug' => 'featured',
		// 				'taxonomy' => 'category'
		// 			)
		// 		),
		// 		'thumbnail' => 'town',
		// 		'replace_term' => 'what_an_adventure_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 35;
		// 		'type' => 'post',
		// 		'name' => 'a-great-new-thing',
		// 		'title' => 'A Great New Thing',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'thumbnail' => 'city1',
		// 		'replace_term' => 'a_great_new_thing_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 90;
		// 		'type' => 'post',
		// 		'name' => 'outside-the-box-thinking',
		// 		'title' => 'Outside the Box Thinking',
		// 		'content' => '<!-- wp:paragraph --><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis. Etiam hendrerit egestas lectus sed maximus. Donec id quam nec ante tempor tempus in id dui. Nullam ut egestas eros, nec vulputate neque. Nulla gravida elit posuere, rhoncus ipsum et, scelerisque tellus. Duis sit amet luctus magna. In tempus sapien quis dictum tristique.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin vitae urna nibh. Sed tincidunt vitae dui sit amet sagittis.',
		// 		'terms' => array (
		// 			array(
		// 				'slug' => 'featured',
		// 				'taxonomy' => 'category'
		// 			)
		// 		),
		// 		'thumbnail' => 'gtlslider1',
		// 		'replace_term' => 'outside_the_box_thinking_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 


		// // Pulito
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'city1',
		// 		'filename' => 'city1.jpg',
		// 		'title' => 'City 1 Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'city2',
		// 		'filename' => 'city2.jpg',
		// 		'title' => 'City 2 Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'town',
		// 		'filename' => 'town.jpg',
		// 		'title' => 'Town Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'gtlslider1',
		// 		'filename' => 'gtlslider1.jpg',
		// 		'title' => 'Macbook and Notepad Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'imacmacbookipad2',
		// 		'filename' => 'imacmacbookipad2.jpg',
		// 		'title' => 'Imac Macbook Ipad Image',
		// 		'content' => ''
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 





		// Charity Help Lite
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'jumping-silhouettes',
		// 		'filename' => 'jumping-silhouettes.jpg',
		// 		'title' => 'Jumping Silhouettes Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'plants',
		// 		'filename' => 'plants.jpg',
		// 		'title' => 'Plants Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 61;
		// 		'type' => 'page',
		// 		'name' => 'amazing-collaborations',
		// 		'title' => 'Amazing Collaborations',
		// 		'content' => '<!-- wp:paragraph --><p>This is the content text for the first image in your slider on your homepage.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'This is the content text for the first image in your slider on your homepage.',
		// 		'thumbnail' => 'jumping-silhouettes',
		// 		'replace_term' => 'slider_one_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 63;
		// 		'type' => 'page',
		// 		'name' => 'great-projects',
		// 		'title' => 'Great Projects',
		// 		'content' => '<!-- wp:paragraph --><p>This is the content text for the second image in your slider on your homepage.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'This is the content text for the second image in your slider on your homepage.',
		// 		'thumbnail' => 'plants',
		// 		'replace_term' => 'slider_two_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 



		// // Benevolent
		// $create_objects = array(
		// 	array(
		// 		'type' => 'category',
		// 		'name' => 'slider',
		// 		'title' => 'Slider',
		// 		'content' => 'For the homepage slider',
		//		'replace_term' => 'slider_cat',
		//		'replace_value' => 'category_id'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'jumping-silhouettes',
		// 		'filename' => 'jumping-silhouettes.jpg',
		// 		'title' => 'Jumping Silhouettes Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'plants',
		// 		'filename' => 'plants.jpg',
		// 		'title' => 'Plants Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'teamwork',
		// 		'filename' => 'teamwork.jpg',
		// 		'title' => 'Teamwork Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 51;
		// 		'type' => 'post',
		// 		'name' => 'do-some-good-today',
		// 		'title' => 'Do Some Good Today',
		// 		'content' => '<!-- wp:paragraph --><p>Check out some of the work we have done so far this year!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Check out some of the work we have done so far this year!',
		// 		'terms' => array (
		// 			array(
		// 				'slug' => 'slider',
		// 				'taxonomy' => 'category'
		// 			)
		// 		),
		// 		'thumbnail' => 'plants',
		// 		'replace_term' => 'do_some_good_today_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 55;
		// 		'type' => 'post',
		// 		'name' => 'check-out-some-of-our-work',
		// 		'title' => 'Check Out Some Of Our Work',
		// 		'content' => '<!-- wp:paragraph --><p>We have been broadening our reach, hoping to the be able to increase the number of people and regions we can help.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have been broadening our reach, hoping to the be able to increase the number of people and regions we can help.',
		// 		'terms' => array (
		// 			array(
		// 				'slug' => 'slider',
		// 				'taxonomy' => 'category'
		// 			)
		// 		),
		// 		'thumbnail' => 'jumping-silhouettes',
		// 		'replace_term' => 'check_out_some_of_our_work_slider_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 57;
		// 		'type' => 'post',
		// 		'name' => 'first-post',
		// 		'title' => 'First Post',
		// 		'content' => '<!-- wp:paragraph --><p>Welcome to WordPress. This is your first post. Edit or delete it, then start writing!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Welcome to WordPress. This is your first post. Edit or delete it, then start writing!',
		// 		'thumbnail' => 'teamwork',
		// 		'replace_term' => 'first_post_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 



		// // Vega
		// $create_objects = array(
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'jumping-silhouettes',
		// 		'filename' => 'jumping-silhouettes.jpg',
		// 		'title' => 'Jumping Silhouettes Image',
		// 		'content' => '',
		//		'replace_term' => 'jumping_silhouettes_image',
		//		'replace_value' => 'post_url'
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'plants',
		// 		'filename' => 'plants.jpg',
		// 		'title' => 'Plants Image',
		// 		'content' => ''
		// 	),
		// 	array(
		// 		'type' => 'attachment',
		// 		'name' => 'teamwork',
		// 		'filename' => 'teamwork.jpg',
		// 		'title' => 'Teamwork Image',
		// 		'content' => ''
		// 	),
		// 	array( //post id: 51;
		// 		'type' => 'post',
		// 		'name' => 'do-some-good-today',
		// 		'title' => 'Do Some Good Today',
		// 		'content' => '<!-- wp:paragraph --><p>Check out some of the work we have done so far this year!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Check out some of the work we have done so far this year!',
		// 		'thumbnail' => 'plants',
		// 		'replace_term' => 'do_some_good_today_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 55;
		// 		'type' => 'post',
		// 		'name' => 'check-out-some-of-our-work',
		// 		'title' => 'Check Out Some Of Our Work',
		// 		'content' => '<!-- wp:paragraph --><p>We have been broadening our reach, hoping to the be able to increase the number of people and regions we can help.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'We have been broadening our reach, hoping to the be able to increase the number of people and regions we can help.',
		// 		'thumbnail' => 'jumping-silhouettes',
		// 		'replace_term' => 'check_out_some_of_our_work_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 57;
		// 		'type' => 'post',
		// 		'name' => 'first-post',
		// 		'title' => 'First Post',
		// 		'content' => '<!-- wp:paragraph --><p>Welcome to WordPress. This is your first post. Edit or delete it, then start writing!</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Welcome to WordPress. This is your first post. Edit or delete it, then start writing!',
		// 		'thumbnail' => 'teamwork',
		// 		'replace_term' => 'first_post_post',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 102;
		// 		'type' => 'page',
		// 		'name' => 'first-call-to-action',
		// 		'title' => 'First call to action',
		// 		'content' => '<!-- wp:paragraph --><p>Get in touch with us using our contact form to find out how you can help us reach our goals.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Get in touch with us using our contact form to find out how you can help us reach our goals.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'call_to_action_one_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// 	array( //post id: 104;
		// 		'type' => 'page',
		// 		'name' => 'second-call-to-action',
		// 		'title' => 'Second call to action',
		// 		'content' => '<!-- wp:paragraph --><p>Get in touch with us using our contact form to find out how you can help us reach our goals.</p><!-- /wp:paragraph -->',
		// 		'excerpt' => 'Get in touch with us using our contact form to find out how you can help us reach our goals.',
		// 		'thumbnail' => '',
		// 		'replace_term' => 'call_to_action_two_page',
		// 		'replace_value' => 'post_id'
		// 	),
		// );
		// update_option("theme_objects_" . $theme_slug, $create_objects); 



		$create_objects = get_option("theme_objects_" . $theme_slug);
		if (!is_array($create_objects)) {$create_objects = array();}

		$theme_post_meta = get_option("theme_post_meta_" . $theme_slug);
		if (!is_array($theme_post_meta)) {$theme_post_meta = array();}

		foreach ($create_objects as $create_object) {
			if ($create_object['type'] == 'post') {
				$posts = get_posts(array('name' => $create_object['name']));
				if (!empty($posts)) {continue;}

				$post_id = wp_insert_post(array('post_name' => $create_object['name'], 'post_title' => $create_object['title'], 'post_content' => $create_object['content'], 'post_excerpt' => $create_object['excerpt'], 'post_status' => 'publish'));
			}
			elseif ($create_object['type'] == 'attachment') {
				require_once( ABSPATH . 'wp-admin/includes/image.php' );

				$upload_dir = wp_upload_dir();

				$filename = $upload_dir['basedir'] . '/initial_images/' . $create_object['filename'];
				$filetype = wp_check_filetype( basename( $filename ), null );

				$attachment = array(
					'post_name' => $create_object['name'], 
					'post_mime_type' => $filetype['type'],
					'post_title' => $create_object['title'],
					'post_content' => $create_object['content']
				);

				$attach_id = wp_insert_attachment( $attachment, $filename);

				$attach_data = wp_generate_attachment_metadata( $attach_id, $filename );
				wp_update_attachment_metadata( $attach_id, $attach_data );
			}
			elseif ($create_object['type'] == 'category') {
				$categories = get_terms(array('taxonomy' => 'category', 'name' => $create_object['name']));
				if (!empty($categories)) {continue;}

				$category = wp_insert_term($create_object['title'], 'category', array('slug' => $create_object['name'], 'description' => $create_object['content'], 'post_status' => 'publish'));
			}
			else {
				$posts = get_posts(array('name' => $create_object['name']));
				if (!empty($posts)) {continue;}

				$post_id = wp_insert_post(array('post_name' => $create_object['name'], 'post_title' => $create_object['title'], 'post_content' => $create_object['content'], 'post_excerpt' => $create_object['excerpt'], 'post_type' => $create_object['type'], 'post_status' => 'publish'));
			}

			if (isset($create_object['terms'])) {
				foreach ($create_object['terms'] as $create_term) {
					$term = get_term_by( 'slug', $create_term['slug'], $create_term['taxonomy'] );
					wp_set_post_terms( $post_id, (int) $term->term_id, $create_term['taxonomy'], true);
				}
			}

			if (isset($create_object['thumbnail'])) {
				$thumbnail = get_page_by_path( $create_object['thumbnail'], OBJECT, 'attachment' );
				
				if ($thumbnail) {set_post_thumbnail($post_id, $thumbnail->ID);}
			}

			if (isset($create_object['post_meta'])) {
				foreach ($create_object['post_meta'] as $post_meta) {
					update_post_meta( $post_id, $post_meta['meta_key'], $post_meta['meta_value'] );
				}
			}

			if (isset($create_object['post_parent'])) {
				$args = array('name' => $create_object['post_parent'], 'post_type' => 'any');
				$post_parent_array = get_posts($args);
				$post_parent = reset($post_parent_array);

				wp_update_post(array('ID' => $post_id, 'post_parent' => $post_parent->ID));
			}

			if (isset($create_object['replace_term'])) {
				$theme_mods = get_option("theme_mods_" . $theme_slug);

				if ($create_object['replace_value'] == 'attachment_id') {$replace_value = $attach_id;}
				if ($create_object['replace_value'] == 'post_id') {$replace_value = $post_id;}
				if ($create_object['replace_value'] == 'post_name') {$post_object = get_post($post_id); $replace_value = $post_object->post_name;}
				if ($create_object['replace_value'] == 'post_title') {$post_object =get_post($post_id); $replace_value = $post_object->post_title;}
				if ($create_object['replace_value'] == 'post_url') {$replace_value = ($create_object['type'] == 'attachment' ? wp_get_attachment_url($attach_id) : get_permalink($post_id));}
				if ($create_object['replace_value'] == 'category_id') {$replace_value = $category->term_id;}
				if ($create_object['replace_value'] == 'category_taxonomy_id') {$replace_value = $category->term_taxonomy_id;}
				if ($create_object['replace_value'] == 'category_slug') {$term = get_term($category->term_id, 'category'); $replace_value = $term->slug;}
				if ($create_object['replace_value'] == 'category_name') {$term = get_term($category->term_id, 'category'); $replace_value = $term->name;}
				
				// this is a really inefficient way of replacing, any way to target it better?
				if (is_array($theme_mods)) {
					foreach ($theme_mods as $key => $mod) {
						$updated_mod = str_replace($create_object['replace_term'], $replace_value, $mod);
						$theme_mods[$key] = $updated_mod;
					}
				}
				update_option("theme_mods_" . $theme_slug, $theme_mods);

				$pages = get_posts( array('post_type'=> 'page', 'posts_per_page' => -1) );
				foreach ($pages as $page) {
					$post_content = str_replace($create_object['replace_term'], $replace_value, $page->post_content);
					wp_update_post( array('ID' => $page->ID, 'post_content' => $post_content) );
				}

				foreach ($theme_post_meta as $key => $post_meta) {
					$theme_post_meta[$key]['meta_value'] = str_replace($create_object['replace_term'], $replace_value, $theme_post_meta[$key]['meta_value']);
				}
			}
		}
update_option('EWDQS_Debugging', $theme_post_meta);
		update_option("theme_post_meta_" . $theme_slug, $theme_post_meta);
	}

	function update_tasks() {
		$completed_tasks = get_option("ewdqs_completed_tasks");
		$completed_tasks[] = 'EWDQS_Theme_Selection';
		update_option("ewdqs_completed_tasks", $completed_tasks);
	}

	function check_color( $value ) { 
    	if ( preg_match( '/^#[a-f0-9]{6}$/i', $value ) ) { 
			return true;
    	}

		return false;
	}
}

function EWDQS_Theme_Selection_name() {
	return "Theme Setup";
}

function EWDQS_Theme_Selection_instructions() {
	return "Select your theme using the radio buttons below, and then use the color pickers to set the color palette for your site.";
}