<?php
/**
 * Class to handle the plugin and theme installations as well as initial SQL queries for EWD Quick Starter
 */

if ( !defined( 'ABSPATH' ) )
	exit;

if ( !class_exists( 'EWDQS_Background_Setup' ) ) {
class EWDQS_Background_Setup {

	public function __construct() {

		if ( ! $this->content_check() ) {
			if ( ! isset( $_POST['content_check_response'] ) ) { $this->display_content_warning(); die(); }
			elseif ( $_POST['content_check_response'] == 'Abort' ) { $this->deactivate_plugin(); }
		}

		delete_transient( 'ewdqs-do-initital-setup' );

		$this->install_images();
		$this->handle_SQL_Queries();

		file_get_contents( site_url( '?ewdqs_run_installation=true' ) );

		set_transient( 'ewdqs-getting-started', true, 60);

		wp_safe_redirect( admin_url() );
	}

	public function content_check() {

		$posts = get_posts( 'any' );

		if ( sizeOf( $posts) > 3 ) { return false; }

		return true;
	}

	public function display_content_warning() { ?>

		<div>
			<h4><?php _e( 'Warning'); ?></h4>
			<div><?php _e( 'It looks like you might have already added content to your site. Running the quick start process will remove or overwrite most of the content you have already added. Do you wish to continue?', 'ewd-quick-starter' ); ?></div>
			<form method='post'>
				<div>
					<input type='submit' name='content_check_response' value='Abort' />
					<input type='submit' name='content_check_response' value='Continue' />
				</div>
			</form>
		</div>
	<?php }

	public function deactivate_plugin() {

		require_once ABSPATH . 'wp-admin/includes/plugin.php';

		deactivate_plugins( 'ewd-quick-starter/Main.php' );

		header( 'Location: plugins.php?deactivate=true' );
	}

	public function install_images() {
		
		$uploads_dir = WP_CONTENT_DIR  . '/uploads/initial_images/';
		$initial_images_dir = EWDQS_DIR . 'initial_images/';

		mkdir( $uploads_dir );

		$files = scandir( $initial_images_dir );

		foreach ( $files as $file ) {
			if ( $file != "." && $file != ".." ) { copy( $initial_images_dir . $file, $uploads_dir . $file ); }
		}
	}

	public function handle_SQL_Queries() {
		global $wpdb;

		$values_array = array(
			'show_on_front' 							=> 'page',
			'page_on_front'								=> '2',
			'ewdqs_active_plugins'						=> 'a:8:{i:0;s:23:"order-tracking/Main.php";i:1;s:22:"ultimate-faqs/Main.php";i:2;s:25:"ultimate-reviews/Main.php";i:3;s:24:"ultimate-slider/Main.php";i:4;s:27:"woocommerce/woocommerce.php";i:5;s:24:"wpforms-lite/wpforms.php";i:6;s:26:"ewd-quick-starter/Main.php";i:7;s:49:"etoile-theme-companion/etoile-theme-companion.php";}',
			'active_plugins' 							=> 'a:8:{i:0;s:23:"order-tracking/Main.php";i:1;s:22:"ultimate-faqs/Main.php";i:2;s:25:"ultimate-reviews/Main.php";i:3;s:24:"ultimate-slider/Main.php";i:4;s:27:"woocommerce/woocommerce.php";i:5;s:24:"wpforms-lite/wpforms.php";i:6;s:26:"ewd-quick-starter/Main.php";i:7;s:49:"etoile-theme-companion/etoile-theme-companion.php";}',
			'template'	 								=> 'keep-calm-and-e-comm',
			'stylesheet'								=> 'keep-calm-and-e-comm',
			'widget_categories'							=> 'a:2:{i:2;a:4:{s:5:"title";s:0:"";s:5:"count";i:0;s:12:"hierarchical";i:0;s:8:"dropdown";i:0;}s:12:"_multiwidget";i:1;}',
			'fresh_site'								=> '1',
			'widget_search'								=> 'a:2:{i:2;a:1:{s:5:"title";s:0:"";}s:12:"_multiwidget";i:1;}',
			'widget_recent-posts'						=> 'a:2:{i:2;a:2:{s:5:"title";s:0:"";s:6:"number";i:5;}s:12:"_multiwidget";i:1;}',
			'widget_recent-comments'					=> 'a:2:{i:2;a:2:{s:5:"title";s:0:"";s:6:"number";i:5;}s:12:"_multiwidget";i:1;}',
			'widget_archives'							=> 'a:2:{i:2;a:3:{s:5:"title";s:0:"";s:5:"count";i:0;s:8:"dropdown";i:0;}s:12:"_multiwidget";i:1;}',
			'widget_meta'								=> 'a:2:{i:2;a:1:{s:5:"title";s:0:"";}s:12:"_multiwidget";i:1;}',
			'sidebars_widgets'							=> 'a:3:{s:19:"wp_inactive_widgets";a:0:{}s:9:"sidebar-1";a:6:{i:0;s:8:"search-2";i:1;s:14:"recent-posts-2";i:2;s:17:"recent-comments-2";i:3;s:10:"archives-2";i:4;s:12:"categories-2";i:5;s:6:"meta-2";}s:13:"array_version";i:3;}',
			'widget_pages'								=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_calendar'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_audio'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_image'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_gallery'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_video'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_tag_cloud'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_nav_menu'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_custom_html'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'ewdqs_tasks'								=> 'a:9:{i:0;s:17:"EWDQS_Basic_Setup";i:1;s:19:"EWDQS_Show_Overview";i:2;s:21:"EWDQS_Theme_Selection";i:3;s:17:"EWDQS_Pages_Setup";i:4;s:23:"EWDQS_WooCommerce_Setup";i:5;s:17:"EWDQS_OTP_Handler";i:6;s:18:"EWDQS_UFAQ_Handler";i:7;s:21:"EWDQS_WPForms_Handler";i:8;s:25:"EWDQS_Show_Optional_Steps";}',
			'ewdqs_completed_tasks'						=> 'a:0:{}',
			'ewdqs_pages'								=> 'a:4:{i:0;a:2:{s:9:"page_slug";s:26:"frequently-asked-questions";s:9:"deletable";b:0;}i:1;a:2:{s:9:"page_slug";s:8:"tracking";s:9:"deletable";b:0;}i:2;a:2:{s:9:"page_slug";s:10:"contact-us";s:9:"deletable";b:0;}i:3;a:2:{s:9:"page_slug";s:8:"about-us";s:9:"deletable";b:1;}}',
			'ewdqs_widgets'								=> 'a:0:{}',
			'ewdqs_intro_text'							=> 'With this package, you will create 4 beautifully looking pages, including FAQs, Tracking, Contact, and About (optional). The package uses WooCommerce - the web’s most popular ecommerce platform - as the backbone for your online store. This will provide you with limitless customization, and powerful search engine optimization to help with product placement on search networks such as Google, Bing, etc. With WooCommerce being a part of the package, you can sell anything online - from digital or physical goods to services, while allowing your customers to track statuses of their orders, access frequently asked questions, or get in touch with your team through a contact form.',
			'ewdqs_theme_options'						=> 'a:3:{i:0;a:3:{s:10:"theme_slug";s:20:"keep-calm-and-e-comm";s:10:"theme_name";s:20:"Keep Calm and E-Comm";s:20:"theme_screenshot_url";s:100:"https://i0.wp.com/themes.svn.wordpress.org/keep-calm-and-e-comm/1.16/screenshot.png?w=1142&strip=all";}i:1;a:3:{s:10:"theme_slug";s:9:"gutenshop";s:10:"theme_name";s:9:"Gutenshop";s:20:"theme_screenshot_url";s:88:"https://i0.wp.com/themes.svn.wordpress.org/gutenshop/2.7/screenshot.png?w=1142&strip=all";}i:2;a:3:{s:10:"theme_slug";s:13:"ecommerce-hub";s:10:"theme_name";s:13:"Ecommerce Hub";s:20:"theme_screenshot_url";s:92:"https://i0.wp.com/themes.svn.wordpress.org/ecommerce-hub/0.1/screenshot.png?w=1142&strip=all";}}',
			'current_theme'								=> '',
			'theme_mods_keep-calm-and-e-comm'			=> 'a:26:{i:0;b:0;s:18:"nav_menu_locations";a:2:{s:9:"main-menu";i:2;s:14:"logged-in-menu";i:0;}s:18:"custom_css_post_id";i:20;s:11:"custom_logo";i:30;s:16:"background_color";s:6:"ffffff";s:27:"ewd_kcae_setting_text_color";s:7:"#333333";s:16:"sidebars_widgets";a:2:{s:4:"time";i:1560278307;s:4:"data";a:4:{s:19:"wp_inactive_widgets";a:1:{i:0;s:32:"upcp_theme_testimonials_widget-4";}s:14:"sidebar_widget";a:2:{i:0;s:31:"ewd_ufaq_display_popular_faqs-2";i:1;s:32:"upcp_theme_testimonials_widget-2";}s:19:"sidebar_widget_blog";a:0:{}s:13:"footer_widget";a:0:{}}}s:39:"ewd_kcae_setting_tracking_page_url_text";s:30:"site_url_placeholder/tracking/";s:31:"ewd_kcae_setting_alternate_logo";s:72:"site_url_placeholder/wp-content/uploads/initial_images/ecommerce-logo-white.png";s:43:"ewd_kcae_setting_textonpic_background_image";s:76:"site_url_placeholder/wp-content/uploads/initial_images/northernlights2-1.jpg";s:40:"ewd_kcae_setting_textonpic_overlay_image";s:66:"site_url_placeholder/wp-content/uploads/initial_images/iphone3.png";s:39:"ewd_kcae_setting_textonpic_heading_text";s:16:"The Latest Tech!";s:42:"ewd_kcae_setting_textonpic_subheading_text";s:69:"All the newest gear from Apple, HP, Samsung, Huawei, Google and more!";s:38:"ewd_kcae_setting_textonpic_button_text";s:9:"Shop Tech";s:38:"ewd_kcae_setting_textonpic_button_link";s:1:"#";s:37:"ewd_kcae_setting_callout_heading_text";s:26:"All The Latest Smartphones";s:40:"ewd_kcae_setting_callout_subheading_text";s:92:"We carry the best and newest phones from brands like Apple, Samsung, Huawei, Nokia and more!";s:36:"ewd_kcae_setting_callout_button_text";s:11:"Shop Phones";s:36:"ewd_kcae_setting_callout_button_link";s:1:"#";s:39:"ewd_kcae_prem_setting_utility_nav_phone";s:14:"1-800-555-5555";s:39:"ewd_kcae_prem_setting_utility_nav_email";s:19:"contact@example.com";s:42:"ewd_kcae_prem_setting_utility_nav_facebook";s:1:"#";s:41:"ewd_kcae_prem_setting_utility_nav_twitter";s:1:"#";s:43:"ewd_kcae_prem_setting_utility_nav_instagram";s:1:"#";s:41:"ewd_kcae_prem_setting_utility_nav_youtube";s:1:"#";s:43:"ewd_kcae_prem_setting_utility_nav_pinterest";s:1:"#";}',
			'theme_plugins_keep-calm-and-e-comm'		=> 'a:2:{i:0;s:49:"etoile-theme-companion/etoile-theme-companion.php";i:1;s:24:"ultimate-slider/Main.php";}',
			'theme_objects_keep-calm-and-e-comm'		=> 'a:16:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"imacmacbookipad2";s:8:"filename";s:20:"imacmacbookipad2.jpg";s:5:"title";s:34:"Ultimate Slider iMac Macbook Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"macbookipadipone";s:8:"filename";s:20:"macbookipadipone.jpg";s:5:"title";s:28:"Ultimate Slider Macbook iPad";s:7:"content";s:0:"";}i:2;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:17:"northernlights2-1";s:8:"filename";s:21:"northernlights2-1.jpg";s:5:"title";s:17:"Text On Pic Image";s:7:"content";s:0:"";}i:3;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:7:"iphone3";s:8:"filename";s:11:"iphone3.png";s:5:"title";s:25:"Text On Pic Overlay Image";s:7:"content";s:0:"";}i:4;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:8:"bicycle2";s:8:"filename";s:12:"bicycle2.png";s:5:"title";s:21:"Bicycle Jump Box Icon";s:7:"content";s:0:"";}i:5;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:4:"bus2";s:8:"filename";s:8:"bus2.png";s:5:"title";s:17:"Bus Jump Box Icon";s:7:"content";s:0:"";}i:6;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:5:"taxi2";s:8:"filename";s:9:"taxi2.png";s:5:"title";s:18:"Taxi Jump Box Icon";s:7:"content";s:0:"";}i:7;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:20:"shop-smart-shop-easy";s:5:"title";s:22:"Shop Smart. Shop Easy.";s:7:"content";s:175:"<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->";s:7:"excerpt";s:125:"We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!";s:9:"thumbnail";s:16:"imacmacbookipad2";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:1;}}s:12:"replace_term";s:33:"imac_macbook_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}i:8;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:26:"great-prices-great-service";s:5:"title";s:28:"Great Prices. Great Service.";s:7:"content";s:147:"<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:97:"We pride ourselves on offering the most up-to-date stock at the best prices you will find online.";s:9:"thumbnail";s:16:"macbookipadipone";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:2;}}s:12:"replace_term";s:33:"macbook_ipad_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}i:9;a:8:{s:4:"type";s:20:"upcp_theme_jumpboxes";s:4:"name";s:19:"everything-you-need";s:5:"title";s:19:"Everything You Need";s:7:"content";s:169:"We have a very large selection of in-stock products. No waiting around or buying from multiple sources. We are your one-stop shop for smartphones, tablets and computers.";s:7:"excerpt";s:65:"We are your one-stop shop for smartphones, tablets and computers.";s:9:"thumbnail";s:8:"bicycle2";s:12:"replace_term";s:32:"everything_you_need_jumpbox_post";s:13:"replace_value";s:7:"post_id";}i:10;a:8:{s:4:"type";s:20:"upcp_theme_jumpboxes";s:4:"name";s:13:"great-service";s:5:"title";s:13:"Great Service";s:7:"content";s:184:"Our knowledgeable staff lives and breathes tech. We are always up to date on the latest technology and trends. So, if you are uncertain about what you need, be sure to ask our experts.";s:7:"excerpt";s:61:"We are always up to date on the latest technology and trends.";s:9:"thumbnail";s:4:"bus2";s:12:"replace_term";s:26:"great_service_jumpbox_post";s:13:"replace_value";s:7:"post_id";}i:11;a:8:{s:4:"type";s:20:"upcp_theme_jumpboxes";s:4:"name";s:11:"best-prices";s:5:"title";s:11:"Best Prices";s:7:"content";s:188:"We offer the best prices you will find online and will not be undersold. If you happen to find one of our items cheaper somewhere else, be sure to get in touch with us and we will beat it.";s:7:"excerpt";s:72:"We offer the best prices you will find online and will not be undersold.";s:9:"thumbnail";s:5:"taxi2";s:12:"replace_term";s:23:"best_price_jumpbox_post";s:13:"replace_value";s:7:"post_id";}i:12;a:8:{s:4:"type";s:20:"upcp_theme_jumpboxes";s:4:"name";s:23:"satisfaction-guaranteed";s:5:"title";s:23:"Satisfaction Guaranteed";s:7:"content";s:188:"We are sure it will not happen, but, if ever there was something about a specific product that did not live up to your expectations, make sure to get in touch and we will be happy to help.";s:7:"excerpt";s:107:"If there is something that did not live up to your expectations, get in touch and we will be happy to help.";s:9:"thumbnail";s:8:"bicycle2";s:12:"replace_term";s:23:"best_price_jumpbox_post";s:13:"replace_value";s:7:"post_id";}i:13;a:9:{s:4:"type";s:16:"upcp_theme_testi";s:4:"name";s:15:"testimonial-one";s:5:"title";s:15:"Testimonial One";s:7:"content";s:62:"Buying from Shop Site was a breeze. I will definitely be back!";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:0:"";s:9:"post_meta";a:2:{i:0;a:2:{s:8:"meta_key";s:16:"_testimonialName";s:10:"meta_value";s:17:"Michelle Falsetto";}i:1;a:2:{s:8:"meta_key";s:19:"_testimonialCompany";s:10:"meta_value";s:11:"Widgets ETC";}}s:12:"replace_term";s:20:"one_testimonial_post";s:13:"replace_value";s:7:"post_id";}i:14;a:9:{s:4:"type";s:16:"upcp_theme_testi";s:4:"name";s:15:"testimonial-two";s:5:"title";s:15:"Testimonial Two";s:7:"content";s:49:"Thank you for the great phone and quick shipping!";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:0:"";s:9:"post_meta";a:2:{i:0;a:2:{s:8:"meta_key";s:16:"_testimonialName";s:10:"meta_value";s:15:"Jane Q. Notreal";}i:1;a:2:{s:8:"meta_key";s:19:"_testimonialCompany";s:10:"meta_value";s:18:"Unreal Enterprises";}}s:12:"replace_term";s:20:"two_testimonial_post";s:13:"replace_value";s:7:"post_id";}i:15;a:9:{s:4:"type";s:16:"upcp_theme_testi";s:4:"name";s:17:"testimonial-three";s:5:"title";s:17:"Testimonial Three";s:7:"content";s:93:"Excellent customer service! They helped me pick out the perfect tablet for my small business.";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:0:"";s:9:"post_meta";a:2:{i:0;a:2:{s:8:"meta_key";s:16:"_testimonialName";s:10:"meta_value";s:12:"John Q. Fake";}i:1;a:2:{s:8:"meta_key";s:19:"_testimonialCompany";s:10:"meta_value";s:21:"The Fake Company Inc.";}}s:12:"replace_term";s:22:"three_testimonial_post";s:13:"replace_value";s:7:"post_id";}}',
			'theme_optional_keep-calm-and-e-comm'		=> 'a:10:{i:0;a:3:{s:4:"name";s:22:"Edit Homepage Sections";s:12:"instructions";s:69:"Enable and disable the different sections that appear on the homepage";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:17:"Homepage Sections";s:4:"type";s:3:"url";s:5:"value";s:72:"customize.php?autofocus[section]=ewd_kcae_prem_setting_homepage_sections";}}}i:1;a:3:{s:4:"name";s:20:"Edit Homepage Slides";s:12:"instructions";s:61:"Edit the two slides that are shown at the top of the homepage";s:5:"links";a:2:{i:0;a:3:{s:4:"text";s:9:"Slide One";s:4:"type";s:15:"ultimate_slider";s:5:"value";s:20:"shop-smart-shop-easy";}i:1;a:3:{s:4:"text";s:9:"Slide Two";s:4:"type";s:15:"ultimate_slider";s:5:"value";s:26:"great-prices-great-service";}}}i:2;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:3;a:3:{s:4:"name";s:21:"Create First Products";s:12:"instructions";s:221:"Create your first product(s) in WooCommerce. This will automatically populate your shop page as well as the featured products area on the homepage. If you do not complete this step at this time, those areas will be empty.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:15:"Create Products";s:4:"type";s:3:"url";s:5:"value";s:26:"edit.php?post_type=product";}}}i:4;a:3:{s:4:"name";s:24:"Choose Featured Products";s:12:"instructions";s:76:"Choose which products show in the featured products section on the homepage.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:15:"Choose Products";s:4:"type";s:3:"url";s:5:"value";s:58:"admin.php?page=EWD-UPCP-Theme-options&DisplayPage=Homepage";}}}i:5;a:3:{s:4:"name";s:41:"Set Contact Info &amp; Social Media Links";s:12:"instructions";s:122:"Add your phone number and email address, as well as links to your social media, to the utility nav (top bar) of your site.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:24:"Set Contact &amp; Social";s:4:"type";s:3:"url";s:5:"value";s:74:"customize.php?autofocus[section]=ewd_kcae_prem_setting_utility_nav_section";}}}i:6;a:3:{s:4:"name";s:15:"Edit Jump Boxes";s:12:"instructions";s:95:"These are the three informational boxes that show on the homepage, above the featured products.";s:5:"links";a:4:{i:0;a:3:{s:4:"text";s:7:"Box One";s:4:"type";s:20:"upcp_theme_jumpboxes";s:5:"value";s:19:"everything-you-need";}i:1;a:3:{s:4:"text";s:7:"Box Two";s:4:"type";s:20:"upcp_theme_jumpboxes";s:5:"value";s:13:"great-service";}i:2;a:3:{s:4:"text";s:9:"Box Three";s:4:"type";s:20:"upcp_theme_jumpboxes";s:5:"value";s:11:"best-prices";}i:3;a:3:{s:4:"text";s:8:"Box Four";s:4:"type";s:20:"upcp_theme_jumpboxes";s:5:"value";s:23:"satisfaction-guaranteed";}}}i:7;a:3:{s:4:"name";s:17:"Edit Testimonials";s:12:"instructions";s:59:"These are the three testimonials that show on the homepage.";s:5:"links";a:3:{i:0;a:3:{s:4:"text";s:15:"Testimonial One";s:4:"type";s:16:"upcp_theme_testi";s:5:"value";s:15:"testimonial-one";}i:1;a:3:{s:4:"text";s:15:"Testimonial Two";s:4:"type";s:16:"upcp_theme_testi";s:5:"value";s:15:"testimonial-two";}i:2;a:3:{s:4:"text";s:17:"Testimonial Three";s:4:"type";s:16:"upcp_theme_testi";s:5:"value";s:17:"testimonial-three";}}}i:8;a:3:{s:4:"name";s:21:"Edit Text on Pic Area";s:12:"instructions";s:74:"Change the picture and content of the text on picture area on the homepage";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:16:"Edit Text on Pic";s:4:"type";s:3:"url";s:5:"value";s:67:"customize.php?autofocus[section]=ewd_kcae_setting_textonpic_section";}}}i:9;a:3:{s:4:"name";s:17:"Edit Callout Area";s:12:"instructions";s:95:"Change the content of the callout promotional area that appears near the bottom of the homepage";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:12:"Edit Callout";s:4:"type";s:3:"url";s:5:"value";s:65:"customize.php?autofocus[section]=ewd_kcae_setting_callout_section";}}}}',
			'theme_post_meta_keep-calm-and-e-comm'		=> 'a:3:{i:0;a:3:{s:7:"post_id";i:5;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:20:"template-sidebar.php";}i:1;a:3:{s:7:"post_id";i:6;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:20:"template-sidebar.php";}i:2;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:17:"template-home.php";}}',
			'theme_css_selectors_keep-calm-and-e-comm'	=> 'a:1:{s:10:"foreground";s:764:"#utilityNav #utilitySocial a:hover .fa {color: $color;} #menu ul li a:hover {border-bottom: 1px solid $color !important;border-top: 1px solid $color !important;} #header input:hover {border-color: $color;background: $color;} .ewd-slider-icon:hover {color: $color;} .slideButtons li a:hover {background: $color !important;} .newButton.centerButton:hover {background: $color;} .newButton.whiteButton:hover {background: $color;} .panel.$colorPanel {background-color: $color;} .newButton:hover {background: $color !important;} .testimonials ul li .testimonialQuote {color: $color;} .calloutArea {background-color: $color;} .singlePage .titleArea {background-color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}";}',
			'theme_page_content_keep-calm-and-e-comm'	=> 'a:1:{i:0;a:2:{s:2:"ID";i:2;s:12:"post_content";s:254:"<!-- wp:paragraph --><p>Thanks for visiting our shop site. We have all the latest tech and the best prices and customer service in the industry. If you have any questions or need any help, please do not hesitate to get in touch.</p><!-- /wp:paragraph -->";}}',
			'theme_mods_gutenshop'						=> 'a:7:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:6:"menu-1";i:2;}s:18:"custom_css_post_id";i:21;s:16:"header_textcolor";s:5:"blank";s:11:"custom_logo";i:31;s:22:"fullwidth_productpages";s:1:"1";s:16:"sidebars_widgets";a:2:{s:4:"time";i:1560279409;s:4:"data";a:6:{s:19:"wp_inactive_widgets";a:1:{i:0;s:32:"upcp_theme_testimonials_widget-4";}s:9:"sidebar-1";a:2:{i:0;s:31:"ewd_ufaq_display_popular_faqs-2";i:1;s:32:"upcp_theme_testimonials_widget-2";}s:21:"woocommerce-sidebar-1";a:0:{}s:17:"footer-widget-one";a:0:{}s:17:"footer-widget-two";a:0:{}s:19:"footer-widget-three";a:0:{}}}}',
			'theme_plugins_gutenshop'					=> 'a:1:{i:0;s:24:"ultimate-slider/Main.php";}',
			'theme_objects_gutenshop'					=> 'a:7:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"imacmacbookipad2";s:8:"filename";s:20:"imacmacbookipad2.jpg";s:5:"title";s:34:"Ultimate Slider iMac Macbook Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"macbookipadipone";s:8:"filename";s:20:"macbookipadipone.jpg";s:5:"title";s:28:"Ultimate Slider Macbook iPad";s:7:"content";s:0:"";}i:2;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"nohiddenfees";s:8:"filename";s:16:"nohiddenfees.png";s:5:"title";s:28:"Gutenshop Jump Box Image One";s:7:"content";s:0:"";s:12:"replace_term";s:23:"nohiddenfees_attachment";s:13:"replace_value";s:8:"post_url";}i:3;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:15:"customerservice";s:8:"filename";s:19:"customerservice.png";s:5:"title";s:28:"Gutenshop Jump Box Image Two";s:7:"content";s:0:"";s:12:"replace_term";s:26:"customerservice_attachment";s:13:"replace_value";s:8:"post_url";}i:4;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"freeshipping";s:8:"filename";s:16:"freeshipping.png";s:5:"title";s:30:"Gutenshop Jump Box Image Three";s:7:"content";s:0:"";s:12:"replace_term";s:23:"freeshipping_attachment";s:13:"replace_value";s:8:"post_url";}i:5;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:20:"shop-smart-shop-easy";s:5:"title";s:22:"Shop Smart. Shop Easy.";s:7:"content";s:175:"<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->";s:7:"excerpt";s:125:"We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!";s:9:"thumbnail";s:16:"imacmacbookipad2";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:1;}}s:12:"replace_term";s:33:"imac_macbook_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}i:6;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:26:"great-prices-great-service";s:5:"title";s:28:"Great Prices. Great Service.";s:7:"content";s:147:"<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:97:"We pride ourselves on offering the most up-to-date stock at the best prices you will find online.";s:9:"thumbnail";s:16:"macbookipadipone";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:2;}}s:12:"replace_term";s:33:"macbook_ipad_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}}',
			'theme_optional_gutenshop'					=> 'a:4:{i:0;a:3:{s:4:"name";s:20:"Edit Homepage Slides";s:12:"instructions";s:61:"Edit the two slides that are shown at the top of the homepage";s:5:"links";a:2:{i:0;a:3:{s:4:"text";s:9:"Slide One";s:4:"type";s:15:"ultimate_slider";s:5:"value";s:20:"shop-smart-shop-easy";}i:1;a:3:{s:4:"text";s:9:"Slide Two";s:4:"type";s:15:"ultimate_slider";s:5:"value";s:26:"great-prices-great-service";}}}i:1;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:2;a:3:{s:4:"name";s:21:"Edit Homepage Content";s:12:"instructions";s:90:"Edit the content of your homepage, including the three informational boxes that show there";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:13:"Edit Homepage";s:4:"type";s:4:"page";s:5:"value";s:4:"home";}}}i:3;a:3:{s:4:"name";s:21:"Create First Products";s:12:"instructions";s:221:"Create your first product(s) in WooCommerce. This will automatically populate your shop page as well as the featured products area on the homepage. If you do not complete this step at this time, those areas will be empty.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:15:"Create Products";s:4:"type";s:3:"url";s:5:"value";s:26:"edit.php?post_type=product";}}}}',
			'theme_post_meta_gutenshop'					=> 'a:3:{i:0;a:3:{s:7:"post_id";i:4;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:28:"page-templates/fullwidth.php";}i:1;a:3:{s:7:"post_id";i:7;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:28:"page-templates/fullwidth.php";}i:2;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:31:"page-templates/landing-page.php";}}',
			'theme_css_selectors_gutenshop'				=> 'a:1:{s:10:"foreground";s:356:".ewd-slider-icon:hover {color: $color;} .slideButtons li a:hover {background: $color !important;} .upcp-minimal-title {color: $color;} .upcp-minimal-price {color: $color;} a {color:$color;} .site-info > a {color: $color;} .footer-info-right > a {color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}";}',
			'theme_page_content_gutenshop'				=> 'a:1:{i:0;a:2:{s:2:"ID";i:2;s:12:"post_content";s:2451:"<!-- wp:ultimate-slider/ewd-us-slider-block /--><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:woocommerce/product-new --><div class="wp-block-woocommerce-product-new">[products limit="3" columns="3" orderby="date" order="DESC"]</div><!-- /wp:woocommerce/product-new --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/freeshipping.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/customerservice.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/nohiddenfees.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns -->";}}',
			'theme_mods_ecommerce-hub'					=> 'a:16:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:7:"primary";i:2;}s:18:"custom_css_post_id";i:22;s:21:"ecommerce_hub_welcome";s:20:"Welcome to our shop!";s:26:"ecommerce_hub_slider_page1";s:31:"ecommerce_hub_second_slide_page";s:26:"ecommerce_hub_slider_page2";s:30:"ecommerce_hub_first_slide_page";s:24:"ecommerce_hub_page_title";s:0:"";s:26:"ecommerce_hub_feature_page";s:0:"";s:24:"ecommerce_hub_email_text";s:9:"Email Us!";s:19:"ecommerce_hub_email";s:19:"contact@example.com";s:23:"ecommerce_hub_call_text";s:12:"Get in Touch";s:25:"ecommerce_hub_call_number";s:12:"232-555-1312";s:18:"ecommerce_hub_text";s:26:"© 2019 éTOILE WEB DESIGN";s:25:"ecommerce_hub_slider_hide";s:1:"1";s:16:"sidebars_widgets";a:2:{s:4:"time";i:1560269340;s:4:"data";a:4:{s:19:"wp_inactive_widgets";a:1:{i:0;s:32:"upcp_theme_testimonials_widget-4";}s:14:"sidebar_widget";a:2:{i:0;s:31:"ewd_ufaq_display_popular_faqs-2";i:1;s:32:"upcp_theme_testimonials_widget-2";}s:19:"sidebar_widget_blog";a:0:{}s:13:"footer_widget";a:0:{}}}s:11:"custom_logo";i:32;}',
			'theme_plugins_ecommerce-hub'				=> 'a:0:{}',
			'theme_objects_ecommerce-hub'				=> 'a:7:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"imacmacbookipad2";s:8:"filename";s:20:"imacmacbookipad2.jpg";s:5:"title";s:34:"Ultimate Slider iMac Macbook Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:10:"gtlslider1";s:8:"filename";s:14:"gtlslider1.jpg";s:5:"title";s:28:"Ultimate Slider Macbook iPad";s:7:"content";s:0:"";}i:2;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"nohiddenfees";s:8:"filename";s:16:"nohiddenfees.png";s:5:"title";s:32:"Ecommerce Hub Jump Box Image One";s:7:"content";s:0:"";s:12:"replace_term";s:23:"nohiddenfees_attachment";s:13:"replace_value";s:8:"post_url";}i:3;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:15:"customerservice";s:8:"filename";s:19:"customerservice.png";s:5:"title";s:32:"Ecommerce Hub Jump Box Image Two";s:7:"content";s:0:"";s:12:"replace_term";s:26:"customerservice_attachment";s:13:"replace_value";s:8:"post_url";}i:4;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"freeshipping";s:8:"filename";s:16:"freeshipping.png";s:5:"title";s:34:"Ecommerce Hub Jump Box Image Three";s:7:"content";s:0:"";s:12:"replace_term";s:23:"freeshipping_attachment";s:13:"replace_value";s:8:"post_url";}i:5;a:8:{s:4:"type";s:4:"page";s:4:"name";s:26:"great-prices-great-service";s:5:"title";s:28:"Great Prices. Great Service.";s:7:"content";s:147:"<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:75:"We pride ourselves on offering the most up-to-date stock at the best prices";s:9:"thumbnail";s:10:"gtlslider1";s:12:"replace_term";s:30:"ecommerce_hub_first_slide_page";s:13:"replace_value";s:7:"post_id";}i:6;a:8:{s:4:"type";s:4:"page";s:4:"name";s:20:"shop-smart-shop-easy";s:5:"title";s:22:"Shop Smart. Shop Easy.";s:7:"content";s:175:"<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->";s:7:"excerpt";s:81:"We have all the latest electronics, including smartphones, tablets and computers.";s:9:"thumbnail";s:16:"imacmacbookipad2";s:12:"replace_term";s:31:"ecommerce_hub_second_slide_page";s:13:"replace_value";s:7:"post_id";}}',
			'theme_optional_ecommerce-hub'				=> 'a:5:{i:0;a:3:{s:4:"name";s:20:"Edit Homepage Slider";s:12:"instructions";s:59:"Choose what images and content show on the homepage slider.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:11:"Edit Slider";s:4:"type";s:3:"url";s:5:"value";s:61:"customize.php?autofocus[section]=ecommerce_hub_slider_section";}}}i:1;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:2;a:3:{s:4:"name";s:23:"Set Contact Information";s:12:"instructions";s:64:"Add your phone number and email address alongside your site menu";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:16:"Set Contact Info";s:4:"type";s:3:"url";s:5:"value";s:58:"customize.php?autofocus[section]=ecommerce_hub_topbar_icon";}}}i:3;a:3:{s:4:"name";s:21:"Edit Homepage Content";s:12:"instructions";s:90:"Edit the content of your homepage, including the three informational boxes that show there";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:13:"Edit Homepage";s:4:"type";s:4:"page";s:5:"value";s:4:"home";}}}i:4;a:3:{s:4:"name";s:21:"Create First Products";s:12:"instructions";s:221:"Create your first product(s) in WooCommerce. This will automatically populate your shop page as well as the featured products area on the homepage. If you do not complete this step at this time, those areas will be empty.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:15:"Create Products";s:4:"type";s:3:"url";s:5:"value";s:26:"edit.php?post_type=product";}}}}',
			'theme_post_meta_ecommerce-hub'				=> 'a:3:{i:0;a:3:{s:7:"post_id";i:5;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:41:"page-template/page-with-right-sidebar.php";}i:1;a:3:{s:7:"post_id";i:6;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:41:"page-template/page-with-right-sidebar.php";}i:2;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:35:"page-template/custom-front-page.php";}}',
			'theme_css_selectors_ecommerce-hub'			=> 'a:1:{s:10:"foreground";s:371:".social-icon {background: $color;} #header .nav ul li a:hover {color: $color;} .contact-details i {color: $color;} .more-btn a:hover {background: #41d5cf;} .inner {background: $color;} h1.page-title, h1.search-title {background: $color;} .title-box {background-color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}";}',
			'theme_page_content_ecommerce-hub'			=> 'a:1:{i:0;a:2:{s:2:"ID";i:2;s:12:"post_content";s:2403:"<!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:woocommerce/product-new --><div class="wp-block-woocommerce-product-new">[products limit="3" columns="3" orderby="date" order="DESC"]</div><!-- /wp:woocommerce/product-new --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/freeshipping.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/customerservice.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="http://www.ewdyoutubetutorials.com/ecommerce-site/wp-content/uploads/2019/05/nohiddenfees.png" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns -->";}}',
			'EWD_KCAE_Homepage_Sections'				=> 'a:9:{i:0;a:2:{s:4:"Name";s:6:"Slider";s:7:"Display";s:3:"Yes";}i:1;a:2:{s:4:"Name";s:12:"Static Slide";s:7:"Display";s:2:"No";}i:2;a:2:{s:4:"Name";s:10:"Jump Boxes";s:7:"Display";s:3:"Yes";}i:3;a:2:{s:4:"Name";s:13:"Tracking Area";s:7:"Display";s:3:"Yes";}i:4;a:2:{s:4:"Name";s:12:"Main Content";s:7:"Display";s:3:"Yes";}i:5;a:2:{s:4:"Name";s:17:"Featured Products";s:7:"Display";s:3:"Yes";}i:6;a:2:{s:4:"Name";s:15:"Text on Picture";s:7:"Display";s:3:"Yes";}i:7;a:2:{s:4:"Name";s:12:"Testimonials";s:7:"Display";s:3:"Yes";}i:8;a:2:{s:4:"Name";s:12:"Callout Area";s:7:"Display";s:3:"Yes";}}'
		);

		foreach ( $values_array as $option_name => $option_value ) {
			$option = get_option( $option_name, 'Not Found' );

			if ( $option == 'Not Found' ) { $wpdb->query( "INSERT INTO $wpdb->options ( option_name, option_value ) VALUES ('" . $option_name . "','" . $option_value ."')" );  }
			else { $wpdb->query( "UPDATE $wpdb->options SET option_value = '" . $option_value . "' WHERE option_name='" . $option_name . "'" ); }
		}

		$values_array = array(
			array(
			 	'meta_id'	=> 2,
			 	'post_id'	=> 30,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/ecommerce-logo-white.png'
			),
			array(
			 	'meta_id'	=> 3,
			 	'post_id'	=> 30,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:1047;s:6:"height";i:146;s:4:"file";s:32:"initial_images/ecommerce-logo-white.png";s:5:"sizes";a:10:{s:9:"thumbnail";a:4:{s:4:"file";s:32:"ecommerce-logo-white-150x146.png";s:5:"width";i:150;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:6:"medium";a:4:{s:4:"file";s:31:"ecommerce-logo-white-300x42.png";s:5:"width";i:300;s:6:"height";i:42;s:9:"mime-type";s:9:"image/png";}s:12:"medium_large";a:4:{s:4:"file";s:32:"ecommerce-logo-white-768x107.png";s:5:"width";i:768;s:6:"height";i:107;s:9:"mime-type";s:9:"image/png";}s:5:"large";a:4:{s:4:"file";s:33:"ecommerce-logo-white-1024x143.png";s:5:"width";i:1024;s:6:"height";i:143;s:9:"mime-type";s:9:"image/png";}s:21:"woocommerce_thumbnail";a:5:{s:4:"file";s:32:"ecommerce-logo-white-300x146.png";s:5:"width";i:300;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";s:9:"uncropped";b:0;}s:18:"woocommerce_single";a:4:{s:4:"file";s:31:"ecommerce-logo-white-600x84.png";s:5:"width";i:600;s:6:"height";i:84;s:9:"mime-type";s:9:"image/png";}s:29:"woocommerce_gallery_thumbnail";a:4:{s:4:"file";s:32:"ecommerce-logo-white-100x100.png";s:5:"width";i:100;s:6:"height";i:100;s:9:"mime-type";s:9:"image/png";}s:12:"shop_catalog";a:4:{s:4:"file";s:32:"ecommerce-logo-white-300x146.png";s:5:"width";i:300;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:11:"shop_single";a:4:{s:4:"file";s:31:"ecommerce-logo-white-600x84.png";s:5:"width";i:600;s:6:"height";i:84;s:9:"mime-type";s:9:"image/png";}s:14:"shop_thumbnail";a:4:{s:4:"file";s:32:"ecommerce-logo-white-100x100.png";s:5:"width";i:100;s:6:"height";i:100;s:9:"mime-type";s:9:"image/png";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 4,
			 	'post_id'	=> 31,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/ecommerce-logo-black2.png'
			),
			array(
			 	'meta_id'	=> 5,
			 	'post_id'	=> 31,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:1047;s:6:"height";i:146;s:4:"file";s:33:"initial_images/ecommerce-logo-black2.png";s:5:"sizes";a:11:{s:9:"thumbnail";a:4:{s:4:"file";s:33:"ecommerce-logo-black2-150x146.png";s:5:"width";i:150;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:6:"medium";a:4:{s:4:"file";s:32:"ecommerce-logo-black2-300x42.png";s:5:"width";i:300;s:6:"height";i:42;s:9:"mime-type";s:9:"image/png";}s:12:"medium_large";a:4:{s:4:"file";s:33:"ecommerce-logo-black2-768x107.png";s:5:"width";i:768;s:6:"height";i:107;s:9:"mime-type";s:9:"image/png";}s:5:"large";a:4:{s:4:"file";s:34:"ecommerce-logo-black2-1024x143.png";s:5:"width";i:1024;s:6:"height";i:143;s:9:"mime-type";s:9:"image/png";}s:17:"gutenshop-related";a:4:{s:4:"file";s:33:"ecommerce-logo-black2-200x125.png";s:5:"width";i:200;s:6:"height";i:125;s:9:"mime-type";s:9:"image/png";}s:21:"woocommerce_thumbnail";a:5:{s:4:"file";s:33:"ecommerce-logo-black2-300x146.png";s:5:"width";i:300;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";s:9:"uncropped";b:0;}s:18:"woocommerce_single";a:4:{s:4:"file";s:32:"ecommerce-logo-black2-600x84.png";s:5:"width";i:600;s:6:"height";i:84;s:9:"mime-type";s:9:"image/png";}s:29:"woocommerce_gallery_thumbnail";a:4:{s:4:"file";s:33:"ecommerce-logo-black2-100x100.png";s:5:"width";i:100;s:6:"height";i:100;s:9:"mime-type";s:9:"image/png";}s:12:"shop_catalog";a:4:{s:4:"file";s:33:"ecommerce-logo-black2-300x146.png";s:5:"width";i:300;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:11:"shop_single";a:4:{s:4:"file";s:32:"ecommerce-logo-black2-600x84.png";s:5:"width";i:600;s:6:"height";i:84;s:9:"mime-type";s:9:"image/png";}s:14:"shop_thumbnail";a:4:{s:4:"file";s:33:"ecommerce-logo-black2-100x100.png";s:5:"width";i:100;s:6:"height";i:100;s:9:"mime-type";s:9:"image/png";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 6,
			 	'post_id'	=> 32,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/cropped-ecommerce-logo-turquoise.png'
			),
			array(
			 	'meta_id'	=> 7,
			 	'post_id'	=> 32,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:240;s:6:"height";i:33;s:4:"file";s:44:"initial_images/cropped-ecommerce-logo-turquoise.png";s:5:"sizes";a:4:{s:9:"thumbnail";a:4:{s:4:"file";s:43:"cropped-ecommerce-logo-turquoise-150x33.png";s:5:"width";i:150;s:6:"height";i:33;s:9:"mime-type";s:9:"image/png";}s:28:"ecommerce-hub-homepage-thumb";a:4:{s:4:"file";s:43:"cropped-ecommerce-logo-turquoise-240x33.png";s:5:"width";i:240;s:6:"height";i:33;s:9:"mime-type";s:9:"image/png";}s:29:"woocommerce_gallery_thumbnail";a:4:{s:4:"file";s:43:"cropped-ecommerce-logo-turquoise-100x33.png";s:5:"width";i:100;s:6:"height";i:33;s:9:"mime-type";s:9:"image/png";}s:14:"shop_thumbnail";a:4:{s:4:"file";s:43:"cropped-ecommerce-logo-turquoise-100x33.png";s:5:"width";i:100;s:6:"height";i:33;s:9:"mime-type";s:9:"image/png";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}'
			),
			array(
					'meta_id'	=> 180,
					'post_id'	=> 10,
					'meta_key'	=> '_menu_item_type',
					'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 181,
				'post_id'	=> 10,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 182,
				'post_id'	=> 10,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '6'
			),
			array(
				'meta_id'	=> 183,
				'post_id'	=> 10,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 184,
				'post_id'	=> 10,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 185,
				'post_id'	=> 10,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 186,
				'post_id'	=> 10,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 187,
				'post_id'	=> 10,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 189,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 190,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 191,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '5'
			),
			array(
				'meta_id'	=> 192,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 193,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 194,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 195,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 196,
				'post_id'	=> 11,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 198,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 199,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 200,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '4'
			),
			array(
				'meta_id'	=> 201,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 202,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 203,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 204,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 205,
				'post_id'	=> 12,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 207,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 208,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 209,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '3'
			),
			array(
				'meta_id'	=> 210,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 211,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 212,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 213,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 214,
				'post_id'	=> 13,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 216,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 217,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 218,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '7'
			),
			array(
				'meta_id'	=> 219,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 220,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 221,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 222,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 223,
				'post_id'	=> 14,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 224,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 225,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 226,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '2'
			),
			array(
				'meta_id'	=> 227,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 228,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 229,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 230,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 231,
				'post_id'	=> 15,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			)
		);

		$wpdb->query( "TRUNCATE TABLE $wpdb->postmeta" );
		foreach ( $values_array as $value ) {
			$wpdb->query( "INSERT INTO $wpdb->postmeta ( meta_id, post_id, meta_key, meta_value ) VALUES ('" . $value['meta_id'] . "','" . $value['post_id'] ."','" . $value['meta_key'] ."','" . $value['meta_value'] ."')" );
		}

		$values_array = array(
			array(
				'ID' 			=> 1,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:heading --><h2>Who we are</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Our website address is: [[softurl]].</p><!-- /wp:paragraph --><!-- wp:heading --><h2>What personal data we collect and why we collect it</h2><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Comments</h3><!-- /wp:heading --><!-- wp:paragraph --><p>When visitors leave comments on the site we collect the data shown in the comments form, and also the visitor&#8217;s IP address and browser user agent string to help spam detection.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>An anonymized string created from your email address (also called a hash) may be provided to the Gravatar service to see if you are using it. The Gravatar service privacy policy is available here: https://automattic.com/privacy/. After approval of your comment, your profile picture is visible to the public in the context of your comment.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Media</h3><!-- /wp:heading --><!-- wp:paragraph --><p>If you upload images to the website, you should avoid uploading images with embedded location data (EXIF GPS) included. Visitors to the website can download and extract any location data from images on the website.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Contact forms</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Cookies</h3><!-- /wp:heading --><!-- wp:paragraph --><p>If you leave a comment on our site you may opt-in to saving your name, email address and website in cookies. These are for your convenience so that you do not have to fill in your details again when you leave another comment. These cookies will last for one year.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>If you have an account and you log in to this site, we will set a temporary cookie to determine if your browser accepts cookies. This cookie contains no personal data and is discarded when you close your browser.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>When you log in, we will also set up several cookies to save your login information and your screen display choices. Login cookies last for two days, and screen options cookies last for a year. If you select &quot;Remember Me&quot;, your login will persist for two weeks. If you log out of your account, the login cookies will be removed.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>If you edit or publish an article, an additional cookie will be saved in your browser. This cookie includes no personal data and simply indicates the post ID of the article you just edited. It expires after 1 day.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Embedded content from other websites</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Articles on this site may include embedded content (e.g. videos, images, articles, etc.). Embedded content from other websites behaves in the exact same way as if the visitor has visited the other website.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>These websites may collect data about you, use cookies, embed additional third-party tracking, and monitor your interaction with that embedded content, including tracking your interaction with the embedded content if you have an account and are logged in to that website.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Analytics</h3><!-- /wp:heading --><!-- wp:heading --><h2>Who we share your data with</h2><!-- /wp:heading --><!-- wp:heading --><h2>How long we retain your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>If you leave a comment, the comment and its metadata are retained indefinitely. This is so we can recognize and approve any follow-up comments automatically instead of holding them in a moderation queue.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>For users that register on our website (if any), we also store the personal information they provide in their user profile. All users can see, edit, or delete their personal information at any time (except they cannot change their username). Website administrators can also see and edit that information.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>What rights you have over your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>If you have an account on this site, or have left comments, you can request to receive an exported file of the personal data we hold about you, including any data you have provided to us. You can also request that we erase any personal data we hold about you. This does not include any data we are obliged to keep for administrative, legal, or security purposes.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>Where we send your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Visitor comments may be checked through an automated spam detection service.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>Your contact information</h2><!-- /wp:heading --><!-- wp:heading --><h2>Additional information</h2><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>How we protect your data</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What data breach procedures we have in place</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What third parties we receive data from</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What automated decision making and/or profiling we do with user data</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Industry regulatory disclosure requirements</h3><!-- /wp:heading -->',
				'post_title'	=> 'Privacy Policy',
				'post_excerpt'	=> '',
				'post_status'	=> 'draft',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'privacy-policy',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=1',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 2,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Welcome to our shop site!</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Home',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'home',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=2',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 3,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p></p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Shop',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'shop',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=3',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 4,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Shop Information:<br/>[ultimate-faqs]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Frequently Asked Questions',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'frequently-asked-questions',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=4',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 5,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Talk about what makes your shop unique, things like your values, your staff or your product offering on this page.</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'About Us',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'about-us',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=5',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 6,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Please use the form below to get in touch with us:[contact_form]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Contact Us',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'contact-us',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=6',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 7,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Please use the form below to track your order:[tracking-form]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Tracking',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'tracking',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=7',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 10,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '10',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=10',
				'menu_order'	=> 6,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 11,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '11',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=11',
				'menu_order'	=> 5,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 12,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '12',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=12',
				'menu_order'	=> 4,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 13,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '13',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=13',
				'menu_order'	=> 3,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 14,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '14',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=14',
				'menu_order'	=> 2,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 15,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '15',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=15',
				'menu_order'	=> 1,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 20,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '/*faq page*/\n.ufaq-faq-category-title {\n  margin-bottom: 20px\n}\n.ufaq-faq-category-title h3 {\n font-size: 20px;\n  letter-spacing: 0;\n}\n.ufaq-faq-title-text h4 {\n  text-transform: initial;\n  letter-spacing: 0;\n}\n.ewd-ufaq-post-margin-symbol {\n margin-top: 5px;\n}\n.ufaq-faq-title {\n  padding: 1px\n}\n.ufaq-faq-post {\n margin: 0 0 20px;\n line-height: 1.5;\n}\n.ewd-ufaq-author-date {\n margin-bottom: 13px;\n}\n.ewd-ufaq-date {\nfont-weight: normal;\n}\n.ufaq-faq-categories {\nfont-weight: bold;\n}\n.ufaq-faq-categories a {\nfont-weight: normal;\n}\n.ufaq-back-to-top-link {\nfont-size: 13px;\ntext-transform: uppercase;\nfont-weight: bold;\n}\n.ufaq-permalink-image {\nmargin-top: -22px;\nmargin-left: 82px;\n}\n\n/*contact us page*/\ndiv.wpforms-container-full .wpforms-form input.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form .wpforms-field-row.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 100%;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n background-color: #037751;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\n background-color: #34AC85;\n  border: none;\n}\n\n/*faq widget*/\n.widgetBox .ufaq-faq-title-text {\n width: 80%;\n}\n.widgetBox .ufaq-faq-display-style-Contemporary .ewd-ufaq-post-margin-symbol {\n  margin-top: 4px;\n}\n.widgetBox .ufaq-faq-category-title {\n  display: none;\n}\n.widgetBox .ufaq-faq-category,\n.widgetBox .ufaq-faq-category-inner {\n  margin-bottom: 0\n}\n',
				'post_title'	=> 'keep-calm-and-e-comm',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'keep-calm-and-e-comm',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=20',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 21,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '/*general*/\np {\n  color: #888;\n}\n\n@media print, screen and (min-width: 64em) {\n.grid-x > .large-3 {\n    width: 20%;\n}\n}\n\n@media print, screen and (min-width: 64em){\n.page-id-45 .grid-x > .large-8 {\n    width: 100%;\n}\n}\n\n/*homepage*/\n.home #page.grid-container {\n max-width: none;\n}\n.home .footer-container #page {\n  max-width: 75rem;\n}\n.ewd-slider-section {\n width: calc(100% + 80px);\n margin-left: -40px;\n margin-top: -50px;\n}\n.slideExcerpt p {\n  color: #fff;\n  margin-bottom: 45px;\n}\n\n.home .wp-block-woocommerce-product-category,\n.home .wp-block-woocommerce-handpicked-products {\n max-width: 95%;\n margin: 40px 2.5% 0;\n  padding: 40px 40px 10px;    \n}\n\n.home .wp-block-columns {\n  max-width: 95%;\n margin: 40px 2.5% 50px;\n border-top: 1px solid #ddd;\n padding: 40px 40px 10px;\n  text-align: center;\n}\n.home .wp-block-columns .wp-block-image img {\n max-width: 120px;\n}\n.home h2.newsmartphoneshomeheading {\n  padding-bottom: 15px;;\n}\n.home p.newsmartphoneshome {\n max-width: 50%;\n margin: 0 25% 20px;\n}\n\n\n/*faq page*/\n.ufaq-faq-category-title {\n  margin-bottom: 20px\n}\n.ufaq-faq-category-title h3 {\n font-size: 20px;\n  letter-spacing: 0;\n}\n.ufaq-faq-title-text h4 {\n  text-transform: initial;\n  letter-spacing: 0;\n}\n.ewd-ufaq-post-margin-symbol {\n margin-top: 9px;\n}\n.ewd-ufaq-post-margin-symbol span {\n  font-family: "ewd-toggle-icon";\n}\n.ufaq-faq-title {\n padding: 1px\n}\n.ufaq-faq-post {\n margin: 0 0 0px;\n  line-height: 1.5;\n}\n.ewd-ufaq-author-date {\n margin-bottom: 13px;\n}\n.ewd-ufaq-date {\nfont-weight: normal;\n}\n.ufaq-faq-categories {\nfont-weight: bold;\n}\n.ufaq-faq-categories a {\nfont-weight: normal;\n}\n.ufaq-back-to-top-link {\nfont-size: 13px;\ntext-transform: uppercase;\nfont-weight: bold;\n}\n.ufaq-permalink-image {\nmargin-top: -28px;\nmargin-left: 90px;\n}\n\n\n/*contact us page*/\ndiv.wpforms-container-full .wpforms-form input.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form .wpforms-field-row.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 100%;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n background-color: #34ADCF;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\n background-color: #6BCEEA;\n  border: none;\n}\n\n\n/*product page*/\n.upcp-product-page button[type=submit] {\n  background-color: #34ADCF !important;\n padding: 14px 32px !important;\n  color: #fff !important;\n border: none !important;\n  cursor: pointer !important;\n}\n.upcp-product-page button[type=submit]:hover {\n  background-color: #6BCEEA !important;\n border: none !important;\n}\n\n\n/*faq widget*/\n.widget .ufaq-faq-div {\n  margin: 0;\n}\n.widget .ufaq-faq-title-text {\n width: 80%;\n}\n.widget .ewd-ufaq-post-margin-symbol {\n  margin-top: 6px;\n}\n.widget .ufaq-faq-category-title {\n display: none;\n}\n.widget .ufaq-faq-category,\n.widget .ufaq-faq-category-inner {\n  margin-bottom: 0\n}\n.widget .ufaq-faq-title-text h4 {\n  border: none !important;\n}\n\n\n/*testimonial widget*/\n.widget .testimonialQuote {\n  display: none;\n}',
				'post_title'	=> 'gutenshop',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'gutenshop',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=21',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 22,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '/*general*/\np {\n  color: #888;\n}\n.logo {\n  margin-top: 1.2em;\n}\n.welcome p {\n color: #fff;\n}\n\n/*homepage*/\n.home .wp-block-woocommerce-product-category,\n.home .wp-block-woocommerce-handpicked-products {\n max-width: 95%;\n margin: 40px 2.5% 0;\n  padding: 40px 40px 10px;    \n}\n\n.home .wp-block-columns {\n  max-width: 95%;\n margin: 40px 2.5% 50px;\n border-top: 1px solid #ddd;\n padding: 40px 40px 10px;\n  text-align: center;\n}\n.home .wp-block-columns .wp-block-image img {\n max-width: 120px;\n}\n.home h2.newsmartphoneshomeheading {\n  padding-bottom: 15px;;\n}\n.home p.newsmartphoneshome {\n max-width: 50%;\n margin: 0 25% 20px;\n}\n\n\n/*shop pages*/\nbody.woocommerce-page .col-lg-8 {\nwidth: 100% !important;\nmax-width: none !important;\nflex: initial !important;\n}\nbody.woocommerce-page .col-lg-4 {\ndisplay: none !important;\n}\n\n.woocommerce ul.products li.product a.woocommerce-loop-product__link {\n  width: 100%;\n}\n\n@media screen and (min-width: 1200px){\n .woocommerce ul.products li.product .button {\n   margin-top: -16%\n  }\n}\n\n/*faq page*/\n.ufaq-faq-category-title {\n  margin-bottom: 20px\n}\n.ufaq-faq-category-title h3 {\n font-size: 20px;\n  letter-spacing: 0;\n}\n.ufaq-faq-title-text h4 {\n  text-transform: initial;\n  letter-spacing: 0;\n}\n.ewd-ufaq-post-margin-symbol {\n margin-top: 9px;\n}\n.ewd-ufaq-post-margin-symbol span {\n  font-family: "ewd-toggle-icon";\n}\n.ufaq-faq-title {\n padding: 1px\n}\n.ufaq-faq-post {\n margin: 0 0 0px;\n  line-height: 1.5;\n}\n.ewd-ufaq-author-date {\n margin-bottom: 13px;\n}\n.ewd-ufaq-date {\nfont-weight: normal;\n}\n.ufaq-faq-categories {\nfont-weight: bold;\n}\n.ufaq-faq-categories a {\nfont-weight: normal;\n}\n.ufaq-back-to-top-link {\nfont-size: 13px;\ntext-transform: uppercase;\nfont-weight: bold;\n}\n.ufaq-permalink-image {\nmargin-top: -28px;\nmargin-left: 90px;\n}\n\n\n/*contact us page*/\ndiv.wpforms-container-full .wpforms-form input.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form .wpforms-field-row.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 100%;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n background-color: #34ADCF;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\n background-color: #6BCEEA;\n  border: none;\n}\n\n\n/*faq widget*/\n.widget .ufaq-faq-div {\n margin: 0;\n}\n.widget .ufaq-faq-title-text {\n width: 80%;\n}\n.widget .ewd-ufaq-post-margin-symbol {\n  margin-top: 6px;\n}\n.widget .ufaq-faq-category-title {\n display: none;\n}\n.widget .ufaq-faq-category,\n.widget .ufaq-faq-category-inner {\n  margin-bottom: 0\n}\n.widget .ufaq-faq-title-text h4 {\n  border: none !important;\n}\n\n\n/*testimonial widget*/\n.widget .testimonialQuote {\n  display: none;\n}',
				'post_title'	=> 'ecommerce-hub',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'ecommerce-hub',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=22',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 30,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/ecommerce-logo-white.png',
				'post_title'	=> 'ecommerce-logo-white',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'ecommerce-logo-white',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/ecommerce-logo-white.png',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 31,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/ecommerce-logo-black2.png',
				'post_title'	=> 'ecommerce-logo-black2',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'ecommerce-logo-black2',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/ecommerce-logo-black2.png',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 32,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/cropped-ecommerce-logo-turquoise.png',
				'post_title'	=> 'cropped-ecommerce-logo-turquoise',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'cropped-ecommerce-logo-turquoise',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/cropped-ecommerce-logo-turquoise.png',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			)
		);

 		$wpdb->query( "TRUNCATE TABLE $wpdb->posts" );
 		foreach ( $values_array as $value ) {
			$wpdb->query( "INSERT INTO $wpdb->posts ( ID, post_author, post_date, post_date_gmt, post_content, post_title, post_excerpt, post_status, comment_status, ping_status, post_password, post_name, to_ping, pinged, post_modified, post_modified_gmt, post_content_filtered, post_parent, guid, menu_order, post_type, post_mime_type, comment_count) VALUES ('" . $value['ID'] . "','" . $value['post_author'] ."','" . $value['post_date'] ."','" . $value['post_date_gmt'] ."','" . $value['post_content'] ."','" . $value['post_title'] ."','" . $value['post_excerpt'] ."','" . $value['post_status'] ."','" . $value['comment_status'] ."','" . $value['ping_status'] ."','" . $value['post_password'] ."','" . $value['post_name'] ."','" . $value['to_ping'] ."','" . $value['pinged'] ."','" . $value['post_modified'] ."','" . $value['post_modified_gmt'] ."','" . $value['post_content_filtered'] ."','" . $value['post_parent'] ."','" . $value['guid'] ."','" . $value['menu_order'] ."','" . $value['post_type'] ."','" . $value['post_mime_type'] ."','" . $value['comment_count'] ."')" );
		}

		/* if ( function_exists( 'wp_get_original_image_path' ) ) {
			$fullsizepath = wp_get_original_image_path( 30 );
		} else {
			$fullsizepath = get_attached_file( 30 );
		}

		wp_generate_attachment_metadata( 30, $fullsizepath ) */

		$wpdb->query( "TRUNCATE TABLE $wpdb->terms" );
		$wpdb->query( "INSERT INTO $wpdb->terms ( term_id, name, slug, term_group ) VALUES ('1','Uncategorized','uncategorized','0')" );
		$wpdb->query( "INSERT INTO $wpdb->terms ( term_id, name, slug, term_group ) VALUES ('2','Main Menu','main-menu','0')" );

		$wpdb->query( "TRUNCATE TABLE $wpdb->term_taxonomy" );
		$wpdb->query( "INSERT INTO $wpdb->term_taxonomy ( term_taxonomy_id, term_id, taxonomy, parent, count ) VALUES ('1','1','category','0','1')" );
		$wpdb->query( "INSERT INTO $wpdb->term_taxonomy ( term_taxonomy_id, term_id, taxonomy, parent, count ) VALUES ('2','2','nav_menu','0','7')" );

		$wpdb->query( "TRUNCATE TABLE $wpdb->term_relationships" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('1','1','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('10','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('11','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('12','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('13','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('14','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('15','2','0')" );
	}
}
}

?>