<?php
/**
 * Class to handle the plugin and theme installations as well as initial SQL queries for EWD Quick Starter
 */

if ( !defined( 'ABSPATH' ) )
	exit;

if ( !class_exists( 'EWDQS_Background_Setup' ) ) {
class EWDQS_Background_Setup {

	public function __construct() {

		if ( ! $this->content_check() ) {
			if ( ! isset( $_POST['content_check_response'] ) ) { $this->display_content_warning(); die(); }
			elseif ( $_POST['content_check_response'] == 'Abort' ) { $this->deactivate_plugin(); }
		}

		delete_transient( 'ewdqs-do-initital-setup' );

		$this->install_images();
		$this->handle_SQL_Queries();

		file_get_contents( site_url( '?ewdqs_run_installation=true' ) );

		set_transient( 'ewdqs-getting-started', true, 60);

		wp_safe_redirect( admin_url() );
	}

	public function content_check() {

		$posts = get_posts( 'any' );

		if ( sizeOf( $posts) > 3 ) { return false; }

		return true;
	}

	public function display_content_warning() { ?>

		<div>
			<h4><?php _e( 'Warning'); ?></h4>
			<div><?php _e( 'It looks like you might have already added content to your site. Running the quick start process will remove or overwrite most of the content you have already added. Do you wish to continue?', 'ewd-quick-starter' ); ?></div>
			<form method='post'>
				<div>
					<input type='submit' name='content_check_response' value='Abort' />
					<input type='submit' name='content_check_response' value='Continue' />
				</div>
			</form>
		</div>
	<?php }

	public function deactivate_plugin() {

		require_once ABSPATH . 'wp-admin/includes/plugin.php';

		deactivate_plugins( 'ewd-quick-starter/Main.php' );

		header( 'Location: plugins.php?deactivate=true' );
	}

	public function install_images() {
		
		$uploads_dir = WP_CONTENT_DIR  . '/uploads/initial_images/';
		$initial_images_dir = EWDQS_DIR . 'initial_images/';

		mkdir( $uploads_dir );

		$files = scandir( $initial_images_dir );

		foreach ( $files as $file ) {
			if ( $file != "." && $file != ".." ) { copy( $initial_images_dir . $file, $uploads_dir . $file ); }
		}
	}

	public function handle_SQL_Queries() {
		global $wpdb;

		$values_array = array(
			'show_on_front' 							=> 'page',
			'page_on_front'								=> '2',
			'ewdqs_active_plugins'						=> 'a:6:{i:0;s:51:"essential-content-types/essential-content-types.php";i:1;s:43:"food-and-drink-menu/food-and-drink-menu.php";i:2;s:51:"restaurant-reservations/restaurant-reservations.php";i:3;s:22:"ultimate-faqs/Main.php";i:4;s:24:"wpforms-lite/wpforms.php";i:5;s:26:"ewd-quick-starter/Main.php";}',
			'active_plugins' 							=> 'a:6:{i:0;s:51:"essential-content-types/essential-content-types.php";i:1;s:43:"food-and-drink-menu/food-and-drink-menu.php";i:2;s:51:"restaurant-reservations/restaurant-reservations.php";i:3;s:22:"ultimate-faqs/Main.php";i:4;s:24:"wpforms-lite/wpforms.php";i:5;s:26:"ewd-quick-starter/Main.php";}',
			'template'	 								=> 'bakes-and-cakes',
			'stylesheet'								=> 'bakes-and-cakes',
			'widget_categories'							=> 'a:2:{i:2;a:4:{s:5:"title";s:0:"";s:5:"count";i:0;s:12:"hierarchical";i:0;s:8:"dropdown";i:0;}s:12:"_multiwidget";i:1;}',
			'fresh_site'								=> '1',
			'widget_search'								=> 'a:2:{i:2;a:1:{s:5:"title";s:0:"";}s:12:"_multiwidget";i:1;}',
			'widget_recent-posts'						=> 'a:2:{i:2;a:2:{s:5:"title";s:0:"";s:6:"number";i:5;}s:12:"_multiwidget";i:1;}',
			'widget_recent-comments'					=> 'a:2:{i:2;a:2:{s:5:"title";s:0:"";s:6:"number";i:5;}s:12:"_multiwidget";i:1;}',
			'widget_archives'							=> 'a:2:{i:2;a:3:{s:5:"title";s:0:"";s:5:"count";i:0;s:8:"dropdown";i:0;}s:12:"_multiwidget";i:1;}',
			'widget_meta'								=> 'a:2:{i:2;a:1:{s:5:"title";s:0:"";}s:12:"_multiwidget";i:1;}',
			'sidebars_widgets'							=> 'a:3:{s:19:"wp_inactive_widgets";a:0:{}s:9:"sidebar-1";a:6:{i:0;s:8:"search-2";i:1;s:14:"recent-posts-2";i:2;s:17:"recent-comments-2";i:3;s:10:"archives-2";i:4;s:12:"categories-2";i:5;s:6:"meta-2";}s:13:"array_version";i:3;}',
			'widget_pages'								=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_calendar'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_audio'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_image'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_gallery'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_video'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_tag_cloud'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_nav_menu'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_custom_html'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'ewdqs_tasks'								=> 'a:9:{i:0;s:17:"EWDQS_Basic_Setup";i:1;s:19:"EWDQS_Show_Overview";i:2;s:21:"EWDQS_Theme_Selection";i:3;s:17:"EWDQS_Pages_Setup";i:4;s:29:"EWDQS_Restaurant_Menu_Handler";i:5;s:37:"EWDQS_Restaurant_Reservations_Handler";i:6;s:18:"EWDQS_UFAQ_Handler";i:7;s:21:"EWDQS_WPForms_Handler";i:8;s:25:"EWDQS_Show_Optional_Steps";}',
			'ewdqs_completed_tasks'						=> 'a:0:{}',
			'ewdqs_pages'								=> 'a:6:{i:0;a:2:{s:9:"page_slug";s:4:"menu";s:9:"deletable";b:0;}i:1;a:2:{s:9:"page_slug";s:12:"reservations";s:9:"deletable";b:0;}i:2;a:2:{s:9:"page_slug";s:26:"frequently-asked-questions";s:9:"deletable";b:0;}i:3;a:2:{s:9:"page_slug";s:10:"contact-us";s:9:"deletable";b:0;}i:4;a:2:{s:9:"page_slug";s:6:"events";s:9:"deletable";b:1;}i:5;a:2:{s:9:"page_slug";s:8:"about-us";s:9:"deletable";b:1;}}',
			'ewdqs_widgets'								=> 'a:0:{}',
			'ewdqs_intro_text'							=> 'With this package, you will create Menu, Reservation, Contact and FAQ pages. Our Menu and Reservation pages were recently updated with new features, allowing you to take online orders without a third-party, or restrict the maximum number of guests who can make a reservation at your restaurant at the same time. These features will help restaurant owners to continue to provide excellent services to customers while complying with the regional regulations on post-pandemic social distancing in public spaces.',
			'ewdqs_theme_options'						=> 'a:3:{i:0;a:3:{s:10:"theme_slug";s:15:"bakes-and-cakes";s:10:"theme_name";s:15:"Bakes and Cakes";s:20:"theme_screenshot_url";s:96:"https://i0.wp.com/themes.svn.wordpress.org/bakes-and-cakes/1.1.6/screenshot.png?w=1142&strip=all";}i:1;a:3:{s:10:"theme_slug";s:15:"catch-foodmania";s:10:"theme_name";s:15:"Catch Foodmania";s:20:"theme_screenshot_url";s:67:"https://themes.svn.wordpress.org/catch-foodmania/2.0/screenshot.png";}i:2;a:3:{s:10:"theme_slug";s:11:"recipe-lite";s:10:"theme_name";s:11:"Recipe Lite";s:20:"theme_screenshot_url";s:63:"https://themes.svn.wordpress.org/recipe-lite/1.1/screenshot.png";}}',
			'current_theme'								=> 'Bakes And Cakes',
			'theme_mods_bakes-and-cakes'				=> 'a:38:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:7:"primary";i:2;}s:18:"custom_css_post_id";i:20;s:11:"custom_logo";i:30;s:16:"background_color";s:6:"eeeeee";s:32:"bakes_and_cakes_ed_about_section";b:0;s:29:"bakes_and_cakes_about_us_page";s:1:"7";s:39:"bakes_and_cakes_ed_testimonials_section";b:0;s:40:"bakes_and_cakes_testimonials_section_cat";s:1:"9";s:32:"bakes_and_cakes_testimonial_page";s:1:"8";s:16:"sidebars_widgets";a:2:{s:4:"time";i:1557165118;s:4:"data";a:6:{s:19:"wp_inactive_widgets";a:4:{i:0;s:10:"archives-2";i:1;s:6:"meta-2";i:2;s:12:"categories-2";i:3;s:17:"recent-comments-2";}s:13:"right-sidebar";a:3:{i:0;s:8:"search-2";i:1;s:30:"ewd_ufaq_display_recent_faqs-3";i:2;s:14:"recent-posts-2";}s:10:"google-map";a:0:{}s:12:"footer-first";a:0:{}s:13:"footer-second";a:0:{}s:12:"footer-third";a:0:{}}}s:38:"bakes_and_cakes_ed_promotional_section";b:1;s:32:"bakes_and_cakes_promotional_page";s:1:"4";s:40:"bakes_and_cakes_promotional_block_button";s:11:"Reserve Now";s:45:"bakes_and_cakes_promotional_block_button_link";s:34:"site_url_placeholder/reservations/";s:34:"bakes_and_cakes_ed_product_section";b:1;s:37:"bakes_and_cakes_featured_product_page";s:1:"7";s:33:"bakes_and_cakes_ed_events_section";b:1;s:36:"bakes_and_cakes_events_section_title";s:17:"What´s Happening";s:32:"bakes_and_cakes_first_event_post";s:14:"event_one_post";s:33:"bakes_and_cakes_second_event_post";s:14:"event_two_post";s:43:"bakes_and_cakes_ed_make_reservation_section";b:0;s:45:"bakes_and_cakes_events_make_reservation_title";s:11:"Reserve now";s:32:"bakes_and_cakes_ed_staff_section";b:0;s:26:"bakes_and_cakes_staff_page";s:1:"4";s:33:"bakes_and_cakes_staff_section_cat";s:0:"";s:38:"bakes_and_cakes_staff_background_image";s:88:"site_url_placeholder/wp-content/uploads/initial_images/samuel-foster-412328-unsplash.jpg";s:31:"bakes_and_cakes_ed_blog_section";b:0;s:25:"bakes_and_cakes_blog_page";s:1:"5";s:44:"bakes_and_cakes_promotional_background_image";s:88:"site_url_placeholder/wp-content/uploads/initial_images/samuel-foster-412328-unsplash.jpg";s:41:"bakes_and_cakes_events_reservation_button";s:2:"ff";s:46:"bakes_and_cakes_events_reservation_button_link";s:1:"#";s:11:"header_text";i:0;s:25:"bakes_and_cakes_ed_slider";b:1;s:26:"bakes_and_cakes_slider_cat";s:15:"slider_category";s:30:"bakes_and_cakes_slider_control";b:0;s:30:"bakes_and_cakes_slider_caption";b:1;s:31:"bakes_and_cakes_animation_speed";i:1000;}',
			'widget_bakes_and_cakes_recent_post'		=> 'a:1:{s:12:\"_multiwidget\";i:1;}',
			'widget_bakes_and_cakes_popular_post'		=> 'a:1:{s:12:\"_multiwidget\";i:1;}',
			'widget_bakes_and_cakes_social_links'		=> 'a:1:{s:12:\"_multiwidget\";i:1;}',
			'theme_plugins_bakes-and-cakes'				=> 'a:0:{}',
			'theme_objects_bakes-and-cakes'				=> 'a:7:{i:0;a:4:{s:4:"type";s:8:"category";s:4:"name";s:6:"slider";s:5:"title";s:6:"Slider";s:7:"content";s:23:"For the homepage slider";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:11:"restaurant4";s:8:"filename";s:15:"restaurant4.jpg";s:5:"title";s:23:"Slider Restaurant Image";s:7:"content";s:0:"";}i:2;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:21:"abendbrot-939435_1920";s:8:"filename";s:25:"abendbrot-939435_1920.jpg";s:5:"title";s:18:"Slider Table Image";s:7:"content";s:0:"";}i:3;a:9:{s:4:"type";s:4:"post";s:4:"name";s:28:"an-amazing-dining-experience";s:5:"title";s:29:"An Amazing Dining Experience!";s:7:"content";s:171:"<!-- wp:paragraph --><p>Our handmade dishes will take you on a culinary adventure. Come join us for a dining experience you will not soon forget.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:58:"Our handmade dishes will take you on a culinary adventure.";s:5:"terms";a:1:{i:0;a:2:{s:4:"slug";s:6:"slider";s:8:"taxonomy";s:8:"category";}}s:9:"thumbnail";s:11:"restaurant4";s:12:"replace_term";s:33:"an_amazing_dining_experience_post";s:13:"replace_value";s:7:"post_id";}i:4;a:9:{s:4:"type";s:4:"post";s:4:"name";s:24:"great-food-great-service";s:5:"title";s:26:"Great Food! Great Service!";s:7:"content";s:146:"<!-- wp:paragraph --><p>When you are here, you are family! Come feel right at home with our tasty menu and warm service.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:96:"When you are here, you are family! Come feel right at home with our tasty menu and warm service.";s:5:"terms";a:1:{i:0;a:2:{s:4:"slug";s:6:"slider";s:8:"taxonomy";s:8:"category";}}s:9:"thumbnail";s:21:"abendbrot-939435_1920";s:12:"replace_term";s:29:"great_food_great_service_post";s:13:"replace_value";s:7:"post_id";}i:5;a:7:{s:4:"type";s:4:"post";s:4:"name";s:9:"event-one";s:5:"title";s:9:"Event One";s:7:"content";s:78:"<!-- wp:paragraph --><p>Description of weekly event.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:18:"Event One Schedule";s:12:"replace_term";s:14:"event_one_post";s:13:"replace_value";s:7:"post_id";}i:6;a:8:{s:4:"type";s:4:"post";s:4:"name";s:9:"event-two";s:5:"title";s:9:"Event Two";s:7:"content";s:78:"<!-- wp:paragraph --><p>Description of weekly event.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:18:"Event Two Schedule";s:13:"category_name";s:0:"";s:12:"replace_term";s:14:"event_two_post";s:13:"replace_value";s:7:"post_id";}}',
			'theme_optional_bakes-and-cakes'			=> 'a:3:{i:0;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:1;a:3:{s:4:"name";s:25:"Set Your Recurring Events";s:12:"instructions";s:207:"These two posts are displayed on your homepage. You can use them to let visitors know about daily events like a happy hour, or something our of the ordinary that happens at your restaurant like a yoga class.";s:5:"links";a:2:{i:0;a:3:{s:4:"text";s:9:"Event One";s:4:"type";s:4:"post";s:5:"value";s:9:"event-one";}i:1;a:3:{s:4:"text";s:9:"Event Two";s:4:"type";s:4:"post";s:5:"value";s:9:"event-two";}}}i:2;a:3:{s:4:"name";s:29:"Edit Homepage Slider Settings";s:12:"instructions";s:74:"Change the settings for the slider that shows at the top of your homepage.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:11:"Edit Slider";s:4:"type";s:3:"url";s:5:"value";s:64:"customize.php?autofocus[section]=bakes_and_cakes_slider_settings";}}}}',
			'theme_post_meta_bakes-and-cakes'			=> 'a:1:{i:0;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:17:"template-home.php";}}',
			'theme_css_selectors_bakes-and-cakes'		=> 'a:1:{s:10:"foreground";s:895:"/* Site navigation border line */.main-navigation {border-top: 1px solid $color;}/* Site navigation */.main-navigation .current_page_item > a, .main-navigation .current-menu-item > a, .main-navigation .current_page_ancestor > a, .main-navigation .current-menu-ancestor > a, .main-navigation a:hover,.main-navigation a:focus{color: $color;}/* Featured color */.featured {background: $color;} .special .header .main-title {color: $color;}.promotional-block .btn-join:hover {background: $color;}.btn-top:hover {color: $color;}/* Menu .erm_product_price .price {color: $color;}*/.rtb-booking-form button:hover {background-color: $color;}/* FAQ +/- symbol */.ewd-ufaq-post-margin-symbol {color: $color !important;}div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}/* Overall changes: *//* make anchor text color as the foreground color */a {color: $color;}";}',
			'theme_page_content_bakes-and-cakes'		=> 'a:0:{}',
			'theme_mods_catch-foodmania'				=> 'a:32:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:6:"menu-1";i:2;}s:18:"custom_css_post_id";i:21;s:30:"catch_foodmania_default_layout";s:21:"no-sidebar-full-width";s:35:"catch_foodmania_front_page_category";s:1:"0";s:29:"catch_foodmania_slider_option";s:8:"homepage";s:29:"catch_foodmania_slider_number";i:2;s:29:"catch_foodmania_slider_page_1";s:33:"an_amazing_dining_experience_page";s:35:"catch_foodmania_header_media_option";s:22:"exclude-home-page-post";s:29:"catch_foodmania_slider_page_2";s:29:"great_food_great_service_page";s:33:"catch_foodmania_excerpt_more_text";s:9:"View More";s:39:"catch_foodmania_featured_content_option";s:8:"homepage";s:38:"catch_foodmania_featured_content_cpt_1";s:32:"happy_hour_featured_content_post";s:30:"catch_foodmania_service_option";s:8:"disabled";s:29:"catch_foodmania_service_cpt_1";i:330;s:29:"catch_foodmania_service_cpt_2";i:331;s:29:"catch_foodmania_service_cpt_3";i:332;s:29:"catch_foodmania_service_cpt_4";i:333;s:34:"catch_foodmania_service_main_image";s:69:"site_url_placeholder/wp-content/uploads/initial_images/services-1.png";s:39:"catch_foodmania_featured_content_number";i:3;s:38:"catch_foodmania_featured_content_cpt_2";s:37:"weekly_specials_featured_content_post";s:38:"catch_foodmania_featured_content_cpt_3";s:35:"private_event_featured_content_post";s:34:"catch_foodmania_testimonial_option";s:8:"homepage";s:34:"catch_foodmania_testimonial_number";i:2;s:33:"catch_foodmania_testimonial_cpt_1";s:22:"first_testimonial_post";s:33:"catch_foodmania_testimonial_cpt_2";s:23:"second_testimonial_post";s:20:"jetpack_testimonials";a:2:{s:12:"page-content";s:28:"<p>What You Have to Say!</p>";s:14:"featured-image";i:137;}s:39:"catch_foodmania_hero_content_visibility";s:8:"homepage";s:28:"catch_foodmania_hero_content";i:7;s:37:"catch_foodmania_hero_content_subtitle";s:9:"Our Story";s:30:"catch_foodmania_excerpt_length";i:10;s:16:"sidebars_widgets";a:2:{s:4:"time";i:1557431215;s:4:"data";a:5:{s:19:"wp_inactive_widgets";a:4:{i:0;s:10:"archives-2";i:1;s:6:"meta-2";i:2;s:12:"categories-2";i:3;s:17:"recent-comments-2";}s:9:"sidebar-1";a:3:{i:0;s:8:"search-2";i:1;s:30:"ewd_ufaq_display_recent_faqs-3";i:2;s:14:"recent-posts-2";}s:9:"sidebar-2";a:0:{}s:9:"sidebar-3";a:0:{}s:9:"sidebar-4";a:0:{}}}}',
			'theme_plugins_catch-foodmania'				=> 'a:1:{i:0;s:51:"essential-content-types/essential-content-types.php";}',
			'theme_objects_catch-foodmania'				=> 'a:14:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:11:"restaurant4";s:8:"filename";s:15:"restaurant4.jpg";s:5:"title";s:23:"Slider Restaurant Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:21:"abendbrot-939435_1920";s:8:"filename";s:25:"abendbrot-939435_1920.jpg";s:5:"title";s:18:"Slider Table Image";s:7:"content";s:0:"";}i:2;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:15:"reservations_fc";s:8:"filename";s:19:"reservations_fc.jpg";s:5:"title";s:37:"Private Events Featured Content Image";s:7:"content";s:0:"";}i:3;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:8:"table_fc";s:8:"filename";s:12:"table_fc.jpg";s:5:"title";s:38:"Weekly Specials Featured Content Image";s:7:"content";s:0:"";}i:4;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"cheersing_fc";s:8:"filename";s:16:"cheersing_fc.jpg";s:5:"title";s:33:"Happy Hour Featured Content Image";s:7:"content";s:0:"";}i:5;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:17:"bowl-1932375_1280";s:8:"filename";s:21:"bowl-1932375_1280.jpg";s:5:"title";s:23:"First Testimonial Image";s:7:"content";s:0:"";}i:6;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:18:"pizza-3303388_1280";s:8:"filename";s:22:"pizza-3303388_1280.jpg";s:5:"title";s:24:"Second Testimonial Image";s:7:"content";s:0:"";}i:7;a:8:{s:4:"type";s:4:"page";s:4:"name";s:28:"an-amazing-dining-experience";s:5:"title";s:29:"An Amazing Dining Experience!";s:7:"content";s:171:"<!-- wp:paragraph --><p>Our handmade dishes will take you on a culinary adventure. Come join us for a dining experience you will not soon forget.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:58:"Our handmade dishes will take you on a culinary adventure!";s:9:"thumbnail";s:11:"restaurant4";s:12:"replace_term";s:33:"an_amazing_dining_experience_page";s:13:"replace_value";s:7:"post_id";}i:8;a:8:{s:4:"type";s:4:"page";s:4:"name";s:24:"great-food-great-service";s:5:"title";s:26:"Great Food! Great Service!";s:7:"content";s:146:"<!-- wp:paragraph --><p>When you are here, you are family! Come feel right at home with our tasty menu and warm service.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:96:"When you are here, you are family! Come feel right at home with our tasty menu and warm service.";s:9:"thumbnail";s:21:"abendbrot-939435_1920";s:12:"replace_term";s:29:"great_food_great_service_page";s:13:"replace_value";s:7:"post_id";}i:9;a:8:{s:4:"type";s:20:"ect_featured_content";s:4:"name";s:14:"private-events";s:5:"title";s:14:"Private Events";s:7:"content";s:111:"<!-- wp:paragraph --><p>Our restaurant offers the perfect setting to host your event.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:61:"Our restaurant offers the perfect setting to host your event.";s:9:"thumbnail";s:15:"reservations_fc";s:12:"replace_term";s:35:"private_event_featured_content_post";s:13:"replace_value";s:7:"post_id";}i:10;a:8:{s:4:"type";s:20:"ect_featured_content";s:4:"name";s:15:"weekly-specials";s:5:"title";s:15:"Weekly Specials";s:7:"content";s:120:"<!-- wp:paragraph --><p>Including dinner specials on Wednesdays and wine tasting on Thursdays.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:70:"Including dinner specials on Wednesdays and wine tasting on Thursdays.";s:9:"thumbnail";s:8:"table_fc";s:12:"replace_term";s:37:"weekly_specials_featured_content_post";s:13:"replace_value";s:7:"post_id";}i:11;a:8:{s:4:"type";s:20:"ect_featured_content";s:4:"name";s:10:"happy-hour";s:5:"title";s:10:"Happy Hour";s:7:"content";s:92:"<!-- wp:paragraph --><p>Between 4pm and 6pm, enjoy 2 for 1 drinks.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:42:"Between 4pm and 6pm, enjoy 2 for 1 drinks.";s:9:"thumbnail";s:12:"cheersing_fc";s:12:"replace_term";s:32:"happy_hour_featured_content_post";s:13:"replace_value";s:7:"post_id";}i:12;a:8:{s:4:"type";s:19:"jetpack-testimonial";s:4:"name";s:15:"giovanna-arturi";s:5:"title";s:15:"Giovanna Arturi";s:7:"content";s:158:"<!-- wp:paragraph --><p>The best restaurant experience I have had in years! The food was great and the service was above and beyond.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:17:"bowl-1932375_1280";s:12:"replace_term";s:22:"first_testimonial_post";s:13:"replace_value";s:7:"post_id";}i:13;a:8:{s:4:"type";s:19:"jetpack-testimonial";s:4:"name";s:11:"james-blake";s:5:"title";s:11:"James Blake";s:7:"content";s:240:"<!-- wp:paragraph --><p>I had a super experience at this restaurant. The food was great, the service was outstanding, and they even brought me a complementary glass of bubbly when they found out it was my birthday!</p><!-- /wp:paragraph -->";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:18:"pizza-3303388_1280";s:12:"replace_term";s:23:"second_testimonial_post";s:13:"replace_value";s:7:"post_id";}}',
			'theme_optional_catch-foodmania'			=> 'a:3:{i:0;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:1;a:3:{s:4:"name";s:17:"Edit Testimonials";s:12:"instructions";s:115:"These two testimonial posts are displayed on your homepage. Edit them with actual testimonials from your customers.";s:5:"links";a:2:{i:0;a:3:{s:4:"text";s:15:"Testimonial One";s:4:"type";s:19:"jetpack-testimonial";s:5:"value";s:15:"giovanna-arturi";}i:1;a:3:{s:4:"text";s:15:"Testimonial Two";s:4:"type";s:19:"jetpack-testimonial";s:5:"value";s:11:"james-blake";}}}i:2;a:3:{s:4:"name";s:29:"Edit Homepage Slider Settings";s:12:"instructions";s:74:"Change the settings for the slider that shows at the top of your homepage.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:11:"Edit Slider";s:4:"type";s:3:"url";s:5:"value";s:64:"customize.php?autofocus[section]=catch_foodmania_featured_slider";}}}}',
			'theme_post_meta_catch-foodmania'			=> 'a:0:{}',
			'theme_css_selectors_catch-foodmania'		=> 'a:1:{s:10:"foreground";s:1021:"/* Site navigation */.sticky-nav.navigation-classic.absolute-header .main-navigation a,.sticky-nav.navigation-classic.absolute-header .main-navigation .current-menu-item > a,.sticky-nav.absolute-header .site-title a,.sticky-nav.absolute-header #social-search-toggle {  color: $color;}/* scroll to top button*/#scrollup { background-color: $color;}/* \"Request Booking\" button */.rtb-booking-form button {  background-color: $color;}/* FAQ +/- symbol */.ewd-ufaq-post-margin-symbol {  color: $color !important;}/* contact form button */div.wpforms-container-full .wpforms-form button[type=submit] { background-color: $color;}/* make anchor text color as the foreground color */a { color: $color;}/* homepage section headings */.featured-content-section h2,.hero-content-wrapper h2,.testimonials-content-wrapper h2 {  color: $color;}/*border around testimonial images*/.cycle-pager-active {  color: $color;}/*read more buttons*/.more-button a {  background-color: $color;}/*footer*/.site-footer {  background-color: $color;}";}',
			'theme_page_content_catch-foodmania'		=> 'a:0:{}',
			'theme_mods_recipe-lite'					=> 'a:23:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:7:"primary";i:2;}s:18:"custom_css_post_id";i:22;s:19:"hide_pagethreeboxes";b:0;s:12:"page-column1";s:15:"happy_hour_page";s:12:"page-column2";s:20:"weekly_specials_page";s:12:"page-column3";s:19:"private_events_page";s:13:"page-setting7";s:33:"an_amazing_dining_experience_page";s:13:"page-setting8";s:29:"great_food_great_service_page";s:11:"hide_slides";b:0;s:11:"custom_logo";i:30;s:11:"sec-column1";s:19:"private_events_page";s:11:"sec-column2";s:33:"an_amazing_dining_experience_page";s:11:"sec-column3";s:15:"happy_hour_page";s:11:"sec-column4";s:29:"great_food_great_service_page";s:25:"hide_home_secwith_content";b:0;s:14:"newsfeed_title";s:15:"Recent Articles";s:11:"about_title";s:10:"Who We are";s:17:"about_description";s:186:"Our restaurant was founded 20 years ago after our head chef, Mario Dugatti, visited his grandmother in northern Italy and was inspired to bring her amazing cuisine to plates in our town.";s:13:"contact_title";s:12:"Get in Touch";s:11:"contact_add";s:6:"123 Oz";s:10:"contact_no";s:12:"555-555-5555";s:12:"contact_mail";s:19:"example@example.com";}',
			'theme_plugins_recipe-lite'					=> 'a:0:{}',
			'theme_objects_recipe-lite'					=> 'a:10:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:11:"restaurant4";s:8:"filename";s:15:"restaurant4.jpg";s:5:"title";s:23:"Slider Restaurant Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:21:"abendbrot-939435_1920";s:8:"filename";s:25:"abendbrot-939435_1920.jpg";s:5:"title";s:18:"Slider Table Image";s:7:"content";s:0:"";}i:2;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:5:"toast";s:8:"filename";s:9:"toast.jpg";s:5:"title";s:16:"Happy Hour Image";s:7:"content";s:0:"";}i:3;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:13:"weeklyspecial";s:8:"filename";s:17:"weeklyspecial.jpg";s:5:"title";s:21:"Weekly Specials Image";s:7:"content";s:0:"";}i:4;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:11:"dinnerevent";s:8:"filename";s:15:"dinnerevent.jpg";s:5:"title";s:20:"Private Events Image";s:7:"content";s:0:"";}i:5;a:8:{s:4:"type";s:4:"page";s:4:"name";s:28:"an-amazing-dining-experience";s:5:"title";s:29:"An Amazing Dining Experience!";s:7:"content";s:171:"<!-- wp:paragraph --><p>Our handmade dishes will take you on a culinary adventure. Come join us for a dining experience you will not soon forget.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:58:"Our handmade dishes will take you on a culinary adventure!";s:9:"thumbnail";s:11:"restaurant4";s:12:"replace_term";s:33:"an_amazing_dining_experience_page";s:13:"replace_value";s:7:"post_id";}i:6;a:8:{s:4:"type";s:4:"page";s:4:"name";s:24:"great-food-great-service";s:5:"title";s:26:"Great Food! Great Service!";s:7:"content";s:146:"<!-- wp:paragraph --><p>When you are here, you are family! Come feel right at home with our tasty menu and warm service.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:96:"When you are here, you are family! Come feel right at home with our tasty menu and warm service.";s:9:"thumbnail";s:21:"abendbrot-939435_1920";s:12:"replace_term";s:29:"great_food_great_service_page";s:13:"replace_value";s:7:"post_id";}i:7;a:8:{s:4:"type";s:4:"page";s:4:"name";s:10:"happy-hour";s:5:"title";s:10:"Happy Hour";s:7:"content";s:92:"<!-- wp:paragraph --><p>Between 4pm and 6pm, enjoy 2 for 1 drinks.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:42:"Between 4pm and 6pm, enjoy 2 for 1 drinks.";s:9:"thumbnail";s:5:"toast";s:12:"replace_term";s:15:"happy_hour_page";s:13:"replace_value";s:7:"post_id";}i:8;a:8:{s:4:"type";s:4:"page";s:4:"name";s:15:"weekly-specials";s:5:"title";s:15:"Weekly Specials";s:7:"content";s:120:"<!-- wp:paragraph --><p>Including dinner specials on Wednesdays and wine tasting on Thursdays.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:70:"Including dinner specials on Wednesdays and wine tasting on Thursdays.";s:9:"thumbnail";s:13:"weeklyspecial";s:12:"replace_term";s:20:"weekly_specials_page";s:13:"replace_value";s:7:"post_id";}i:9;a:8:{s:4:"type";s:4:"page";s:4:"name";s:14:"private-events";s:5:"title";s:14:"Private Events";s:7:"content";s:111:"<!-- wp:paragraph --><p>Our restaurant offers the perfect setting to host your event.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:61:"Our restaurant offers the perfect setting to host your event.";s:9:"thumbnail";s:11:"dinnerevent";s:12:"replace_term";s:19:"private_events_page";s:13:"replace_value";s:7:"post_id";}}',
			'theme_optional_recipe-lite'				=> 'a:4:{i:0;a:3:{s:4:"name";s:22:"Enable Homepage Slider";s:12:"instructions";s:103:"Enable the slider that shows at the top of your homepage, and choose which pages to use for the slider.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:14:"Turn Slider On";s:4:"type";s:3:"url";s:5:"value";s:47:"customize.php?autofocus[section]=slider_section";}}}i:1;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:2;a:3:{s:4:"name";s:28:"Homepage Three Boxes Section";s:12:"instructions";s:82:"Edit the pages that are used for the three boxes under the slider on the homepage.";s:5:"links";a:3:{i:0;a:3:{s:4:"text";s:5:"Box 1";s:4:"type";s:4:"page";s:5:"value";s:10:"happy-hour";}i:1;a:3:{s:4:"text";s:5:"Box 2";s:4:"type";s:4:"page";s:5:"value";s:15:"weekly-specials";}i:2;a:3:{s:4:"text";s:5:"Box 3";s:4:"type";s:4:"page";s:5:"value";s:14:"private-events";}}}i:3;a:3:{s:4:"name";s:27:"Homepage Four Boxes Section";s:12:"instructions";s:74:"Edit the pages that are used for the area with four boxes on the homepage.";s:5:"links";a:4:{i:0;a:3:{s:4:"text";s:5:"Box 1";s:4:"type";s:4:"page";s:5:"value";s:14:"private-events";}i:1;a:3:{s:4:"text";s:5:"Box 2";s:4:"type";s:4:"page";s:5:"value";s:28:"an-amazing-dining-experience";}i:2;a:3:{s:4:"text";s:5:"Box 3";s:4:"type";s:4:"page";s:5:"value";s:10:"happy-hour";}i:3;a:3:{s:4:"text";s:5:"Box 4";s:4:"type";s:4:"page";s:5:"value";s:24:"great-food-great-service";}}}}',
			'theme_post_meta_recipe-lite'				=> 'a:6:{i:0;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:21:"template-fullwide.php";}i:1;a:3:{s:7:"post_id";i:3;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:21:"template-fullwide.php";}i:2;a:3:{s:7:"post_id";i:4;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:21:"template-fullwide.php";}i:3;a:3:{s:7:"post_id";i:5;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:21:"template-fullwide.php";}i:4;a:3:{s:7:"post_id";i:6;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:21:"template-fullwide.php";}i:5;a:3:{s:7:"post_id";i:7;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:21:"template-fullwide.php";}}',
			'theme_css_selectors_recipe-lite'			=> 'a:1:{s:10:"foreground";s:1465:".sitenav ul li a:hover, .sitenav ul li.current_page_item a, .sitenav ul li.menu-item-has-children.hover, .sitenav ul li.current-menu-parent a.parent {color: $color;}/* Slider \"Read More\" button hover*/.slide_info .slide_more:hover {background-color:$color;}/* Check if slide_info span needs to be foreground or if it is included in \"Headings\" color selector *//*.slide_info h2 span {    color: $color;}*//* Slider ControNav Dot */.nivo-controlNav a.active {    background-color: $color;}/* Specialty Box *//* Check if :hover h4 is included in \"Headings\" color selector .specialty-box-inner:hover h4 {    color: $color;}*//* Threebox hover color */.threebox {background-color: $color;}/* \"Reserve Now\" button hover*/.newReservationButton:hover {background: $color;}/* Footer recent-post anchor text hover*/.recent-post a:hover {color: $color;}/* Footer email text hover*/.phone-no a:hover {color: $color;}.erm_product_price .price {color: $color;}*//* \"Request Booking\" button */.rtb-booking-form button:hover {background-color: $color;}/* FAQ +/- symbol */.ewd-ufaq-post-margin-symbol {color: $color !important;}/* \"Search\" button */input.search-submit, .post-password-form input[type=submit], .wpcf7-form input[type=submit] {background-color: $color;}/* \"Submit\" button hover */div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}/* Overall changes: *//* make anchor text color as the foreground color */a {color: $color;}";}',
			'theme_page_content_recipe-lite'			=> 'a:0:{}',
			'rtb-settings'								=> 'a:1:{s:12:\"booking-page\";i:4;}',
			'ect_portfolio' => 'a:1:{s:6:"status";i:1;}',
			'ect_testimonial' => 'a:1:{s:6:"status";i:1;}',
			'ect_featured_content' => 'a:1:{s:6:"status";i:1;}',
			'ect_service' => 'a:1:{s:6:"status";i:1;}',
			'ect_food_menu' => 'a:1:{s:6:"status";i:0;}',
			'ect_service_content' => 'What We Do',
			'EWD_UFAQ_Custom_CSS' => '.ewd-ufaq-author-date {\nmargin-bottom:20px;\n}',
			'EWD_UFAQ_Scroll_To_Top' => 'No',
			'EWD_UFAQ_Display_Author' => 'No',
			'EWD_UFAQ_Display_Style' => 'Contemporary',
			'EWD_UFAQ_FAQ_Elements' => 'a:10:{i:0;s:4:\"Body\";i:1;s:13:\"Custom_Fields\";i:2;s:10:\"Categories\";i:3;s:4:\"Tags\";i:4;s:11:\"Author_Date\";i:5;s:7:\"Ratings\";i:6;s:12:\"Social_Media\";i:7;s:9:\"Permalink\";i:8;s:8:\"Comments\";i:9;s:11:\"Back_To_Top\";}',
			'EWD_UFAQ_Group_By_Category' => 'Yes',
			'EWD_UFAQ_Styling_Toggle_Symbol_Size' => '21px',
			'EWD_UFAQ_Styling_Default_Font_Color' => '#555555',
			'EWD_UFAQ_Styling_Question_Font_Size' => '18px',
			'EWD_UFAQ_Styling_Category_Heading_Font_Size' => '24px',
			'EWD_UFAQ_Styling_Category_Heading_Type' => 'h3'
		);

		foreach ( $values_array as $option_name => $option_value ) {
			$option = get_option( $option_name, 'Not Found' );

			if ( $option == 'Not Found' ) { $wpdb->query( "INSERT INTO $wpdb->options ( option_name, option_value ) VALUES ('" . $option_name . "','" . $option_value ."')" );  }
			else { $wpdb->query( "UPDATE $wpdb->options SET option_value = '" . $option_value . "' WHERE option_name='" . $option_name . "'" ); }
		}

		$values_array = array(
			array(
			 	'meta_id'	=> 2,
			 	'post_id'	=> 30,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/cropped-restaurant-site-logo3.png'
			),
			array(
			 	'meta_id'	=> 3,
			 	'post_id'	=> 30,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:1164;s:6:"height";i:146;s:4:"file";s:43:"initial_images/cropped-restaurant-site-logo3.png";s:5:"sizes";a:13:{s:9:"thumbnail";a:4:{s:4:"file";s:43:"cropped-restaurant-site-logo3-150x146.png";s:5:"width";i:150;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:6:"medium";a:4:{s:4:"file";s:42:"cropped-restaurant-site-logo3-300x38.png";s:5:"width";i:300;s:6:"height";i:38;s:9:"mime-type";s:9:"image/png";}s:12:"medium_large";a:4:{s:4:"file";s:42:"cropped-restaurant-site-logo3-768x96.png";s:5:"width";i:768;s:6:"height";i:96;s:9:"mime-type";s:9:"image/png";}s:5:"large";a:4:{s:4:"file";s:44:"cropped-restaurant-site-logo3-1024x128.png";s:5:"width";i:1024;s:6:"height";i:128;s:9:"mime-type";s:9:"image/png";}s:26:"bakes-and-cakes-post-thumb";a:4:{s:4:"file";s:41:"cropped-restaurant-site-logo3-60x60.png";s:5:"width";i:60;s:6:"height";i:60;s:9:"mime-type";s:9:"image/png";}s:27:"bakes-and-cakes-about-thumb";a:4:{s:4:"file";s:43:"cropped-restaurant-site-logo3-600x146.png";s:5:"width";i:600;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:29:"bakes-and-cakes-product-thumb";a:4:{s:4:"file";s:43:"cropped-restaurant-site-logo3-235x146.png";s:5:"width";i:235;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:26:"bakes-and-cakes-image-full";a:4:{s:4:"file";s:44:"cropped-restaurant-site-logo3-1139x146.png";s:5:"width";i:1139;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:21:"bakes-and-cakes-image";a:4:{s:4:"file";s:43:"cropped-restaurant-site-logo3-750x146.png";s:5:"width";i:750;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:27:"bakes-and-cakes-staff-thumb";a:4:{s:4:"file";s:43:"cropped-restaurant-site-logo3-487x146.png";s:5:"width";i:487;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:26:"bakes-and-cakes-blog-thumb";a:4:{s:4:"file";s:43:"cropped-restaurant-site-logo3-280x146.png";s:5:"width";i:280;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:28:"bakes-and-cakes-events-thumb";a:4:{s:4:"file";s:43:"cropped-restaurant-site-logo3-255x146.png";s:5:"width";i:255;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:22:"bakes-and-cakes-schema";a:4:{s:4:"file";s:42:"cropped-restaurant-site-logo3-600x60.png";s:5:"width";i:600;s:6:"height";i:60;s:9:"mime-type";s:9:"image/png";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 4,
			 	'post_id'	=> 31,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/cheersing.jpg'
			),
			array(
			 	'meta_id'	=> 5,
			 	'post_id'	=> 31,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:1200;s:6:"height";i:400;s:4:"file";s:21:"initial_images/cheersing.jpg";s:5:"sizes";a:13:{s:9:"thumbnail";a:4:{s:4:"file";s:21:"cheersing-150x150.jpg";s:5:"width";i:150;s:6:"height";i:150;s:9:"mime-type";s:10:"image/jpeg";}s:6:"medium";a:4:{s:4:"file";s:21:"cheersing-300x100.jpg";s:5:"width";i:300;s:6:"height";i:100;s:9:"mime-type";s:10:"image/jpeg";}s:12:"medium_large";a:4:{s:4:"file";s:21:"cheersing-768x256.jpg";s:5:"width";i:768;s:6:"height";i:256;s:9:"mime-type";s:10:"image/jpeg";}s:5:"large";a:4:{s:4:"file";s:22:"cheersing-1024x341.jpg";s:5:"width";i:1024;s:6:"height";i:341;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-post-thumb";a:4:{s:4:"file";s:19:"cheersing-60x60.jpg";s:5:"width";i:60;s:6:"height";i:60;s:9:"mime-type";s:10:"image/jpeg";}s:27:"bakes-and-cakes-about-thumb";a:4:{s:4:"file";s:21:"cheersing-600x400.jpg";s:5:"width";i:600;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:29:"bakes-and-cakes-product-thumb";a:4:{s:4:"file";s:21:"cheersing-235x235.jpg";s:5:"width";i:235;s:6:"height";i:235;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-image-full";a:4:{s:4:"file";s:22:"cheersing-1139x400.jpg";s:5:"width";i:1139;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:21:"bakes-and-cakes-image";a:4:{s:4:"file";s:21:"cheersing-750x400.jpg";s:5:"width";i:750;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:27:"bakes-and-cakes-staff-thumb";a:4:{s:4:"file";s:21:"cheersing-487x400.jpg";s:5:"width";i:487;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-blog-thumb";a:4:{s:4:"file";s:21:"cheersing-280x255.jpg";s:5:"width";i:280;s:6:"height";i:255;s:9:"mime-type";s:10:"image/jpeg";}s:28:"bakes-and-cakes-events-thumb";a:4:{s:4:"file";s:21:"cheersing-255x255.jpg";s:5:"width";i:255;s:6:"height";i:255;s:9:"mime-type";s:10:"image/jpeg";}s:22:"bakes-and-cakes-schema";a:4:{s:4:"file";s:20:"cheersing-600x60.jpg";s:5:"width";i:600;s:6:"height";i:60;s:9:"mime-type";s:10:"image/jpeg";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"1";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 6,
			 	'post_id'	=> 32,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/reservations-img.jpg'
			),
			array(
			 	'meta_id'	=> 7,
			 	'post_id'	=> 32,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:1200;s:6:"height";i:400;s:4:"file";s:24:"initial_images/reservations-img.jpg";s:5:"sizes";a:13:{s:9:"thumbnail";a:4:{s:4:"file";s:24:"reservations-150x150.jpg";s:5:"width";i:150;s:6:"height";i:150;s:9:"mime-type";s:10:"image/jpeg";}s:6:"medium";a:4:{s:4:"file";s:24:"reservations-300x100.jpg";s:5:"width";i:300;s:6:"height";i:100;s:9:"mime-type";s:10:"image/jpeg";}s:12:"medium_large";a:4:{s:4:"file";s:24:"reservations-768x256.jpg";s:5:"width";i:768;s:6:"height";i:256;s:9:"mime-type";s:10:"image/jpeg";}s:5:"large";a:4:{s:4:"file";s:25:"reservations-1024x341.jpg";s:5:"width";i:1024;s:6:"height";i:341;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-post-thumb";a:4:{s:4:"file";s:22:"reservations-60x60.jpg";s:5:"width";i:60;s:6:"height";i:60;s:9:"mime-type";s:10:"image/jpeg";}s:27:"bakes-and-cakes-about-thumb";a:4:{s:4:"file";s:24:"reservations-600x400.jpg";s:5:"width";i:600;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:29:"bakes-and-cakes-product-thumb";a:4:{s:4:"file";s:24:"reservations-235x235.jpg";s:5:"width";i:235;s:6:"height";i:235;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-image-full";a:4:{s:4:"file";s:25:"reservations-1139x400.jpg";s:5:"width";i:1139;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:21:"bakes-and-cakes-image";a:4:{s:4:"file";s:24:"reservations-750x400.jpg";s:5:"width";i:750;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:27:"bakes-and-cakes-staff-thumb";a:4:{s:4:"file";s:24:"reservations-487x400.jpg";s:5:"width";i:487;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-blog-thumb";a:4:{s:4:"file";s:24:"reservations-280x255.jpg";s:5:"width";i:280;s:6:"height";i:255;s:9:"mime-type";s:10:"image/jpeg";}s:28:"bakes-and-cakes-events-thumb";a:4:{s:4:"file";s:24:"reservations-255x255.jpg";s:5:"width";i:255;s:6:"height";i:255;s:9:"mime-type";s:10:"image/jpeg";}s:22:"bakes-and-cakes-schema";a:4:{s:4:"file";s:23:"reservations-600x60.jpg";s:5:"width";i:600;s:6:"height";i:60;s:9:"mime-type";s:10:"image/jpeg";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"1";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 8,
			 	'post_id'	=> 33,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/kitchen1.jpg'
			),
			array(
			 	'meta_id'	=> 9,
			 	'post_id'	=> 33,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:1280;s:6:"height";i:853;s:4:"file";s:20:"initial_images/kitchen1.jpg";s:5:"sizes";a:17:{s:9:"thumbnail";a:4:{s:4:"file";s:20:"kitchen1-150x150.jpg";s:5:"width";i:150;s:6:"height";i:150;s:9:"mime-type";s:10:"image/jpeg";}s:6:"medium";a:4:{s:4:"file";s:20:"kitchen1-300x200.jpg";s:5:"width";i:300;s:6:"height";i:200;s:9:"mime-type";s:10:"image/jpeg";}s:12:"medium_large";a:4:{s:4:"file";s:20:"kitchen1-768x512.jpg";s:5:"width";i:768;s:6:"height";i:512;s:9:"mime-type";s:10:"image/jpeg";}s:5:"large";a:4:{s:4:"file";s:21:"kitchen1-1024x682.jpg";s:5:"width";i:1024;s:6:"height";i:682;s:9:"mime-type";s:10:"image/jpeg";}s:30:"ect-jetpack-portfolio-featured";a:4:{s:4:"file";s:20:"kitchen1-640x640.jpg";s:5:"width";i:640;s:6:"height";i:640;s:9:"mime-type";s:10:"image/jpeg";}s:20:"ect-featured-content";a:4:{s:4:"file";s:20:"kitchen1-640x640.jpg";s:5:"width";i:640;s:6:"height";i:640;s:9:"mime-type";s:10:"image/jpeg";}s:11:"ect-service";a:4:{s:4:"file";s:20:"kitchen1-640x640.jpg";s:5:"width";i:640;s:6:"height";i:640;s:9:"mime-type";s:10:"image/jpeg";}s:14:"post-thumbnail";a:4:{s:4:"file";s:20:"kitchen1-666x666.jpg";s:5:"width";i:666;s:6:"height";i:666;s:9:"mime-type";s:10:"image/jpeg";}s:28:"catch-foodmania-header-inner";a:4:{s:4:"file";s:21:"kitchen1-1280x540.jpg";s:5:"width";i:1280;s:6:"height";i:540;s:9:"mime-type";s:10:"image/jpeg";}s:32:"catch-foodmania-featured-content";a:4:{s:4:"file";s:20:"kitchen1-666x444.jpg";s:5:"width";i:666;s:6:"height";i:444;s:9:"mime-type";s:10:"image/jpeg";}s:23:"catch-foodmania-service";a:4:{s:4:"file";s:18:"kitchen1-70x70.jpg";s:5:"width";i:70;s:6:"height";i:70;s:9:"mime-type";s:10:"image/jpeg";}s:27:"catch-foodmania-testimonial";a:4:{s:4:"file";s:20:"kitchen1-666x750.jpg";s:5:"width";i:666;s:6:"height";i:750;s:9:"mime-type";s:10:"image/jpeg";}s:33:"catch-foodmania-testimonial-thumb";a:4:{s:4:"file";s:18:"kitchen1-75x75.jpg";s:5:"width";i:75;s:6:"height";i:75;s:9:"mime-type";s:10:"image/jpeg";}s:28:"catch-foodmania-hero-content";a:4:{s:4:"file";s:20:"kitchen1-680x635.jpg";s:5:"width";i:680;s:6:"height";i:635;s:9:"mime-type";s:10:"image/jpeg";}s:29:"jetpack-portfolio-admin-thumb";a:4:{s:4:"file";s:18:"kitchen1-50x50.jpg";s:5:"width";i:50;s:6:"height";i:50;s:9:"mime-type";s:10:"image/jpeg";}s:28:"featured-content-admin-thumb";a:4:{s:4:"file";s:18:"kitchen1-50x50.jpg";s:5:"width";i:50;s:6:"height";i:50;s:9:"mime-type";s:10:"image/jpeg";}s:19:"service-admin-thumb";a:4:{s:4:"file";s:18:"kitchen1-50x50.jpg";s:5:"width";i:50;s:6:"height";i:50;s:9:"mime-type";s:10:"image/jpeg";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 10,
			 	'post_id'	=> 34,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/table.jpg'
			),
			array(
			 	'meta_id'	=> 11,
			 	'post_id'	=> 34,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:1200;s:6:"height";i:400;s:4:"file";s:17:"initial_images/table.jpg";s:5:"sizes";a:13:{s:9:"thumbnail";a:4:{s:4:"file";s:17:"table-150x150.jpg";s:5:"width";i:150;s:6:"height";i:150;s:9:"mime-type";s:10:"image/jpeg";}s:6:"medium";a:4:{s:4:"file";s:17:"table-300x100.jpg";s:5:"width";i:300;s:6:"height";i:100;s:9:"mime-type";s:10:"image/jpeg";}s:12:"medium_large";a:4:{s:4:"file";s:17:"table-768x256.jpg";s:5:"width";i:768;s:6:"height";i:256;s:9:"mime-type";s:10:"image/jpeg";}s:5:"large";a:4:{s:4:"file";s:18:"table-1024x341.jpg";s:5:"width";i:1024;s:6:"height";i:341;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-post-thumb";a:4:{s:4:"file";s:15:"table-60x60.jpg";s:5:"width";i:60;s:6:"height";i:60;s:9:"mime-type";s:10:"image/jpeg";}s:27:"bakes-and-cakes-about-thumb";a:4:{s:4:"file";s:17:"table-600x400.jpg";s:5:"width";i:600;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:29:"bakes-and-cakes-product-thumb";a:4:{s:4:"file";s:17:"table-235x235.jpg";s:5:"width";i:235;s:6:"height";i:235;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-image-full";a:4:{s:4:"file";s:18:"table-1139x400.jpg";s:5:"width";i:1139;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:21:"bakes-and-cakes-image";a:4:{s:4:"file";s:17:"table-750x400.jpg";s:5:"width";i:750;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:27:"bakes-and-cakes-staff-thumb";a:4:{s:4:"file";s:17:"table-487x400.jpg";s:5:"width";i:487;s:6:"height";i:400;s:9:"mime-type";s:10:"image/jpeg";}s:26:"bakes-and-cakes-blog-thumb";a:4:{s:4:"file";s:17:"table-280x255.jpg";s:5:"width";i:280;s:6:"height";i:255;s:9:"mime-type";s:10:"image/jpeg";}s:28:"bakes-and-cakes-events-thumb";a:4:{s:4:"file";s:17:"table-255x255.jpg";s:5:"width";i:255;s:6:"height";i:255;s:9:"mime-type";s:10:"image/jpeg";}s:22:"bakes-and-cakes-schema";a:4:{s:4:"file";s:16:"table-600x60.jpg";s:5:"width";i:600;s:6:"height";i:60;s:9:"mime-type";s:10:"image/jpeg";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"1";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 12,
			 	'post_id'	=> 5,
			 	'meta_key'	=> '_thumbnail_id',
			 	'meta_value'	=> '31'
			),
			array(
			 	'meta_id'	=> 13,
			 	'post_id'	=> 4,
			 	'meta_key'	=> '_thumbnail_id',
			 	'meta_value'	=> '32'
			),
			array(
			 	'meta_id'	=> 14,
			 	'post_id'	=> 6,
			 	'meta_key'	=> '_thumbnail_id',
			 	'meta_value'	=> '33'
			),
			array(
			 	'meta_id'	=> 15,
			 	'post_id'	=> 7,
			 	'meta_key'	=> '_thumbnail_id',
			 	'meta_value'	=> '34'
			),

			array(
				'meta_id'	=> 180,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 181,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 182,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '8'
			),
			array(
				'meta_id'	=> 183,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 184,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> '')
			,
			array(
				'meta_id'	=> 185,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:
				1:{i:0;s:0:\"\";}'),
			array(
				'meta_id'	=> 186,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> '')
			,
			array(
				'meta_id'	=> 187,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> '')
			,
			array(
				'meta_id'	=> 189,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 190,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 191,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '7'
			),
			array(
				'meta_id'	=> 192,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 193,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 194,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 195,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 196,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 198,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 199,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 200,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '6'
			),
			array(
				'meta_id'	=> 201,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 202,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 203,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 204,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 205,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 207,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 208,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 209,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '4'
			),
			array(
				'meta_id'	=> 210,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 211,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 212,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 213,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 214,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 216,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 217,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 218,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '5'
			),
			array(
				'meta_id'	=> 219,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 220,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 221,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 222,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 223,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 225,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 226,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 227,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '3'
			),
			array(
				'meta_id'	=> 228,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 229,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 230,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 231,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 232,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 234,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 235,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 236,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '2'
			),
			array(
				'meta_id'	=> 237,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 238,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 239,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 240,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 241,
				'post_id'  	=> 16,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			)
		);

		$wpdb->query( "TRUNCATE TABLE $wpdb->postmeta" );
		foreach ( $values_array as $value ) {
			$wpdb->query( "INSERT INTO $wpdb->postmeta ( meta_id, post_id, meta_key, meta_value ) VALUES ('" . $value['meta_id'] . "','" . $value['post_id'] ."','" . $value['meta_key'] ."','" . $value['meta_value'] ."')" );
		}

		$values_array = array(
			array(
				'ID' 			=> 1,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:heading --><h2>Who we are</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Our website address is: [[softurl]].</p><!-- /wp:paragraph --><!-- wp:heading --><h2>What personal data we collect and why we collect it</h2><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Comments</h3><!-- /wp:heading --><!-- wp:paragraph --><p>When visitors leave comments on the site we collect the data shown in the comments form, and also the visitor&#8217;s IP address and browser user agent string to help spam detection.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>An anonymized string created from your email address (also called a hash) may be provided to the Gravatar service to see if you are using it. The Gravatar service privacy policy is available here: https://automattic.com/privacy/. After approval of your comment, your profile picture is visible to the public in the context of your comment.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Media</h3><!-- /wp:heading --><!-- wp:paragraph --><p>If you upload images to the website, you should avoid uploading images with embedded location data (EXIF GPS) included. Visitors to the website can download and extract any location data from images on the website.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Contact forms</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Cookies</h3><!-- /wp:heading --><!-- wp:paragraph --><p>If you leave a comment on our site you may opt-in to saving your name, email address and website in cookies. These are for your convenience so that you do not have to fill in your details again when you leave another comment. These cookies will last for one year.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>If you have an account and you log in to this site, we will set a temporary cookie to determine if your browser accepts cookies. This cookie contains no personal data and is discarded when you close your browser.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>When you log in, we will also set up several cookies to save your login information and your screen display choices. Login cookies last for two days, and screen options cookies last for a year. If you select &quot;Remember Me&quot;, your login will persist for two weeks. If you log out of your account, the login cookies will be removed.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>If you edit or publish an article, an additional cookie will be saved in your browser. This cookie includes no personal data and simply indicates the post ID of the article you just edited. It expires after 1 day.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Embedded content from other websites</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Articles on this site may include embedded content (e.g. videos, images, articles, etc.). Embedded content from other websites behaves in the exact same way as if the visitor has visited the other website.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>These websites may collect data about you, use cookies, embed additional third-party tracking, and monitor your interaction with that embedded content, including tracking your interaction with the embedded content if you have an account and are logged in to that website.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Analytics</h3><!-- /wp:heading --><!-- wp:heading --><h2>Who we share your data with</h2><!-- /wp:heading --><!-- wp:heading --><h2>How long we retain your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>If you leave a comment, the comment and its metadata are retained indefinitely. This is so we can recognize and approve any follow-up comments automatically instead of holding them in a moderation queue.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>For users that register on our website (if any), we also store the personal information they provide in their user profile. All users can see, edit, or delete their personal information at any time (except they cannot change their username). Website administrators can also see and edit that information.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>What rights you have over your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>If you have an account on this site, or have left comments, you can request to receive an exported file of the personal data we hold about you, including any data you have provided to us. You can also request that we erase any personal data we hold about you. This does not include any data we are obliged to keep for administrative, legal, or security purposes.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>Where we send your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Visitor comments may be checked through an automated spam detection service.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>Your contact information</h2><!-- /wp:heading --><!-- wp:heading --><h2>Additional information</h2><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>How we protect your data</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What data breach procedures we have in place</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What third parties we receive data from</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What automated decision making and/or profiling we do with user data</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Industry regulatory disclosure requirements</h3><!-- /wp:heading -->',
				'post_title'	=> 'Privacy Policy',
				'post_excerpt'	=> '',
				'post_status'	=> 'draft',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'privacy-policy',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=1',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 2,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:heading {"align":"center"} --><h2 style="text-align:center">Reservations</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center"} --><p style="text-align:center">You can request a reservation directly on our site using our new online booking form! Of course, you can always give us a ring at 555-555-5555 if you would prefer to book over the phone.</p><!-- /wp:paragraph --><!-- wp:html --><a href="/reservations/" class="newReservationButton">RESERVE NOW</a><!-- /wp:html --><!-- wp:paragraph --><p></p><!-- /wp:paragraph -->',
				'post_title'	=> 'Home',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'home',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=2',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 3,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Please find our menu below:<br/>[fdm-menu]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Menu',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'menu',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=3',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 4,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Please use the form below to make a reservation:<br/></p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Reservations',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'reservations',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=4',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 5,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Our restaurant provides the perfect venue for you to host your next private event. We can accommodate medium-sized groups. Please get in touch with us through our contact page.</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Events',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'events',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=5',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 6,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Restaurant Information:<br/>[ultimate-faqs]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Frequently Asked Questions',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'frequently-asked-questions',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=6',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 7,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Talk about what makes your restaurant unique, things like your values, your staff or your cuisine on this page.</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'About Us',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'about-us',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=7',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 8,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Please use the form below to get in touch with us:[contact_form]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Contact Us',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'contact-us',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=8',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 10,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '10',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=10',
				'menu_order'	=> 7,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 11,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '11',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=11',
				'menu_order'	=> 6,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 12,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '12',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=12',
				'menu_order'	=> 5,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 13,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '13',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=13',
				'menu_order'	=> 4,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 14,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '14',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=14',
				'menu_order'	=> 3,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 15,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '15',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=15',
				'menu_order'	=> 2,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 16,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '16',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=16',
				'menu_order'	=> 1,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 20,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> 'body {\n  color: #333333;\n}\n\n/*slider*/\n.site-branding {\n  margin: 8px 0 16px;\n}\n@media screen and (min-width: 568px) {\n.site-branding img {\n  width: 400px;\n}\n}\n@media screen and (max-width: 567px) {\n.site-branding img {\n max-width: 80%;\n}\n}\n.owl-carousel,\n.owl-stage-outer,\n.owl-stage,\n.owl-carousel .owl-item,\n.owl-carousel .owl-item li,\n.owl-carousel .owl-item img {\n height: 460px !important;\n}\n.banner .banner-text {\n  top: 6vw;\n}\n.banner .banner-text .text {\n  text-transform: none;\n}\n.banner .banner-text .text a.btn {\n  display: none;\n}\n.banner .banner-text .text p {\n background: rgba(0,0,0,.4);\n padding: 8px 13px;\n}\nbody.home .banner:after {\n  background: none;\n}\n\n/*menu page*/\n.erm_menu {\n  border-top: 3px solid black !important;\n}\n.erm_menu h1 {\n  display: none;\n}\n.erm_menu h2 {\n font-size: 28px !important;\n border: none !important;\n}\n.erm_menu h3 {\n font-size: 20px !important;\n}\n.erm_menu img {\n width: 90px !important;\n}\n.erm_product {\n  margin: 8px 0;\n}\n.erm_product_price {\n float: right;\n margin-top: 9px;\n}\n\n/*homepage*/\n\nbody.home #product p {\n margin-top: 16px\n}\n\nbody.home #events h3 a {\n cursor: default;\n  pointer-events: none;\n}\n\n/*inner pages*/\n#secondary {\n display: none;\n}\n#primary {\n width: 100%;\n  padding: 0;\n}\n.entry-content .wp-block-image {\n  width: calc(100% + 66px);\n margin-left: -33px;\n max-width: none;\n}\n.entry-content .wp-block-image img {\n width: 100%;\n}\n\n/*faq page*/\n.ufaq-faq-category-title h3 {\n  font-size: 24px !important;\n}\n.ufaq-faq-title p {\n display: none;\n}\n.ewd-ufaq-author-date,\n.ufaq-faq-categories {\n color: #888;\n}\n.ewd-ufaq-date {\n font-weight: normal;\n}\n.ufaq-faq-display-style-Contemporary .ewd-ufaq-post-margin-symbol {\n  margin-top: 10px;\n}\n\n/*reservations anc contact us pages*/\n.rtb-booking-form button,\ndiv.wpforms-container-full .wpforms-form button[type=\"submit\"] {\n  background: #F6A8C6;\n  box-shadow: none;\n text-shadow: none;\n  color: #fff;\n  border: 2px solid;\n  border-color: #F6A8C6;\n  font-size: 14px;\n  margin-left: 2px;\n}\n.rtb-booking-form button:hover,\ndiv.wpforms-container-full .wpforms-form button[type=\"submit\"]:hover {\n background: #F3C4D6;\n  box-shadow: none;\n text-shadow: none;\n  color: #fff;\n  border: 2px solid;\n  border-color: #F3C4D6;\n  font-size: 14px;\n  cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 60%;\n}',
				'post_title'	=> 'bakes-and-cakes',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'bakes-and-cakes',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=20',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 21,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '/*pages*/\nbody.page .entry-meta {\n display: none;\n}\nbody.page .wp-block-image img {\n  width: 100%;\n}\n.breadcrumb-current {\n  color: white;\n}\n\n/*homepage*/\n.graybackground {\n background: #f4f4f4;\n}\n#services-section .ect-service .hentry-inner img {\ndisplay: none;\n}\n#services-section .more-button {\ndisplay: none;\n}\n@media screen and (min-width: 1024px) {\n  #services-section .special-image img {\n    width: 80%;\n   margin-top: 120px;\n  }\n}\nbody.home #content {\n  background: url(' . get_site_url() . '/wp-content/uploads/initial_images/samuel-foster-412328-unsplash.jpg);\n background-size: cover;\n color: #fff;\n}\nbody.home #content h2 {\n  color: #fff;\n}\nbody.home #content .entry-title {\n  display: none;\n}\n.newReservationButton {\n  position: relative;\n float: left;\n  width: 160px;\n padding: 8px 0;\n border: 2px solid #fff;\n margin: 24px 0 0 calc(50% - 82px);\n  background: transparent;\n  color: #fff;\n  text-align: center;\n font-weight: bold;\n}\n.newReservationButton:hover {\n  background: #fff;\n color: #333;\n}\n\n/*menu page*/\n.erm_menu {\n border-top: 3px solid black !important;\n}\n.erm_menu h1 {\n  display: none;\n}\n.erm_menu h2 {\n font-size: 28px !important;\n border: none !important;\n}\n.erm_menu h3 {\n font-size: 20px !important;\n}\n.erm_menu img {\n width: 90px !important;\n}\n.erm_product {\n  margin: 8px 0;\n}\n.erm_product_price {\n float: right;\n margin-top: 9px;\n}\n\n/*faq page*/\n.ufaq-faq-category-title h3 {\n  font-size: 24px !important;\n}\n.ufaq-faq-title p {\n display: none;\n}\n.ewd-ufaq-author-date,\n.ufaq-faq-categories {\n color: #888;\n}\n.ewd-ufaq-date {\n font-weight: normal;\n}\n.ufaq-faq-display-style-Contemporary .ewd-ufaq-post-margin-symbol {\n  margin-top: 10px;\n}\n\n/*contact us pages*/\ndiv.wpforms-container-full .wpforms-form textarea {\n max-width: 60%;\n}\n',
				'post_title'	=> 'catch-foodmania',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'catch-foodmania',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=21',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 22,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> 'body {\n font-size: 16px;\n}\n\n/*header*/\nbody.enableslide .header {\n background: #000;\n}\n.sitenav {\n  padding: 23px 0 20px 0;\n}\n\n/*pages*/\n.page-template-template-fullwide .entry-content .wp-block-image img {\n  width: 100%;\n  margin-bottom: 30px;\n}\n\n/*menu page*/\n.erm_menu {\n border-top: 3px solid black !important;\n}\n.erm_menu h1 {\n  display: none;\n}\n.erm_menu h2 {\n font-size: 28px !important;\n border: none !important;\n}\n.erm_menu h3 {\n font-size: 20px !important;\n}\n.erm_menu img {\n width: 90px !important;\n}\n.erm_product {\n  margin: 8px 0;\n}\n.erm_product_price {\n float: right;\n margin-top: 9px;\n}\n\n/*faq page*/\n.ufaq-faq-category-title h3 {\n  font-size: 24px !important;\n}\n.ufaq-faq-title p {\n display: none;\n}\n.ewd-ufaq-author-date,\n.ufaq-faq-categories {\n color: #888;\n}\n.ewd-ufaq-date {\n font-weight: normal;\n}\n.ufaq-faq-display-style-Contemporary .ewd-ufaq-post-margin-symbol {\n  margin-top: 10px;\n}\n\n/*faq widget*/\naside.widget .ufaq-faq-title-text {\n width: 80%;\n}\naside.widget .ufaq-faq-display-style-Contemporary .ewd-ufaq-post-margin-symbol {\n  margin-top: 4px;\n}\naside.widget .ufaq-faq-category-title {\n  display: none;\n}\naside.widget .ufaq-faq-category,\naside.widget .ufaq-faq-category-inner {\n  margin-bottom: 0\n}\naside.widget .ufaq-faq-display-style-Contemporary {\n  border-bottom: none;\n}\naside.widget .ewd-ufaq-faqs {\n  border-bottom: 1px solid #ccc;\n}\n\n/*contact us page*/\ndiv.wpforms-container-full .wpforms-form input.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form .wpforms-field-row.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 100%;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n font: 700 14px \'Roboto\', sans-serif;\n  background-color: #f58c7f;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\n background-color: #f16150;\n  border: none;\n}\n\n/*reservations page*/\n.rtb-booking-form fieldset {\n border: 2px solid #ddd;\n padding: 0 20px 20px;\n}\n.rtb-booking-form button {\n  font: 700 14px \'Roboto\', sans-serif;\n  background-color: #f58c7f;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\n.rtb-booking-form button:hover {\n background-color: #f16150;\n}\n\n/*homepage*/\n.nivo-caption .slide_info h2{\n  font-family: \'Roboto Condensed\';\n  line-height: 1;\n font-weight: 300;\n text-shadow: 1px 2px 8px #000;\n  font-size: 70px !important;\n}\n\nbody.home #sidebar {\n  display: none;\n}\nbody.home .container:nth-of-type(3) {\n  width: 100%;\n  margin: 0;\n  padding: 0;\n background: url(' . get_site_url() . '/wp-content/uploads/initial_images/light_grey.png);\n  background-repeat: repeat;\n  color: #333;\n}\nbody.home .container:nth-of-type(3) .entry-header {\n  display: none;\n}\nbody.home .site-main {\n width: 80%;\n margin-left: 10%;\n}\nbody.home .container:nth-of-type(3) h2 {\n  color: #333;\n  font-size: 28px;\n  padding: 48px 0 20px\n}\nbody.home .container:nth-of-type(3) p {\n  line-height: 1.7;\n}\n.newReservationButton {\n position: relative;\n float: left;\n  width: 160px;\n padding: 8px 0;\n border: 2px solid #333;\n margin: 24px 0 40px calc(50% - 82px);\n background: transparent;\n  color: #333;\n  text-align: center;\n font-weight: bold;\n}\n.newReservationButton:hover {\n  background: #fff;\n color: #333;\n}',
				'post_title'	=> 'recipe-lite',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'recipe-lite',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=22',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 30,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/cropped-restaurant-site-logo3.png',
				'post_title'	=> 'cropped-restaurant-site-logo3',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'cropped-restaurant-site-logo3',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/cropped-restaurant-site-logo3.png',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 31,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/cheersing.jpg',
				'post_title'	=> 'cheersing',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'cheersing',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/cheersing.jpg',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 32,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/reservations-img.jpg',
				'post_title'	=> 'reservations-img',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'reservations-img',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/reservations-img.jpg',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 33,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/kitchen1.jpg',
				'post_title'	=> 'kitchen1',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'kitchen1',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/kitchen1.jpg',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 34,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/table.jpg',
				'post_title'	=> 'table',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'table',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/table.jpg',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			)
		);

 		$wpdb->query( "TRUNCATE TABLE $wpdb->posts" );
 		foreach ( $values_array as $value ) {
			$wpdb->query( "INSERT INTO $wpdb->posts ( ID, post_author, post_date, post_date_gmt, post_content, post_title, post_excerpt, post_status, comment_status, ping_status, post_password, post_name, to_ping, pinged, post_modified, post_modified_gmt, post_content_filtered, post_parent, guid, menu_order, post_type, post_mime_type, comment_count) VALUES ('" . $value['ID'] . "','" . $value['post_author'] ."','" . $value['post_date'] ."','" . $value['post_date_gmt'] ."','" . $value['post_content'] ."','" . $value['post_title'] ."','" . $value['post_excerpt'] ."','" . $value['post_status'] ."','" . $value['comment_status'] ."','" . $value['ping_status'] ."','" . $value['post_password'] ."','" . $value['post_name'] ."','" . $value['to_ping'] ."','" . $value['pinged'] ."','" . $value['post_modified'] ."','" . $value['post_modified_gmt'] ."','" . $value['post_content_filtered'] ."','" . $value['post_parent'] ."','" . $value['guid'] ."','" . $value['menu_order'] ."','" . $value['post_type'] ."','" . $value['post_mime_type'] ."','" . $value['comment_count'] ."')" );
		}

		/* if ( function_exists( 'wp_get_original_image_path' ) ) {
			$fullsizepath = wp_get_original_image_path( 30 );
		} else {
			$fullsizepath = get_attached_file( 30 );
		}

		wp_generate_attachment_metadata( 30, $fullsizepath ) */

		$wpdb->query( "TRUNCATE TABLE $wpdb->terms" );
		$wpdb->query( "INSERT INTO $wpdb->terms ( term_id, name, slug, term_group ) VALUES ('1','Uncategorized','uncategorized','0')" );
		$wpdb->query( "INSERT INTO $wpdb->terms ( term_id, name, slug, term_group ) VALUES ('2','Main Menu','main-menu','0')" );

		$wpdb->query( "TRUNCATE TABLE $wpdb->term_taxonomy" );
		$wpdb->query( "INSERT INTO $wpdb->term_taxonomy ( term_taxonomy_id, term_id, taxonomy, parent, count ) VALUES ('1','1','category','0','1')" );
		$wpdb->query( "INSERT INTO $wpdb->term_taxonomy ( term_taxonomy_id, term_id, taxonomy, parent, count ) VALUES ('2','2','nav_menu','0','7')" );

		$wpdb->query( "TRUNCATE TABLE $wpdb->term_relationships" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('1','1','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('9','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('10','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('11','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('12','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('13','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('14','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('15','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('16','2','0')" );
	}
}
}

?>