<?php
/**
 * Class to handle the plugin and theme installations as well as initial SQL queries for EWD Quick Starter
 */

if ( !defined( 'ABSPATH' ) )
	exit;

if ( !class_exists( 'EWDQS_Background_Setup' ) ) {
class EWDQS_Background_Setup {

	public function __construct() {

		ob_start();

		$this->install_themes();
		$this->install_plugins();
		$this->install_images();
		$this->handle_SQL_Queries();

		ob_end_clean();

		set_transient('ewdqs-getting-started', true, 30);
	}

	public function install_themes() {
		require_once ABSPATH . 'wp-admin/includes/file.php';
		require_once ABSPATH . 'wp-admin/includes/misc.php';
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
		require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';

		$themes_dir = WP_CONTENT_DIR  . '/themes';

		$installer = new Plugin_Upgrader();

		$themes = array(
			array(
				'package' 		=> 'https://downloads.wordpress.org/theme/gtl-multipurpose.2.0.6.zip',
				'destination'	=> $themes_dir
			),
			array(
				'package' 		=> 'https://downloads.wordpress.org/theme/gutenshop.1.0.zip',
				'destination'	=> $themes_dir
			),
			array(
				'package' 		=> 'https://downloads.wordpress.org/theme/ultimate-showcase.1.16.zip',
				'destination'	=> $themes_dir
			),
		);

		foreach ( $themes as $theme ) {
			$installer->run( $theme );
		}

	}

	public function install_plugins() {
		require_once ABSPATH . 'wp-admin/includes/file.php';
		require_once ABSPATH . 'wp-admin/includes/misc.php';
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
		require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';

		$installer = new Plugin_Upgrader();

		$plugins = array(
			array(
				'package' 		=> 'https://downloads.wordpress.org/plugin/etoile-theme-companion.zip',
				'destination'	=> WP_PLUGIN_DIR
			),
			array(
				'package' 		=> 'https://downloads.wordpress.org/plugin/ultimate-faqs.1.9.0.zip',
				'destination'	=> WP_PLUGIN_DIR
			),
			array(
				'package' 		=> 'https://downloads.wordpress.org/plugin/ultimate-product-catalogue.zip',
				'destination'	=> WP_PLUGIN_DIR
			),
			array(
				'package' 		=> 'https://downloads.wordpress.org/plugin/ultimate-reviews.zip',
				'destination'	=> WP_PLUGIN_DIR
			),
			array(
				'package' 		=> 'https://downloads.wordpress.org/plugin/ultimate-slider.zip',
				'destination'	=> WP_PLUGIN_DIR
			),
			array(
				'package' 		=> 'https://downloads.wordpress.org/plugin/wpforms-lite.1.5.1.3.zip',
				'destination'	=> WP_PLUGIN_DIR
			),
		);

		foreach ( $plugins as $plugin ) {
			$installer->run( $plugin );
		}
	}

	public function install_images() {
		
		$uploads_dir = WP_CONTENT_DIR  . '/uploads/initial_images/';
		$initial_images_dir = EWDQS_DIR . 'initial_images/';

		mkdir( $uploads_dir );

		$files = scandir( $initial_images_dir );

		foreach ( $files as $file ) {
			if ( $file != "." && $file != ".." ) { copy( $initial_images_dir . $file, $uploads_dir . $file ); }
		}
	}

	public function handle_SQL_Queries() {
		global $wpdb;

		$values_array = array(
			'show_on_front' 							=> 'page',
			'page_on_front'								=> '2',
			'ewdqs_active_plugins'						=> 'a:7:{i:0;s:49:"etoile-theme-companion/etoile-theme-companion.php";i:1;s:22:"ultimate-faqs/Main.php";i:2;s:40:"ultimate-product-catalogue/UPCP_Main.php";i:3;s:25:"ultimate-reviews/Main.php";i:4;s:24:"ultimate-slider/Main.php";i:5;s:24:"wpforms-lite/wpforms.php";i:6;s:26:"ewd-quick-starter/Main.php";}',
			'active_plugins' 							=> 'a:7:{i:0;s:49:"etoile-theme-companion/etoile-theme-companion.php";i:1;s:22:"ultimate-faqs/Main.php";i:2;s:40:"ultimate-product-catalogue/UPCP_Main.php";i:3;s:25:"ultimate-reviews/Main.php";i:4;s:24:"ultimate-slider/Main.php";i:5;s:24:"wpforms-lite/wpforms.php";i:6;s:26:"ewd-quick-starter/Main.php";}',
			'template'	 								=> 'ultimate-showcase',
			'stylesheet'								=> 'ultimate-showcase',
			'widget_categories'							=> 'a:2:{i:2;a:4:{s:5:"title";s:0:"";s:5:"count";i:0;s:12:"hierarchical";i:0;s:8:"dropdown";i:0;}s:12:"_multiwidget";i:1;}',
			'fresh_site'								=> '1',
			'widget_search'								=> 'a:2:{i:2;a:1:{s:5:"title";s:0:"";}s:12:"_multiwidget";i:1;}',
			'widget_recent-posts'						=> 'a:2:{i:2;a:2:{s:5:"title";s:0:"";s:6:"number";i:5;}s:12:"_multiwidget";i:1;}',
			'widget_recent-comments'					=> 'a:2:{i:2;a:2:{s:5:"title";s:0:"";s:6:"number";i:5;}s:12:"_multiwidget";i:1;}',
			'widget_archives'							=> 'a:2:{i:2;a:3:{s:5:"title";s:0:"";s:5:"count";i:0;s:8:"dropdown";i:0;}s:12:"_multiwidget";i:1;}',
			'widget_meta'								=> 'a:2:{i:2;a:1:{s:5:"title";s:0:"";}s:12:"_multiwidget";i:1;}',
			'sidebars_widgets'							=> 'a:3:{s:19:"wp_inactive_widgets";a:0:{}s:9:"sidebar-1";a:6:{i:0;s:8:"search-2";i:1;s:14:"recent-posts-2";i:2;s:17:"recent-comments-2";i:3;s:10:"archives-2";i:4;s:12:"categories-2";i:5;s:6:"meta-2";}s:13:"array_version";i:3;}',
			'widget_pages'								=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_calendar'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_audio'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_image'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_gallery'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_media_video'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_tag_cloud'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_nav_menu'							=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'widget_custom_html'						=> 'a:1:{s:12:"_multiwidget";i:1;}',
			'ewdqs_tasks'								=> 'a:9:{i:0;s:17:"EWDQS_Basic_Setup";i:1;s:19:"EWDQS_Show_Overview";i:2;s:21:"EWDQS_Theme_Selection";i:3;s:17:"EWDQS_Pages_Setup";i:4;s:21:"EWDQS_Catalogue_Setup";i:5;s:23:"EWDQS_Featured_Products";i:6;s:18:"EWDQS_UFAQ_Handler";i:7;s:21:"EWDQS_WPForms_Handler";i:8;s:25:"EWDQS_Show_Optional_Steps";}',
			'ewdqs_completed_tasks'						=> 'a:0:{}',
			'ewdqs_pages'								=> 'a:3:{i:0;a:2:{s:9:"page_slug";s:26:"frequently-asked-questions";s:9:"deletable";b:0;}i:1;a:2:{s:9:"page_slug";s:10:"contact-us";s:9:"deletable";b:0;}i:2;a:2:{s:9:"page_slug";s:8:"about-us";s:9:"deletable";b:1;}}',
			'ewdqs_widgets'								=> 'a:7:{i:0;s:11:"widget_text";i:1;s:12:"widget_pages";i:2;s:15:"widget_nav_menu";i:3;s:37:"widget_upcp_theme_testimonials_widget";i:4;s:36:"widget_ewd_ufaq_display_popular_faqs";i:5;s:31:"widget_upcp_product_list_widget";i:6;s:35:"widget_upcp_popular_products_widget";}',
			'ewdqs_theme_options'						=> 'a:3:{i:0;a:4:{s:10:"theme_slug";s:17:"ultimate-showcase";s:10:"theme_name";s:17:"Ultimate Showcase";s:20:"theme_screenshot_url";s:97:"https://i0.wp.com/themes.svn.wordpress.org/ultimate-showcase/1.16/screenshot.png?w=1142&strip=all";s:7:"plugins";a:1:{i:0;s:49:"etoile-theme-companion/etoile-theme-companion.php";}}i:1;a:4:{s:10:"theme_slug";s:9:"gutenshop";s:10:"theme_name";s:9:"Gutenshop";s:20:"theme_screenshot_url";s:88:"https://i0.wp.com/themes.svn.wordpress.org/gutenshop/2.7/screenshot.png?w=1142&strip=all";s:7:"plugins";a:0:{}}i:2;a:4:{s:10:"theme_slug";s:16:"gtl-multipurpose";s:10:"theme_name";s:17:"GTL Multipurpose ";s:20:"theme_screenshot_url";s:97:"https://i0.wp.com/themes.svn.wordpress.org/gtl-multipurpose/2.1.4/screenshot.png?w=1142&strip=all";s:7:"plugins";a:0:{}}}',
			'current_theme'								=> '',
			'theme_mods_ultimate-showcase'				=> 'a:20:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:9:"main-menu";i:2;}s:18:"custom_css_post_id";i:20;s:11:"custom_logo";i:30;s:16:"background_color";s:6:"ffffff";s:29:"upcp_theme_setting_text_color";s:7:"#333333";s:41:"upcp_theme_setting_homepage_slider_enable";s:3:"yes";s:44:"upcp_theme_setting_homepage_jumpboxes_enable";s:3:"yes";s:35:"upcp_theme_setting_catalog_url_text";s:26:"site_url_placeholder/shop/";s:41:"upcp_theme_setting_textonpic_heading_text";s:16:"The Latest Tech!";s:44:"upcp_theme_setting_textonpic_subheading_text";s:69:"All the newest gear from Apple, HP, Samsung, Huawei, Google and more!";s:40:"upcp_theme_setting_textonpic_button_text";s:9:"Shop Tech";s:40:"upcp_theme_setting_textonpic_button_link";s:26:"site_url_placeholder/shop/";s:45:"upcp_theme_setting_textonpic_background_image";s:73:"site_url_placeholder/wp-content/uploads/initial_images/macbookonleft2.jpg";s:39:"upcp_theme_setting_callout_heading_text";s:26:"All The Latest Smartphones";s:42:"upcp_theme_setting_callout_subheading_text";s:92:"We carry the best and newest phones from brands like Apple, Samsung, Huawei, Nokia and more!";s:38:"upcp_theme_setting_callout_button_text";s:11:"Shop Phones";s:38:"upcp_theme_setting_callout_button_link";s:26:"site_url_placeholder/shop/";s:30:"upcp_theme_setting_logo_height";s:4:"32px";s:34:"upcp_theme_setting_logo_top_margin";s:4:"24px";}',
			'theme_plugins_ultimate-showcase'			=> 'a:2:{i:0;s:49:"etoile-theme-companion/etoile-theme-companion.php";i:1;s:24:"ultimate-slider/Main.php";}',
			'theme_objects_ultimate-showcase'			=> 'a:12:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"imacmacbookipad2";s:8:"filename";s:20:"imacmacbookipad2.jpg";s:5:"title";s:34:"Ultimate Slider iMac Macbook Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"macbookipadipone";s:8:"filename";s:20:"macbookipadipone.jpg";s:5:"title";s:28:"Ultimate Slider Macbook iPad";s:7:"content";s:0:"";}i:2;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:14:"macbookonleft2";s:8:"filename";s:18:"macbookonleft2.jpg";s:5:"title";s:17:"Text On Pic Image";s:7:"content";s:0:"";}i:3;a:8:{s:4:"type";s:4:"page";s:4:"name";s:4:"home";s:5:"title";s:4:"Home";s:7:"content";s:254:"<!-- wp:paragraph --><p>Thanks for visiting our shop site. We have all the latest tech and the best prices and customer service in the industry. If you have any questions or need any help, please do not hesitate to get in touch.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:0:"";s:12:"replace_term";s:9:"home_page";s:13:"replace_value";s:7:"post_id";}i:4;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:20:"shop-smart-shop-easy";s:5:"title";s:22:"Shop Smart. Shop Easy.";s:7:"content";s:175:"<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->";s:7:"excerpt";s:125:"We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!";s:9:"thumbnail";s:16:"imacmacbookipad2";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:1;}}s:12:"replace_term";s:33:"imac_macbook_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}i:5;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:26:"great-prices-great-service";s:5:"title";s:28:"Great Prices. Great Service.";s:7:"content";s:147:"<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:97:"We pride ourselves on offering the most up-to-date stock at the best prices you will find online.";s:9:"thumbnail";s:16:"macbookipadipone";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:2;}}s:12:"replace_term";s:33:"macbook_ipad_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}i:6;a:8:{s:4:"type";s:20:"upcp_theme_jumpboxes";s:4:"name";s:19:"everything-you-need";s:5:"title";s:19:"Everything You Need";s:7:"content";s:169:"We have a very large selection of in-stock products. No waiting around or buying from multiple sources. We are your one-stop shop for smartphones, tablets and computers.";s:7:"excerpt";s:65:"We are your one-stop shop for smartphones, tablets and computers.";s:9:"thumbnail";s:0:"";s:12:"replace_term";s:32:"everything_you_need_jumpbox_post";s:13:"replace_value";s:7:"post_id";}i:7;a:8:{s:4:"type";s:20:"upcp_theme_jumpboxes";s:4:"name";s:13:"great-service";s:5:"title";s:13:"Great Service";s:7:"content";s:184:"Our knowledgeable staff lives and breathes tech. We are always up to date on the latest technology and trends. So, if you are uncertain about what you need, be sure to ask our experts.";s:7:"excerpt";s:61:"We are always up to date on the latest technology and trends.";s:9:"thumbnail";s:0:"";s:12:"replace_term";s:26:"great_service_jumpbox_post";s:13:"replace_value";s:7:"post_id";}i:8;a:8:{s:4:"type";s:20:"upcp_theme_jumpboxes";s:4:"name";s:20:"best-price-guarantee";s:5:"title";s:20:"Best Price Guarantee";s:7:"content";s:188:"We offer the best prices you will find online and will not be undersold. If you happen to find one of our items cheaper somewhere else, be sure to get in touch with us and we will beat it.";s:7:"excerpt";s:72:"We offer the best prices you will find online and will not be undersold.";s:9:"thumbnail";s:0:"";s:12:"replace_term";s:23:"best_price_jumpbox_post";s:13:"replace_value";s:7:"post_id";}i:9;a:9:{s:4:"type";s:16:"upcp_theme_testi";s:4:"name";s:15:"testimonial-one";s:5:"title";s:15:"Testimonial One";s:7:"content";s:62:"Buying from Shop Site was a breeze. I will definitely be back!";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:0:"";s:9:"post_meta";a:2:{i:0;a:2:{s:8:"meta_key";s:16:"_testimonialName";s:10:"meta_value";s:17:"Michelle Falsetto";}i:1;a:2:{s:8:"meta_key";s:19:"_testimonialCompany";s:10:"meta_value";s:11:"Widgets ETC";}}s:12:"replace_term";s:20:"one_testimonial_post";s:13:"replace_value";s:7:"post_id";}i:10;a:9:{s:4:"type";s:16:"upcp_theme_testi";s:4:"name";s:15:"testimonial-two";s:5:"title";s:15:"Testimonial Two";s:7:"content";s:49:"Thank you for the great phone and quick shipping!";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:0:"";s:9:"post_meta";a:2:{i:0;a:2:{s:8:"meta_key";s:16:"_testimonialName";s:10:"meta_value";s:15:"Jane Q. Notreal";}i:1;a:2:{s:8:"meta_key";s:19:"_testimonialCompany";s:10:"meta_value";s:18:"Unreal Enterprises";}}s:12:"replace_term";s:20:"two_testimonial_post";s:13:"replace_value";s:7:"post_id";}i:11;a:9:{s:4:"type";s:16:"upcp_theme_testi";s:4:"name";s:17:"testimonial-three";s:5:"title";s:17:"Testimonial Three";s:7:"content";s:93:"Excellent customer service! They helped me pick out the perfect tablet for my small business.";s:7:"excerpt";s:0:"";s:9:"thumbnail";s:0:"";s:9:"post_meta";a:2:{i:0;a:2:{s:8:"meta_key";s:16:"_testimonialName";s:10:"meta_value";s:12:"John Q. Fake";}i:1;a:2:{s:8:"meta_key";s:19:"_testimonialCompany";s:10:"meta_value";s:21:"The Fake Company Inc.";}}s:12:"replace_term";s:22:"three_testimonial_post";s:13:"replace_value";s:7:"post_id";}}}',
			'theme_optional_ultimate-showcase'			=> 'a:6:{i:0;a:3:{s:4:"name";s:22:"Edit Homepage Sections";s:12:"instructions";s:69:"Enable and disable the different sections that appear on the homepage";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:17:"Homepage Sections";s:4:"type";s:3:"url";s:5:"value";s:68:"customize.php?autofocus[section]=upcp_theme_setting_homepage_section";}}}i:1;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:2;a:3:{s:4:"name";s:15:"Edit Jump Boxes";s:12:"instructions";s:95:"These are the three informational boxes that show on the homepage, above the featured products.";s:5:"links";a:3:{i:0;a:3:{s:4:"text";s:7:"Box One";s:4:"type";s:20:"upcp_theme_jumpboxes";s:5:"value";s:19:"everything-you-need";}i:1;a:3:{s:4:"text";s:7:"Box Two";s:4:"type";s:20:"upcp_theme_jumpboxes";s:5:"value";s:13:"great-service";}i:2;a:3:{s:4:"text";s:9:"Box Three";s:4:"type";s:20:"upcp_theme_jumpboxes";s:5:"value";s:20:"best-price-guarantee";}}}i:3;a:3:{s:4:"name";s:17:"Edit Testimonials";s:12:"instructions";s:59:"These are the three testimonials that show on the homepage.";s:5:"links";a:3:{i:0;a:3:{s:4:"text";s:15:"Testimonial One";s:4:"type";s:16:"upcp_theme_testi";s:5:"value";s:15:"testimonial-one";}i:1;a:3:{s:4:"text";s:15:"Testimonial Two";s:4:"type";s:16:"upcp_theme_testi";s:5:"value";s:15:"testimonial-two";}i:2;a:3:{s:4:"text";s:17:"Testimonial Three";s:4:"type";s:16:"upcp_theme_testi";s:5:"value";s:17:"testimonial-three";}}}i:4;a:3:{s:4:"name";s:21:"Edit Text on Pic Area";s:12:"instructions";s:74:"Change the picture and content of the text on picture area on the homepage";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:16:"Edit Text on Pic";s:4:"type";s:3:"url";s:5:"value";s:69:"customize.php?autofocus[section]=upcp_theme_setting_textonpic_section";}}}i:5;a:3:{s:4:"name";s:17:"Edit Callout Area";s:12:"instructions";s:95:"Change the content of the callout promotional area that appears near the bottom of the homepage";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:12:"Edit Callout";s:4:"type";s:3:"url";s:5:"value";s:67:"customize.php?autofocus[section]=upcp_theme_setting_callout_section";}}}}',
			'theme_post_meta_ultimate-showcase'			=> 'a:1:{i:0;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:13:"page-home.php";}}',
			'theme_css_selectors_ultimate-showcase'		=> 'a:1:{s:10:"foreground";s:576:"#menu ul li a:hover {color: $color; border-bottom: 2px solid $color;} #header input:hover {border-color: $color; background: $color;} .ewd-slider-icon:hover {color: $color;} .slideButtons li a:hover {background: $color !important;} .newButton.centerButton:hover {background: $color;} .newButton.whiteButton:hover {background: $color;} .testimonials ul li .testimonialQuote {color: $color;} .calloutArea {background-color: $color;} .singlePage .titleArea {background-color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}";}',
			'theme_page_content_ultimate-showcase'		=> 'a:1:{i:0;a:2:{s:2:"ID";i:2;s:12:"post_content";s:254:"<!-- wp:paragraph --><p>Thanks for visiting our shop site. We have all the latest tech and the best prices and customer service in the industry. If you have any questions or need any help, please do not hesitate to get in touch.</p><!-- /wp:paragraph -->";}}',
			'theme_mods_gutenshop'						=> 'a:7:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:6:"menu-1";i:2;}s:18:"custom_css_post_id";i:21;s:16:"sidebars_widgets";a:2:{s:4:"time";i:1559231965;s:4:"data";a:6:{s:19:"wp_inactive_widgets";a:0:{}s:9:"sidebar-1";a:5:{i:0;s:32:"upcp_theme_testimonials_widget-2";i:1;s:31:"ewd_ufaq_display_popular_faqs-2";i:2;s:6:"text-2";i:3;s:7:"pages-2";i:4;s:32:"upcp_theme_testimonials_widget-3";}s:21:"woocommerce-sidebar-1";a:2:{i:0;s:6:"text-4";i:1;s:30:"upcp_popular_products_widget-3";}s:17:"footer-widget-one";a:0:{}s:17:"footer-widget-two";a:0:{}s:19:"footer-widget-three";a:0:{}}}s:11:"custom_logo";i:30;s:16:"header_textcolor";s:5:"blank";s:15:"hide_navigation";s:0:"";}',
			'theme_plugins_gutenshop'					=> 'a:1:{i:0;s:24:"ultimate-slider/Main.php";}',
			'theme_objects_gutenshop'					=> 'a:7:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"imacmacbookipad2";s:8:"filename";s:20:"imacmacbookipad2.jpg";s:5:"title";s:34:"Ultimate Slider iMac Macbook Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"macbookipadipone";s:8:"filename";s:20:"macbookipadipone.jpg";s:5:"title";s:28:"Ultimate Slider Macbook iPad";s:7:"content";s:0:"";}i:2;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"nohiddenfees";s:8:"filename";s:16:"nohiddenfees.png";s:5:"title";s:28:"Gutenshop Jump Box Image One";s:7:"content";s:0:"";s:12:"replace_term";s:23:"nohiddenfees_attachment";s:13:"replace_value";s:8:"post_url";}i:3;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:15:"customerservice";s:8:"filename";s:19:"customerservice.png";s:5:"title";s:28:"Gutenshop Jump Box Image Two";s:7:"content";s:0:"";s:12:"replace_term";s:26:"customerservice_attachment";s:13:"replace_value";s:8:"post_url";}i:4;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"freeshipping";s:8:"filename";s:16:"freeshipping.png";s:5:"title";s:30:"Gutenshop Jump Box Image Three";s:7:"content";s:0:"";s:12:"replace_term";s:23:"freeshipping_attachment";s:13:"replace_value";s:8:"post_url";}i:5;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:20:"shop-smart-shop-easy";s:5:"title";s:22:"Shop Smart. Shop Easy.";s:7:"content";s:175:"<!-- wp:paragraph --><p>We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!</p><!-- /wp:paragraph -->";s:7:"excerpt";s:125:"We have all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!";s:9:"thumbnail";s:16:"imacmacbookipad2";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:1;}}s:12:"replace_term";s:33:"imac_macbook_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}i:6;a:9:{s:4:"type";s:15:"ultimate_slider";s:4:"name";s:26:"great-prices-great-service";s:5:"title";s:28:"Great Prices. Great Service.";s:7:"content";s:147:"<!-- wp:paragraph --><p>We pride ourselves on offering the most up-to-date stock at the best prices you will find online.</p><!-- /wp:paragraph -->";s:7:"excerpt";s:97:"We pride ourselves on offering the most up-to-date stock at the best prices you will find online.";s:9:"thumbnail";s:16:"macbookipadipone";s:9:"post_meta";a:1:{i:0;a:2:{s:8:"meta_key";s:18:"EWD_US_Slide_Order";s:10:"meta_value";i:2;}}s:12:"replace_term";s:33:"macbook_ipad_ultimate_slider_post";s:13:"replace_value";s:7:"post_id";}}',
			'theme_optional_gutenshop'					=> 'a:3:{i:0;a:3:{s:4:"name";s:20:"Edit Homepage Slides";s:12:"instructions";s:61:"Edit the two slides that are shown at the top of the homepage";s:5:"links";a:2:{i:0;a:3:{s:4:"text";s:9:"Slide One";s:4:"type";s:15:"ultimate_slider";s:5:"value";s:20:"shop-smart-shop-easy";}i:1;a:3:{s:4:"text";s:9:"Slide Two";s:4:"type";s:15:"ultimate_slider";s:5:"value";s:26:"great-prices-great-service";}}}i:1;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:2;a:3:{s:4:"name";s:21:"Edit Homepage Content";s:12:"instructions";s:90:"Edit the content of your homepage, including the three informational boxes that show there";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:13:"Edit Homepage";s:4:"type";s:4:"page";s:5:"value";s:4:"home";}}}}',
			'theme_post_meta_gutenshop'					=> 'a:3:{i:0;a:3:{s:7:"post_id";i:4;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:28:"page-templates/fullwidth.php";}i:1;a:3:{s:7:"post_id";i:3;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:28:"page-templates/fullwidth.php";}i:2;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:31:"page-templates/landing-page.php";}}',
			'theme_css_selectors_gutenshop'				=> 'a:1:{s:10:"foreground";s:338:".ewd-slider-icon:hover {color: $color;} .slideButtons li a:hover {background: $color !important;} .upcp-minimal-title {color: $color;} .upcp-minimal-price {color: $color;} .site-info > a {color: $color;} .footer-info-right > a {color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}";}',
			'theme_page_content_gutenshop'				=> 'a:1:{i:0;a:2:{s:2:"ID";i:2;s:12:"post_content";s:2879:"<!-- wp:ultimate-slider/ewd-us-slider-block /--><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode -->[insert-products catalogue_url="site_url_placeholder/shop/" product_ids="featured_product_ids" product_count="4"]<!-- /wp:shortcode --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="freeshipping_attachment" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="customerservice_attachment" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="nohiddenfees_attachment" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns --><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">New Smartphones</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our latest new stock of smartphones. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode -->[insert-products catalogue_url="site_url_placeholder/shop/" category_id="featured_category_id" product_count="4"]<!-- /wp:shortcode -->";}}',
			'theme_mods_gtl-multipurpose'				=> 'a:20:{i:0;b:0;s:18:"nav_menu_locations";a:1:{s:12:"primary-menu";i:2;}s:16:"sidebars_widgets";a:2:{s:4:"time";i:1559331284;s:4:"data";a:11:{s:19:"wp_inactive_widgets";a:0:{}s:9:"sidebar-1";a:7:{i:0;s:32:"upcp_theme_testimonials_widget-2";i:1;s:31:"ewd_ufaq_display_popular_faqs-2";i:2;s:6:"text-2";i:3;s:7:"pages-2";i:4;s:32:"upcp_theme_testimonials_widget-3";i:5;s:6:"text-4";i:6;s:30:"upcp_popular_products_widget-3";}s:16:"gtl-blog-sidebar";a:0:{}s:16:"gtl-shop-sidebar";a:0:{}s:13:"gtl-sidebar-2";a:0:{}s:13:"gtl-sidebar-3";a:0:{}s:13:"gtl-sidebar-4";a:0:{}s:13:"gtl-sidebar-5";a:0:{}s:12:"gtl-footer-1";a:0:{}s:12:"gtl-footer-2";a:0:{}s:12:"gtl-footer-3";a:0:{}}}s:18:"custom_css_post_id";i:22;s:12:"slider_speed";i:8000;s:14:"slider_title_1";s:22:"Shop Smart. Shop Easy.";s:17:"slider_subtitle_1";s:127:"We\'ve got all the latest electronics, including smartphones, tablets and computers. All at great prices and with great service!";s:18:"slider_cta_1_label";s:8:"Shop Now";s:16:"slider_cta_1_url";s:1:"#";s:14:"slider_title_2";s:28:"Great Prices. Great Service.";s:17:"slider_subtitle_2";s:97:"We pride ourselves on offering the most up-to-date stock at the best prices you will find online.";s:18:"slider_cta_2_label";s:10:"Go to Shop";s:16:"slider_cta_2_url";s:1:"#";s:11:"custom_logo";i:30;s:16:"header_textcolor";s:5:"blank";s:16:"site_layout_type";s:17:"full-width-layout";s:19:"site_container_type";s:15:"container-large";s:16:"page_sidebar_pos";s:5:"right";s:19:"footer_widget_areas";s:1:"3";s:14:"slider_image_2";s:75:"site_url_placeholder/wp-content/uploads/initial_images/imacmacbookipad2.jpg";}',
			'theme_plugins_gtl-multipurpose'			=> 'a:0:{}',
			'theme_objects_gtl-multipurpose'			=> 'a:5:{i:0;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:10:"gtlslider1";s:8:"filename";s:14:"gtlslider1.jpg";s:5:"title";s:21:"GTL Slider Fist Image";s:7:"content";s:0:"";}i:1;a:5:{s:4:"type";s:10:"attachment";s:4:"name";s:16:"imacmacbookipad2";s:8:"filename";s:20:"imacmacbookipad2.jpg";s:5:"title";s:23:"GTL Slider Second Image";s:7:"content";s:0:"";}i:2;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"nohiddenfees";s:8:"filename";s:16:"nohiddenfees.png";s:5:"title";s:28:"Gutenshop Jump Box Image One";s:7:"content";s:0:"";s:12:"replace_term";s:23:"nohiddenfees_attachment";s:13:"replace_value";s:8:"post_url";}i:3;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:15:"customerservice";s:8:"filename";s:19:"customerservice.png";s:5:"title";s:28:"Gutenshop Jump Box Image Two";s:7:"content";s:0:"";s:12:"replace_term";s:26:"customerservice_attachment";s:13:"replace_value";s:8:"post_url";}i:4;a:7:{s:4:"type";s:10:"attachment";s:4:"name";s:12:"freeshipping";s:8:"filename";s:16:"freeshipping.png";s:5:"title";s:30:"Gutenshop Jump Box Image Three";s:7:"content";s:0:"";s:12:"replace_term";s:23:"freeshipping_attachment";s:13:"replace_value";s:8:"post_url";}}',
			'theme_optional_gtl-multipurpose'			=> 'a:3:{i:0;a:3:{s:4:"name";s:20:"Edit Homepage Slider";s:12:"instructions";s:59:"Choose what images and content show on the homepage slider.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:11:"Edit Slider";s:4:"type";s:3:"url";s:5:"value";s:43:"customize.php?autofocus[section]=gtl_slider";}}}i:1;a:3:{s:4:"name";s:10:"Add a Logo";s:12:"instructions";s:109:"Add your logo to the header of your site, so that visitors know that they are on the right website instantly.";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:8:"Set Logo";s:4:"type";s:3:"url";s:5:"value";s:46:"customize.php?autofocus[section]=title_tagline";}}}i:2;a:3:{s:4:"name";s:21:"Edit Homepage Content";s:12:"instructions";s:90:"Edit the content of your homepage, including the three informational boxes that show there";s:5:"links";a:1:{i:0;a:3:{s:4:"text";s:13:"Edit Homepage";s:4:"type";s:4:"page";s:5:"value";s:4:"home";}}}}',
			'theme_post_meta_gtl-multipurpose'			=> 'a:1:{i:0;a:3:{s:7:"post_id";i:2;s:8:"meta_key";s:17:"_wp_page_template";s:10:"meta_value";s:17:"template-home.php";}}',
			'theme_css_selectors_gtl-multipurpose'		=> 'a:1:{s:10:"foreground";s:419:"nav ul > li.current-menu-item {background-color: $color;} .custom-btn.secondary-btn, .wpcf7-submit {background-color: $color;} .flex-prev {color: $color;} .flex-prev:hover {color: $color;} .flex-next {color: $color;} .flex-next:hover {color: $color;} .upcp-minimal-title {color: $color;} .upcp-minimal-price {color: $color;} div.wpforms-container-full .wpforms-form button[type=submit]:hover {background-color: $color;}";}',
			'theme_page_content_gtl-multipurpose'		=> 'a:1:{i:0;a:2:{s:2:"ID";i:2;s:12:"post_content";s:2879:"<!-- wp:ultimate-slider/ewd-us-slider-block /--><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">Featured Products</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our featured products. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode -->[insert-products catalogue_url="site_url_placeholder/shop/" product_ids="featured_product_ids" product_count="4"]<!-- /wp:shortcode --><!-- wp:columns {"columns":3} --><div class="wp-block-columns has-3-columns"><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":209} --><figure class="wp-block-image"><img class="wp-image-209" src="freeshipping_attachment" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>Free Shipping</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":210} --><figure class="wp-block-image"><img class="wp-image-210" src="customerservice_attachment" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>24/7 Customer Service</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --><!-- wp:column --><div class="wp-block-column"><!-- wp:image {"id":211} --><figure class="wp-block-image"><img class="wp-image-211" src="nohiddenfees_attachment" alt="" /></figure><!-- /wp:image --><!-- wp:heading {"level":3} --><h3>No Hidden Fees</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Sed ut unde omnis iste natus fringilla tempor dignissim at, pretium et arcu. Sed ut unde omnis iste tempor dignissim at.</p><!-- /wp:paragraph --></div><!-- /wp:column --></div><!-- /wp:columns --><!-- wp:heading {"align":"center","className":"newsmartphoneshomeheading"} --><h2 class="newsmartphoneshomeheading" style="text-align: center;">New Smartphones</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"center","className":"newsmartphoneshome"} --><p class="newsmartphoneshome" style="text-align: center;">Check out our latest new stock of smartphones. We have several different brands and models, with options that feature the latest tech and also budget conscious choices.</p><!-- /wp:paragraph --><!-- wp:shortcode -->[insert-products catalogue_url="site_url_placeholder/shop/" category_id="featured_category_id" product_count="4"]<!-- /wp:shortcode -->";}}',
			'sidebars_widgets' 							=> '.a:6:{s:19:"wp_inactive_widgets";a:0:{}s:14:"sidebar_widget";a:2:{i:0;s:32:"upcp_theme_testimonials_widget-2";i:1;s:31:"ewd_ufaq_display_popular_faqs-2";}s:19:"sidebar_widget_blog";a:0:{}s:13:"footer_widget";a:0:{}s:9:"sidebar-1";a:0:{}s:13:"array_version";i:3;}',
			'widget_text'								=> 'a:5:{i:1;a:0:{}i:2;a:4:{s:5:\"title\";s:8:\"Location\";s:4:\"text\";s:48:\"123 Lollipop Lane\r\nMunchkinland, Oz\r\n555-555-555\";s:6:\"filter\";b:1;s:6:\"visual\";b:1;}i:4;a:4:{s:5:\"title\";s:17:\"Featured Products\";s:4:\"text\";s:0:\"\";s:6:\"filter\";b:1;s:6:\"visual\";b:1;}i:5;a:4:{s:5:\"title\";s:12:\"Get in Touch\";s:4:\"text\";s:48:\"889 Grove Street\r\nLos Santos\r\nSan Andreas\r\n12345\";s:6:\"filter\";b:1;s:6:\"visual\";b:1;}s:12:\"_multiwidget\";i:1;}',
			'widget_pages' 								=> 'a:2:{i:2;a:3:{s:5:\"title\";s:8:\"Sections\";s:6:\"sortby\";s:10:\"post_title\";s:7:\"exclude\";s:0:\"\";}s:12:\"_multiwidget\";i:1;}',
			'widget_nav_menu' 							=> 'a:2:{i:2;a:2:{s:5:\"title\";s:8:\"Sections\";s:8:\"nav_menu\";i:2;}s:12:\"_multiwidget\";i:1;}',
			'widget_upcp_theme_testimonials_widget' 	=> 'a:5:{i:2;a:2:{s:5:\"title\";s:14:\"What You Think\";s:17:\"which_testimonial\";s:17:\"randomTestimonial\";}i:3;a:2:{s:5:\"title\";s:11:\"Testimonial\";s:17:\"which_testimonial\";s:17:\"randomTestimonial\";}i:4;a:2:{s:5:\"title\";s:14:\"What You Think\";s:17:\"which_testimonial\";s:17:\"randomTestimonial\";}i:5;a:2:{s:5:\"title\";s:11:\"Testimonial\";s:17:\"which_testimonial\";s:17:\"randomTestimonial\";}s:12:\"_multiwidget\";i:1;}',
			'widget_ewd_ufaq_display_popular_faqs' 		=> 'a:3:{i:2;a:2:{s:10:\"post_count\";s:1:\"2\";s:9:\"faq_title\";s:12:\"Popular FAQs\";}i:3;a:2:{s:10:\"post_count\";s:1:\"5\";s:9:\"faq_title\";s:12:\"Popular FAQs\";}s:12:\"_multiwidget\";i:1;}',
			'widget_upcp_product_list_widget' 			=> 'a:2:{i:2;a:3:{s:12:\"product_list\";s:20:\"featured_product_ids\";s:13:\"catalogue_url\";s:26:\"site_url_placeholder/shop/\";s:16:\"products_per_row\";s:1:\"4\";}s:12:\"_multiwidget\";i:1;}',
			'widget_upcp_popular_products_widget' 		=> 'a:2:{s:12:\"_multiwidget\";i:1;i:3;a:3:{s:12:\"catalogue_id\";s:1:\"1\";s:13:\"product_count\";s:1:\"4\";s:13:\"catalogue_url\";s:26:\"site_url_placeholder/shop/\";}}'
		);

		foreach ( $values_array as $option_name => $option_value ) {
			$option = get_option( $option_name, 'Not Found' );

			if ( $option == 'Not Found' ) { $wpdb->query( "INSERT INTO $wpdb->options ( option_name, option_value ) VALUES ('" . $option_name . "','" . $option_value ."')" );  }
			else { $wpdb->query( "UPDATE $wpdb->options SET option_value = '" . $option_value . "' WHERE option_name='" . $option_name . "'" ); }
		}

		$values_array = array(
			array(
			 	'meta_id'	=> 1,
			 	'post_id'	=> 5,
			 	'meta_key'	=> '_wp_page_template',
			 	'meta_value'	=> 'page-sidebar.php'
			),
			array(
			 	'meta_id'	=> 2,
			 	'post_id'	=> 30,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/shop-logo-blue2.png'
			),
			array(
			 	'meta_id'	=> 3,
			 	'post_id'	=> 30,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:895;s:6:"height";i:146;s:4:"file";s:27:"2019/04/shop-logo-blue2.png";s:5:"sizes";a:3:{s:9:"thumbnail";a:4:{s:4:"file";s:27:"shop-logo-blue2-150x146.png";s:5:"width";i:150;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:6:"medium";a:4:{s:4:"file";s:26:"shop-logo-blue2-300x49.png";s:5:"width";i:300;s:6:"height";i:49;s:9:"mime-type";s:9:"image/png";}s:12:"medium_large";a:4:{s:4:"file";s:27:"shop-logo-blue2-768x125.png";s:5:"width";i:768;s:6:"height";i:125;s:9:"mime-type";s:9:"image/png";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}'
			),
			array(
			 	'meta_id'	=> 4,
			 	'post_id'	=> 31,
			 	'meta_key'	=> '_wp_attached_file',
			 	'meta_value'	=> 'initial_images/shop-logo-white.png'
			),
			array(
			 	'meta_id'	=> 5,
			 	'post_id'	=> 31,
			 	'meta_key'	=> '_wp_attachment_metadata',
			 	'meta_value'	=> 'a:5:{s:5:"width";i:895;s:6:"height";i:146;s:4:"file";s:27:"2019/04/shop-logo-white.png";s:5:"sizes";a:9:{s:9:"thumbnail";a:4:{s:4:"file";s:27:"shop-logo-white-150x146.png";s:5:"width";i:150;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:6:"medium";a:4:{s:4:"file";s:26:"shop-logo-white-300x49.png";s:5:"width";i:300;s:6:"height";i:49;s:9:"mime-type";s:9:"image/png";}s:12:"medium_large";a:4:{s:4:"file";s:27:"shop-logo-white-768x125.png";s:5:"width";i:768;s:6:"height";i:125;s:9:"mime-type";s:9:"image/png";}s:28:"gtl-multipurpose-img-525-350";a:4:{s:4:"file";s:27:"shop-logo-white-525x146.png";s:5:"width";i:525;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:28:"gtl-multipurpose-img-585-500";a:4:{s:4:"file";s:27:"shop-logo-white-585x146.png";s:5:"width";i:585;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:28:"gtl-multipurpose-img-330-200";a:4:{s:4:"file";s:27:"shop-logo-white-330x146.png";s:5:"width";i:330;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:28:"gtl-multipurpose-img-250-380";a:4:{s:4:"file";s:27:"shop-logo-white-250x146.png";s:5:"width";i:250;s:6:"height";i:146;s:9:"mime-type";s:9:"image/png";}s:27:"gtl-multipurpose-img-105-70";a:4:{s:4:"file";s:26:"shop-logo-white-105x70.png";s:5:"width";i:105;s:6:"height";i:70;s:9:"mime-type";s:9:"image/png";}s:26:"gtl-multipurpose-img-46-54";a:4:{s:4:"file";s:25:"shop-logo-white-46x54.png";s:5:"width";i:46;s:6:"height";i:54;s:9:"mime-type";s:9:"image/png";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}'
			),
			array(
				'meta_id'	=> 180,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 181,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 182,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '6'
			),
			array(
				'meta_id'	=> 183,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 184,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> '')
			,
			array(
				'meta_id'	=> 185,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:
				1:{i:0;s:0:\"\";}'),
			array(
				'meta_id'	=> 186,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> '')
			,
			array(
				'meta_id'	=> 187,
				'post_id'  	=> 10,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> '')
			,
			array(
				'meta_id'	=> 189,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 190,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 191,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '5'
			),
			array(
				'meta_id'	=> 192,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 193,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 194,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 195,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 196,
				'post_id'  	=> 11,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 198,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 199,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 200,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '4'
			),
			array(
				'meta_id'	=> 201,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 202,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 203,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 204,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 205,
				'post_id'  	=> 12,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 207,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 208,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 209,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '3'
			),
			array(
				'meta_id'	=> 210,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 211,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 212,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 213,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 214,
				'post_id'  	=> 13,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 216,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 217,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 218,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '2'
			),
			array(
				'meta_id'	=> 219,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 220,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 221,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 222,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 223,
				'post_id'  	=> 14,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 225,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_type',
				'meta_value'	=> 'post_type'
			),
			array(
				'meta_id'	=> 226,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_menu_item_parent',
				'meta_value'	=> '0'
			),
			array(
				'meta_id'	=> 227,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_object_id',
				'meta_value'	=> '1'
			),
			array(
				'meta_id'	=> 228,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_object',
				'meta_value'	=> 'page'
			),
			array(
				'meta_id'	=> 229,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_target',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 230,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_classes',
				'meta_value'	=> 'a:1:{i:0;s:0:\"\";}'
			),
			array(
				'meta_id'	=> 231,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_xfn',
				'meta_value'	=> ''
			),
			array(
				'meta_id'	=> 232,
				'post_id'  	=> 15,
				'meta_key'	=> '_menu_item_url',
				'meta_value'	=> ''
			)
		);

		$wpdb->query( "TRUNCATE TABLE $wpdb->postmeta" );
		foreach ( $values_array as $value ) {
			$wpdb->query( "INSERT INTO $wpdb->postmeta ( meta_id, post_id, meta_key, meta_value ) VALUES ('" . $value['meta_id'] . "','" . $value['post_id'] ."','" . $value['meta_key'] ."','" . $value['meta_value'] ."')" );
		}

		$values_array = array(
			array(
				'ID' 			=> 1,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:heading --><h2>Who we are</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Our website address is: [[softurl]].</p><!-- /wp:paragraph --><!-- wp:heading --><h2>What personal data we collect and why we collect it</h2><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Comments</h3><!-- /wp:heading --><!-- wp:paragraph --><p>When visitors leave comments on the site we collect the data shown in the comments form, and also the visitor&#8217;s IP address and browser user agent string to help spam detection.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>An anonymized string created from your email address (also called a hash) may be provided to the Gravatar service to see if you are using it. The Gravatar service privacy policy is available here: https://automattic.com/privacy/. After approval of your comment, your profile picture is visible to the public in the context of your comment.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Media</h3><!-- /wp:heading --><!-- wp:paragraph --><p>If you upload images to the website, you should avoid uploading images with embedded location data (EXIF GPS) included. Visitors to the website can download and extract any location data from images on the website.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Contact forms</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Cookies</h3><!-- /wp:heading --><!-- wp:paragraph --><p>If you leave a comment on our site you may opt-in to saving your name, email address and website in cookies. These are for your convenience so that you do not have to fill in your details again when you leave another comment. These cookies will last for one year.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>If you have an account and you log in to this site, we will set a temporary cookie to determine if your browser accepts cookies. This cookie contains no personal data and is discarded when you close your browser.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>When you log in, we will also set up several cookies to save your login information and your screen display choices. Login cookies last for two days, and screen options cookies last for a year. If you select &quot;Remember Me&quot;, your login will persist for two weeks. If you log out of your account, the login cookies will be removed.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>If you edit or publish an article, an additional cookie will be saved in your browser. This cookie includes no personal data and simply indicates the post ID of the article you just edited. It expires after 1 day.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Embedded content from other websites</h3><!-- /wp:heading --><!-- wp:paragraph --><p>Articles on this site may include embedded content (e.g. videos, images, articles, etc.). Embedded content from other websites behaves in the exact same way as if the visitor has visited the other website.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>These websites may collect data about you, use cookies, embed additional third-party tracking, and monitor your interaction with that embedded content, including tracking your interaction with the embedded content if you have an account and are logged in to that website.</p><!-- /wp:paragraph --><!-- wp:heading {"level":3} --><h3>Analytics</h3><!-- /wp:heading --><!-- wp:heading --><h2>Who we share your data with</h2><!-- /wp:heading --><!-- wp:heading --><h2>How long we retain your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>If you leave a comment, the comment and its metadata are retained indefinitely. This is so we can recognize and approve any follow-up comments automatically instead of holding them in a moderation queue.</p><!-- /wp:paragraph --><!-- wp:paragraph --><p>For users that register on our website (if any), we also store the personal information they provide in their user profile. All users can see, edit, or delete their personal information at any time (except they cannot change their username). Website administrators can also see and edit that information.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>What rights you have over your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>If you have an account on this site, or have left comments, you can request to receive an exported file of the personal data we hold about you, including any data you have provided to us. You can also request that we erase any personal data we hold about you. This does not include any data we are obliged to keep for administrative, legal, or security purposes.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>Where we send your data</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Visitor comments may be checked through an automated spam detection service.</p><!-- /wp:paragraph --><!-- wp:heading --><h2>Your contact information</h2><!-- /wp:heading --><!-- wp:heading --><h2>Additional information</h2><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>How we protect your data</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What data breach procedures we have in place</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What third parties we receive data from</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>What automated decision making and/or profiling we do with user data</h3><!-- /wp:heading --><!-- wp:heading {"level":3} --><h3>Industry regulatory disclosure requirements</h3><!-- /wp:heading -->',
				'post_title'	=> 'Privacy Policy',
				'post_excerpt'	=> '',
				'post_status'	=> 'draft',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'privacy-policy',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=1',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 2,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Welcome to our shop site!</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Home',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'home',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=2',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 3,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>[product-catalog].</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Shop',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'shop',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=3',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 4,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Shop Information:<br/>[ultimate-faqs]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Frequently Asked Questions',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'frequently-asked-questions',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=4',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 5,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Talk about what makes your shop unique, things like your values, your staff or your product offering on this page.</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'About Us',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'about-us',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=5',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 6,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '<!-- wp:paragraph -->\n<p>Please use the form below to get in touch with us:[contact_form]</p>\n<!-- /wp:paragraph -->',
				'post_title'	=> 'Contact Us',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'contact-us',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=6',
				'menu_order'	=> 0,
				'post_type'		=> 'page',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 10,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '10',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=10',
				'menu_order'	=> 5,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 11,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '11',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=11',
				'menu_order'	=> 4,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 12,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '12',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=12',
				'menu_order'	=> 3,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 13,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '13',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=13',
				'menu_order'	=> 2,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 14,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> ' ',
				'post_title'	=> '',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> '14',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=14',
				'menu_order'	=> 1,
				'post_type'		=> 'nav_menu_item',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 20,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> 'hr.starHR {\n overflow: visible;\n}\n.textOnPic {\n background-size: cover !important;\n}\n\n/*faq page*/\n.ufaq-faq-category-title {\n margin-bottom: 20px\n}\n.ufaq-faq-category-title h3 {\n font-size: 20px;\n  letter-spacing: 0;\n}\n.ufaq-faq-title-text h4 {\n  text-transform: initial;\n  letter-spacing: 0;\n}\n.ewd-ufaq-post-margin-symbol {\n margin-top: 5px;\n}\n.ufaq-faq-title {\n  padding: 1px\n}\n.ufaq-faq-post {\n margin: 0 0 20px;\n line-height: 1.5;\n}\n.ewd-ufaq-author-date {\n margin-bottom: 13px;\n}\n.ewd-ufaq-date {\nfont-weight: normal;\n}\n.ufaq-faq-categories {\nfont-weight: bold;\n}\n.ufaq-faq-categories a {\nfont-weight: normal;\n}\n.ufaq-back-to-top-link {\nfont-size: 13px;\ntext-transform: uppercase;\nfont-weight: bold;\n}\n.ufaq-permalink-image {\nmargin-top: -22px;\nmargin-left: 82px;\n}\n\n/*contact us page*/\ndiv.wpforms-container-full .wpforms-form input.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form .wpforms-field-row.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 100%;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n background-color: #34ADCF;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\n background-color: #6BCEEA;\n  border: none;\n}\n\n/*faq widget*/\n.widgetBox .ufaq-faq-title-text {\n width: 80%;\n}\n.widgetBox .ufaq-faq-display-style-Contemporary .ewd-ufaq-post-margin-symbol {\n  margin-top: 4px;\n}\n.widgetBox .ufaq-faq-category-title {\n  display: none;\n}\n.widgetBox .ufaq-faq-category,\n.widgetBox .ufaq-faq-category-inner {\n  margin-bottom: 0\n}\n',
				'post_title'	=> 'ultimate-showcase',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'ultimate-showcase',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=20',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 21,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '/*general*/\n@media print, screen and (min-width: 64em) {\n.grid-x > .large-3 {\n    width: 20%;\n}\n}\n\n\n/*homepage*/\n.home #page.grid-container {\n  max-width: none;\n}\n.home .footer-container #page {\n  max-width: 75rem;\n}\n.ewd-slider-section {\n width: calc(100% + 80px);\n margin-left: -40px;\n margin-top: -50px;\n}\n.slideExcerpt p {\n  color: #fff;\n  margin-bottom: 45px;\n}\n\n.home .upcp-minimal-catalogue {\n  position: relative;\n float: left;\n  width: 100%;\n  height: auto;\n margin-top: 40px;\n margin-bottom: 40px;\n}\n.home .upcp-minimal-product-listing {\n  position: relative;\n float: left;\n  width: 20%;\n height: auto !important;\n  margin: 0 2.5%;\n}\n@media screen and (max-width: 900px) {\n  .home .upcp-minimal-product-listing {\n   width: 45%;\n }\n}\n.home .upcp-minimal-img-div {\n width: 100%;\n  height: 200px;\n  overflow: hidden;\n border: none;\n}\n.home .upcp-minimal-img {\n max-height: none !important;\n  max-width: none !important;\n width: 130%;\n  margin-left: -15%;\n  height: auto;\n}\n@media screen and (max-width: 1400px) {\n .home .upcp-minimal-img {\n   width: 180%;\n    margin-left: -40%;\n  }\n}\n.home .upcp-minimal-link {\n  color: #333;\n  font-size: 15px\n}\n.home .upcp-minimal-price {\n font-weight: normal;\n}\n\n.home .wp-block-columns {\n  max-width: 95%;\n margin: 40px 2.5% 50px;\n border-top: 1px solid #ddd;\n border-bottom: 1px solid #ddd;\n  padding: 40px 40px 10px;\n  text-align: center;\n}\n.home .wp-block-columns .wp-block-image img {\n max-width: 120px;\n}\n.home h2.newsmartphoneshomeheading {\n  padding-bottom: 15px;;\n}\n.home p.newsmartphoneshome {\n max-width: 50%;\n margin: 0 25% 20px;\n}\n\n\n/*faq page*/\n.ufaq-faq-category-title {\n  margin-bottom: 20px\n}\n.ufaq-faq-category-title h3 {\n font-size: 20px;\n  letter-spacing: 0;\n}\n.ufaq-faq-title-text h4 {\n  text-transform: initial;\n  letter-spacing: 0;\n}\n.ewd-ufaq-post-margin-symbol {\n margin-top: 9px;\n}\n.ewd-ufaq-post-margin-symbol span {\n  font-family: \'ewd-toggle-icon\';\n}\n.ufaq-faq-title {\n padding: 1px\n}\n.ufaq-faq-post {\n margin: 0 0 0px;\n  line-height: 1.5;\n}\n.ewd-ufaq-author-date {\n margin-bottom: 13px;\n}\n.ewd-ufaq-date {\nfont-weight: normal;\n}\n.ufaq-faq-categories {\nfont-weight: bold;\n}\n.ufaq-faq-categories a {\nfont-weight: normal;\n}\n.ufaq-back-to-top-link {\nfont-size: 13px;\ntext-transform: uppercase;\nfont-weight: bold;\n}\n.ufaq-permalink-image {\nmargin-top: -28px;\nmargin-left: 90px;\n}\n\n\n/*contact us page*/\ndiv.wpforms-container-full .wpforms-form input.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form .wpforms-field-row.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 100%;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n background-color: #34ADCF;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\n background-color: #6BCEEA;\n  border: none;\n}\n\n\n/*product page*/\n.upcp-product-page button[type=submit] {\n  background-color: #34ADCF !important;\n padding: 14px 32px !important;\n  color: #fff !important;\n border: none !important;\n  cursor: pointer !important;\n}\n.upcp-product-page button[type=submit]:hover {\n  background-color: #6BCEEA !important;\n border: none !important;\n}\n\n\n/*faq widget*/\n.widget .ufaq-faq-div {\n  margin: 0;\n}\n.widget .ufaq-faq-title-text {\n width: 80%;\n}\n.widget .ewd-ufaq-post-margin-symbol {\n  margin-top: 6px;\n}\n.widget .ufaq-faq-category-title {\n display: none;\n}\n.widget .ufaq-faq-category,\n.widget .ufaq-faq-category-inner {\n  margin-bottom: 0\n}\n.widget .ufaq-faq-title-text h4 {\n  border: none !important;\n}\n\n\n/*testimonial widget*/\n.widget .testimonialQuote {\n  display: none;\n}',
				'post_title'	=> 'gutenshop',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'gutenshop',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=21',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 22,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> '/*general*/\nbody a {\n  color: #34adcf;\n}\na:hover {\ncolor: #6BCEEA;\n}\n.custom-logo {\n max-width: 186px !important;\n}\n.page-id-3 .is-sidebar,\n.page-id-4 .is-sidebar {\n display: none;\n}\n.page-id-3 .col_2-70-30 .cols:nth-child(1),\n.page-id-4 .col_2-70-30 .cols:nth-child(1){\n  grid-column: span 10;\n}\nnav ul li:hover, nav ul li.active-page, nav ul > li.current-menu-item {\n background-color: #34adcf;\n}\n.custom-btn.secondary-btn, .wpcf7-submit {\n background-color: #34adcf;\n}\n.custom-btn.secondary-btn:hover, .wpcf7-submit:hover {\n background-color: #6BCEEA;\n}\n\n\n/*homepage*/\n.ewd-slider-section {\n  display: none;\n}\n.home .upcp-minimal-catalogue {\n  position: relative;\n float: left;\n  width: 100%;\n  height: auto;\n margin-top: 40px;\n margin-bottom: 40px;\n}\n.home .upcp-minimal-product-listing {\n  position: relative;\n float: left;\n  width: 20%;\n height: auto !important;\n  margin: 0 2.5%;\n}\n@media screen and (max-width: 900px) {\n  .home .upcp-minimal-product-listing {\n   width: 45%;\n }\n}\n.home .upcp-minimal-img-div {\n width: 100%;\n  height: 200px;\n  overflow: hidden;\n border: none;\n}\n.home .upcp-minimal-img {\n max-height: none !important;\n  max-width: none !important;\n width: 130%;\n  margin-left: -15%;\n  height: auto;\n}\n@media screen and (max-width: 1400px) {\n .home .upcp-minimal-img {\n   width: 180%;\n    margin-left: -40%;\n  }\n}\n.home .upcp-minimal-link {\n  color: #333;\n  font-size: 15px\n}\n.home .upcp-minimal-price {\n font-weight: normal;\n}\n\n.home .wp-block-columns {\n  width: 100%;\n  margin: 40px 0 50px;\n  border: none;\n padding: 60px 40px;\n text-align: center;\n background: #f6f6f6;\n}\n.home .wp-block-columns .wp-block-image img {\n  max-width: 120px;\n}\n.home h2.newsmartphoneshomeheading {\n  padding-bottom: 15px;\n margin-top: 70px;\n}\n.home p.newsmartphoneshome {\n  max-width: 50%;\n margin: 0 25% 20px;\n}\n\n\n/*faq page*/\n.ufaq-faq-category-title {\n  margin-bottom: 20px\n}\n.ufaq-faq-category-title h3 {\n font-size: 20px;\n  letter-spacing: 0;\n}\n.ufaq-faq-title-text h4 {\n  text-transform: initial;\n  letter-spacing: 0;\n}\n.ewd-ufaq-post-margin-symbol {\n margin-top: 9px;\n}\n.ewd-ufaq-post-margin-symbol span {\n  font-family: \'ewd-toggle-icon\';\n}\n.ufaq-faq-title {\n padding: 1px\n}\n.ufaq-faq-post {\n margin: 0 0 0px;\n  line-height: 1.5;\n}\n.ewd-ufaq-author-date {\n margin-bottom: 13px;\n}\n.ewd-ufaq-date {\nfont-weight: normal;\n}\n.ufaq-faq-categories {\nfont-weight: bold;\n}\n.ufaq-faq-categories a {\nfont-weight: normal;\n}\n.ufaq-back-to-top-link {\nfont-size: 13px;\ntext-transform: uppercase;\nfont-weight: bold;\n}\n.ufaq-permalink-image {\nmargin-top: -28px;\nmargin-left: 90px;\n}\n\n\n/*contact us page*/\ndiv.wpforms-container-full .wpforms-form input.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form .wpforms-field-row.wpforms-field-medium,\ndiv.wpforms-container-full .wpforms-form textarea {\n  max-width: 100%;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit] {\n background-color: #34ADCF;\n  padding: 14px 32px;\n color: #fff;\n  border: none;\n cursor: pointer;\n}\ndiv.wpforms-container-full .wpforms-form button[type=submit]:hover {\n background-color: #6BCEEA;\n  border: none;\n}\n\n\n/*product page*/\n.upcp-product-page button[type=submit] {\n  background-color: #34ADCF !important;\n padding: 14px 32px !important;\n  color: #fff !important;\n border: none !important;\n  cursor: pointer !important;\n}\n.upcp-product-page button[type=submit]:hover {\n  background-color: #6BCEEA !important;\n border: none !important;\n}\n\n\n/*faq widget*/\n.widget_ewd_ufaq_display_popular_faqs .ufaq-faq-div {\n  margin: 0;\n}\n.widget_ewd_ufaq_display_popular_faqs .ufaq-faq-title-text {\n width: 80%;\n}\n.widget_ewd_ufaq_display_popular_faqs .ewd-ufaq-post-margin-symbol {\n  margin-top: 6px;\n}\n.widget_ewd_ufaq_display_popular_faqs .ufaq-faq-category-title {\n display: none;\n}\n.widget_ewd_ufaq_display_popular_faqs .ufaq-faq-category,\n.widget_ewd_ufaq_display_popular_faqs .ufaq-faq-category-inner {\n  margin-bottom: 0\n}\n.widget_ewd_ufaq_display_popular_faqs .ufaq-faq-title-text h4 {\n  border: none !important;\n}\n\n\n/*testimonial widget*/\n.widget_upcp_theme_testimonials_widget .testimonialQuote {\n display: none;\n}\n\n\n/*footer*/\n#footer .upcp-minimal-title,\n#footer .upcp-minimal-price {\n  display: none;\n}',
				'post_title'	=> 'gtl-multipurpose',
				'post_excerpt'	=> '',
				'post_status'	=> 'publish',
				'comment_status'=> 'closed',
				'ping_status'	=> 'open',
				'post_password'	=> '',
				'post_name'		=> 'gtl-multipurpose',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/?page_id=22',
				'menu_order'	=> 0,
				'post_type'		=> 'custom_css',
				'post_mime_type'=> '',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 30,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/shop-logo-blue2.png',
				'post_title'	=> 'shop-logo-blue2',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'shop-logo-blue2',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/shop-logo-blue2.png',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			),
			array(
				'ID' 			=> 31,
				'post_author'	=> 1,
				'post_date'		=> date("Y-m-d H:i:s"),
				'post_date_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content'	=> get_site_url() . '/wp-content/uploads/initial_images/shop-logo-white.png',
				'post_title'	=> 'shop-logo-white',
				'post_excerpt'	=> '',
				'post_status'	=> 'inherit',
				'comment_status'=> 'open',
				'ping_status'	=> 'closed',
				'post_password'	=> '',
				'post_name'		=> 'shop-logo-white',
				'to_ping'		=> '',
				'pinged'		=> '',
				'post_modified'	=> date("Y-m-d H:i:s"),
				'post_modified_gmt'	=> gmdate("Y-m-d H:i:s"),
				'post_content_filtered' => '',
				'post_parent'	=> 0,
				'guid'			=> get_site_url() . '/wp-content/uploads/initial_images/shop-logo-white.png',
				'menu_order'	=> 0,
				'post_type'		=> 'attachment',
				'post_mime_type'=> 'image/png',
				'comment_count'	=> 0
			)
		);

 		$wpdb->query( "TRUNCATE TABLE $wpdb->posts" );
 		foreach ( $values_array as $value ) {
			$wpdb->query( "INSERT INTO $wpdb->posts ( ID, post_author, post_date, post_date_gmt, post_content, post_title, post_excerpt, post_status, comment_status, ping_status, post_password, post_name, to_ping, pinged, post_modified, post_modified_gmt, post_content_filtered, post_parent, guid, menu_order, post_type, post_mime_type, comment_count) VALUES ('" . $value['ID'] . "','" . $value['post_author'] ."','" . $value['post_date'] ."','" . $value['post_date_gmt'] ."','" . $value['post_content'] ."','" . $value['post_title'] ."','" . $value['post_excerpt'] ."','" . $value['post_status'] ."','" . $value['comment_status'] ."','" . $value['ping_status'] ."','" . $value['post_password'] ."','" . $value['post_name'] ."','" . $value['to_ping'] ."','" . $value['pinged'] ."','" . $value['post_modified'] ."','" . $value['post_modified_gmt'] ."','" . $value['post_content_filtered'] ."','" . $value['post_parent'] ."','" . $value['guid'] ."','" . $value['menu_order'] ."','" . $value['post_type'] ."','" . $value['post_mime_type'] ."','" . $value['comment_count'] ."')" );
		}

		/* if ( function_exists( 'wp_get_original_image_path' ) ) {
			$fullsizepath = wp_get_original_image_path( 30 );
		} else {
			$fullsizepath = get_attached_file( 30 );
		}

		wp_generate_attachment_metadata( 30, $fullsizepath ) */

		$wpdb->query( "TRUNCATE TABLE $wpdb->terms" );
		$wpdb->query( "INSERT INTO $wpdb->terms ( term_id, name, slug, term_group ) VALUES ('1','Uncategorized','uncategorized','0')" );
		$wpdb->query( "INSERT INTO $wpdb->terms ( term_id, name, slug, term_group ) VALUES ('2','Main Menu','main-menu','0')" );

		$wpdb->query( "TRUNCATE TABLE $wpdb->term_taxonomy" );
		$wpdb->query( "INSERT INTO $wpdb->term_taxonomy ( term_taxonomy_id, term_id, taxonomy, parent, count ) VALUES ('1','1','category','0','1')" );
		$wpdb->query( "INSERT INTO $wpdb->term_taxonomy ( term_taxonomy_id, term_id, taxonomy, parent, count ) VALUES ('2','2','nav_menu','0','7')" );

		$wpdb->query( "TRUNCATE TABLE $wpdb->term_relationships" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('1','1','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('10','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('11','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('12','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('13','2','0')" );
		$wpdb->query( "INSERT INTO $wpdb->term_relationships ( object_id, term_taxonomy_id, term_order ) VALUES ('14','2','0')" );
	}
}
}

?>