<?php
class EWDQS_Show_Overview {

	function __construct() {
		add_action( 'admin_enqueue_scripts', array($this, 'enqueue_scripts') );
		add_action( 'admin_menu', array($this, 'add_menu_page') );
		add_action( 'admin_head', array($this, 'remove_admin_menu_link') );
		
		if (isset($_POST['overview_completed'])) {
			$this->update_tasks();

			wp_safe_redirect(admin_url());
		}
		else {
			if (!isset($_GET['page']) or $_GET['page'] != 'ewdqs-overview') {
				wp_safe_redirect( admin_url( 'index.php?page=ewdqs-overview') );
				exit;
			}
		}
	}

	function enqueue_scripts() {
		wp_enqueue_style( 'ewdqs-overview-css', EWDQS_URL . 'includes/css/ewdqs-overview.css' );
	}

	function add_menu_page() {
		add_dashboard_page(
			esc_html__( 'Setup Overview', 'ewd-quick-starter' ),
			esc_html__( 'Setup Overview', 'ewd-quick-starter' ),
			'manage_options',
			'ewdqs-overview',
			array($this, 'display_overview_screen')
		);
	}

	function remove_admin_menu_link() {
		remove_submenu_page( 'index.php', 'ewdqs-overview' );
	}

	function display_overview_screen() {
		$tasks = get_option("ewdqs_tasks");
		$intro_text = get_option("ewdqs_intro_text");

		echo '<div class="ewdqs-theme-selection">';

		if ( $intro_text ) { echo '<div class="ewdqs-intro-text">' . $intro_text . '</div>'; }
		
		echo '<form method="post">';
		
		echo '<ol>';
		foreach ($tasks as $count => $task) {
			$step_name_function = $task . "_name";
            
            if (!$step_name_function() or $count == 1) {continue;}

            $instructions_function = $task . "_instructions";

			echo '<li class="ewdqs-overview-step">';
			echo '<div class="ewdqs-step-name">' . $step_name_function() . '</div>';
			echo '<div class="ewdqs-step-instructions">' . $instructions_function() . '</div>';
			echo '</li>';
		}
		echo '</ol>';
		echo '<div class="ewdqs-clear"></div>';

		echo '<div class="ewdqs-overview-completed">';
		echo '<input type="submit" name="overview_completed" value="' . __('Get Started', 'ewd-quick-starter') . '" />';
		echo '</div>';

		echo '</form>';
		
		echo '</div>';
	}

	function update_tasks() {
		$completed_tasks = get_option("ewdqs_completed_tasks");
		$completed_tasks[] = 'EWDQS_Show_Overview';
		update_option("ewdqs_completed_tasks", $completed_tasks);
	}
}

function EWDQS_Show_Overview_name() {
	return __("Setting Up Your Site", 'ewd-quick-starter');
}

function EWDQS_Show_Overview_instructions() {
	return __('This walkthrough will help you get your site set up in just a few minutes. These are the steps involved:', 'ewd-quick-starter');
}
?>